/*
 * Names for errors generated from
 * [MS-ERREF] https://msdn.microsoft.com/en-us/library/cc231199.aspx
 */
	 case 0x0:
		return "WERR_SUCCESS";
		break;
	 case 0x1:
		return "WERR_INVALID_FUNCTION";
		break;
	 case 0x2:
		return "WERR_FILE_NOT_FOUND";
		break;
	 case 0x3:
		return "WERR_PATH_NOT_FOUND";
		break;
	 case 0x4:
		return "WERR_TOO_MANY_OPEN_FILES";
		break;
	 case 0x5:
		return "WERR_ACCESS_DENIED";
		break;
	 case 0x6:
		return "WERR_INVALID_HANDLE";
		break;
	 case 0x7:
		return "WERR_ARENA_TRASHED";
		break;
	 case 0x8:
		return "WERR_NOT_ENOUGH_MEMORY";
		break;
	 case 0x9:
		return "WERR_INVALID_BLOCK";
		break;
	 case 0xa:
		return "WERR_BAD_ENVIRONMENT";
		break;
	 case 0xb:
		return "WERR_BAD_FORMAT";
		break;
	 case 0xc:
		return "WERR_INVALID_ACCESS";
		break;
	 case 0xd:
		return "WERR_INVALID_DATA";
		break;
	 case 0xe:
		return "WERR_OUTOFMEMORY";
		break;
	 case 0xf:
		return "WERR_INVALID_DRIVE";
		break;
	 case 0x10:
		return "WERR_CURRENT_DIRECTORY";
		break;
	 case 0x11:
		return "WERR_NOT_SAME_DEVICE";
		break;
	 case 0x12:
		return "WERR_NO_MORE_FILES";
		break;
	 case 0x13:
		return "WERR_WRITE_PROTECT";
		break;
	 case 0x14:
		return "WERR_BAD_UNIT";
		break;
	 case 0x15:
		return "WERR_NOT_READY";
		break;
	 case 0x16:
		return "WERR_BAD_COMMAND";
		break;
	 case 0x17:
		return "WERR_CRC";
		break;
	 case 0x18:
		return "WERR_BAD_LENGTH";
		break;
	 case 0x19:
		return "WERR_SEEK";
		break;
	 case 0x1a:
		return "WERR_NOT_DOS_DISK";
		break;
	 case 0x1b:
		return "WERR_SECTOR_NOT_FOUND";
		break;
	 case 0x1c:
		return "WERR_OUT_OF_PAPER";
		break;
	 case 0x1d:
		return "WERR_WRITE_FAULT";
		break;
	 case 0x1e:
		return "WERR_READ_FAULT";
		break;
	 case 0x1f:
		return "WERR_GEN_FAILURE";
		break;
	 case 0x20:
		return "WERR_SHARING_VIOLATION";
		break;
	 case 0x21:
		return "WERR_LOCK_VIOLATION";
		break;
	 case 0x22:
		return "WERR_WRONG_DISK";
		break;
	 case 0x24:
		return "WERR_SHARING_BUFFER_EXCEEDED";
		break;
	 case 0x26:
		return "WERR_HANDLE_EOF";
		break;
	 case 0x27:
		return "WERR_HANDLE_DISK_FULL";
		break;
	 case 0x32:
		return "WERR_NOT_SUPPORTED";
		break;
	 case 0x33:
		return "WERR_REM_NOT_LIST";
		break;
	 case 0x34:
		return "WERR_DUP_NAME";
		break;
	 case 0x35:
		return "WERR_BAD_NETPATH";
		break;
	 case 0x36:
		return "WERR_NETWORK_BUSY";
		break;
	 case 0x37:
		return "WERR_DEV_NOT_EXIST";
		break;
	 case 0x38:
		return "WERR_TOO_MANY_CMDS";
		break;
	 case 0x39:
		return "WERR_ADAP_HDW_ERR";
		break;
	 case 0x3a:
		return "WERR_BAD_NET_RESP";
		break;
	 case 0x3b:
		return "WERR_UNEXP_NET_ERR";
		break;
	 case 0x3c:
		return "WERR_BAD_REM_ADAP";
		break;
	 case 0x3d:
		return "WERR_PRINTQ_FULL";
		break;
	 case 0x3e:
		return "WERR_NO_SPOOL_SPACE";
		break;
	 case 0x3f:
		return "WERR_PRINT_CANCELLED";
		break;
	 case 0x40:
		return "WERR_NETNAME_DELETED";
		break;
	 case 0x41:
		return "WERR_NETWORK_ACCESS_DENIED";
		break;
	 case 0x42:
		return "WERR_BAD_DEV_TYPE";
		break;
	 case 0x43:
		return "WERR_BAD_NET_NAME";
		break;
	 case 0x44:
		return "WERR_TOO_MANY_NAMES";
		break;
	 case 0x45:
		return "WERR_TOO_MANY_SESS";
		break;
	 case 0x46:
		return "WERR_SHARING_PAUSED";
		break;
	 case 0x47:
		return "WERR_REQ_NOT_ACCEP";
		break;
	 case 0x48:
		return "WERR_REDIR_PAUSED";
		break;
	 case 0x50:
		return "WERR_FILE_EXISTS";
		break;
	 case 0x52:
		return "WERR_CANNOT_MAKE";
		break;
	 case 0x53:
		return "WERR_FAIL_I24";
		break;
	 case 0x54:
		return "WERR_OUT_OF_STRUCTURES";
		break;
	 case 0x55:
		return "WERR_ALREADY_ASSIGNED";
		break;
	 case 0x56:
		return "WERR_INVALID_PASSWORD";
		break;
	 case 0x57:
		return "WERR_INVALID_PARAMETER";
		break;
	 case 0x58:
		return "WERR_NET_WRITE_FAULT";
		break;
	 case 0x59:
		return "WERR_NO_PROC_SLOTS";
		break;
	 case 0x64:
		return "WERR_TOO_MANY_SEMAPHORES";
		break;
	 case 0x65:
		return "WERR_EXCL_SEM_ALREADY_OWNED";
		break;
	 case 0x66:
		return "WERR_SEM_IS_SET";
		break;
	 case 0x67:
		return "WERR_TOO_MANY_SEM_REQUESTS";
		break;
	 case 0x68:
		return "WERR_INVALID_AT_INTERRUPT_TIME";
		break;
	 case 0x69:
		return "WERR_SEM_OWNER_DIED";
		break;
	 case 0x6a:
		return "WERR_SEM_USER_LIMIT";
		break;
	 case 0x6b:
		return "WERR_DISK_CHANGE";
		break;
	 case 0x6c:
		return "WERR_DRIVE_LOCKED";
		break;
	 case 0x6d:
		return "WERR_BROKEN_PIPE";
		break;
	 case 0x6e:
		return "WERR_OPEN_FAILED";
		break;
	 case 0x6f:
		return "WERR_BUFFER_OVERFLOW";
		break;
	 case 0x70:
		return "WERR_DISK_FULL";
		break;
	 case 0x71:
		return "WERR_NO_MORE_SEARCH_HANDLES";
		break;
	 case 0x72:
		return "WERR_INVALID_TARGET_HANDLE";
		break;
	 case 0x75:
		return "WERR_INVALID_CATEGORY";
		break;
	 case 0x76:
		return "WERR_INVALID_VERIFY_SWITCH";
		break;
	 case 0x77:
		return "WERR_BAD_DRIVER_LEVEL";
		break;
	 case 0x78:
		return "WERR_CALL_NOT_IMPLEMENTED";
		break;
	 case 0x79:
		return "WERR_SEM_TIMEOUT";
		break;
	 case 0x7a:
		return "WERR_INSUFFICIENT_BUFFER";
		break;
	 case 0x7b:
		return "WERR_INVALID_NAME";
		break;
	 case 0x7c:
		return "WERR_INVALID_LEVEL";
		break;
	 case 0x7d:
		return "WERR_NO_VOLUME_LABEL";
		break;
	 case 0x7e:
		return "WERR_MOD_NOT_FOUND";
		break;
	 case 0x7f:
		return "WERR_PROC_NOT_FOUND";
		break;
	 case 0x80:
		return "WERR_WAIT_NO_CHILDREN";
		break;
	 case 0x81:
		return "WERR_CHILD_NOT_COMPLETE";
		break;
	 case 0x82:
		return "WERR_DIRECT_ACCESS_HANDLE";
		break;
	 case 0x83:
		return "WERR_NEGATIVE_SEEK";
		break;
	 case 0x84:
		return "WERR_SEEK_ON_DEVICE";
		break;
	 case 0x85:
		return "WERR_IS_JOIN_TARGET";
		break;
	 case 0x86:
		return "WERR_IS_JOINED";
		break;
	 case 0x87:
		return "WERR_IS_SUBSTED";
		break;
	 case 0x88:
		return "WERR_NOT_JOINED";
		break;
	 case 0x89:
		return "WERR_NOT_SUBSTED";
		break;
	 case 0x8a:
		return "WERR_JOIN_TO_JOIN";
		break;
	 case 0x8b:
		return "WERR_SUBST_TO_SUBST";
		break;
	 case 0x8c:
		return "WERR_JOIN_TO_SUBST";
		break;
	 case 0x8d:
		return "WERR_SUBST_TO_JOIN";
		break;
	 case 0x8e:
		return "WERR_BUSY_DRIVE";
		break;
	 case 0x8f:
		return "WERR_SAME_DRIVE";
		break;
	 case 0x90:
		return "WERR_DIR_NOT_ROOT";
		break;
	 case 0x91:
		return "WERR_DIR_NOT_EMPTY";
		break;
	 case 0x92:
		return "WERR_IS_SUBST_PATH";
		break;
	 case 0x93:
		return "WERR_IS_JOIN_PATH";
		break;
	 case 0x94:
		return "WERR_PATH_BUSY";
		break;
	 case 0x95:
		return "WERR_IS_SUBST_TARGET";
		break;
	 case 0x96:
		return "WERR_SYSTEM_TRACE";
		break;
	 case 0x97:
		return "WERR_INVALID_EVENT_COUNT";
		break;
	 case 0x98:
		return "WERR_TOO_MANY_MUXWAITERS";
		break;
	 case 0x99:
		return "WERR_INVALID_LIST_FORMAT";
		break;
	 case 0x9a:
		return "WERR_LABEL_TOO_LONG";
		break;
	 case 0x9b:
		return "WERR_TOO_MANY_TCBS";
		break;
	 case 0x9c:
		return "WERR_SIGNAL_REFUSED";
		break;
	 case 0x9d:
		return "WERR_DISCARDED";
		break;
	 case 0x9e:
		return "WERR_NOT_LOCKED";
		break;
	 case 0x9f:
		return "WERR_BAD_THREADID_ADDR";
		break;
	 case 0xa0:
		return "WERR_BAD_ARGUMENTS";
		break;
	 case 0xa1:
		return "WERR_BAD_PATHNAME";
		break;
	 case 0xa2:
		return "WERR_SIGNAL_PENDING";
		break;
	 case 0xa4:
		return "WERR_MAX_THRDS_REACHED";
		break;
	 case 0xa7:
		return "WERR_LOCK_FAILED";
		break;
	 case 0xaa:
		return "WERR_BUSY";
		break;
	 case 0xad:
		return "WERR_CANCEL_VIOLATION";
		break;
	 case 0xae:
		return "WERR_ATOMIC_LOCKS_NOT_SUPPORTED";
		break;
	 case 0xb4:
		return "WERR_INVALID_SEGMENT_NUMBER";
		break;
	 case 0xb6:
		return "WERR_INVALID_ORDINAL";
		break;
	 case 0xb7:
		return "WERR_ALREADY_EXISTS";
		break;
	 case 0xba:
		return "WERR_INVALID_FLAG_NUMBER";
		break;
	 case 0xbb:
		return "WERR_SEM_NOT_FOUND";
		break;
	 case 0xbc:
		return "WERR_INVALID_STARTING_CODESEG";
		break;
	 case 0xbd:
		return "WERR_INVALID_STACKSEG";
		break;
	 case 0xbe:
		return "WERR_INVALID_MODULETYPE";
		break;
	 case 0xbf:
		return "WERR_INVALID_EXE_SIGNATURE";
		break;
	 case 0xc0:
		return "WERR_EXE_MARKED_INVALID";
		break;
	 case 0xc1:
		return "WERR_BAD_EXE_FORMAT";
		break;
	 case 0xc2:
		return "WERR_ITERATED_DATA_EXCEEDS_64K";
		break;
	 case 0xc3:
		return "WERR_INVALID_MINALLOCSIZE";
		break;
	 case 0xc4:
		return "WERR_DYNLINK_FROM_INVALID_RING";
		break;
	 case 0xc5:
		return "WERR_IOPL_NOT_ENABLED";
		break;
	 case 0xc6:
		return "WERR_INVALID_SEGDPL";
		break;
	 case 0xc7:
		return "WERR_AUTODATASEG_EXCEEDS_64K";
		break;
	 case 0xc8:
		return "WERR_RING2SEG_MUST_BE_MOVABLE";
		break;
	 case 0xc9:
		return "WERR_RELOC_CHAIN_XEEDS_SEGLIM";
		break;
	 case 0xca:
		return "WERR_INFLOOP_IN_RELOC_CHAIN";
		break;
	 case 0xcb:
		return "WERR_ENVVAR_NOT_FOUND";
		break;
	 case 0xcd:
		return "WERR_NO_SIGNAL_SENT";
		break;
	 case 0xce:
		return "WERR_FILENAME_EXCED_RANGE";
		break;
	 case 0xcf:
		return "WERR_RING2_STACK_IN_USE";
		break;
	 case 0xd0:
		return "WERR_META_EXPANSION_TOO_LONG";
		break;
	 case 0xd1:
		return "WERR_INVALID_SIGNAL_NUMBER";
		break;
	 case 0xd2:
		return "WERR_THREAD_1_INACTIVE";
		break;
	 case 0xd4:
		return "WERR_LOCKED";
		break;
	 case 0xd6:
		return "WERR_TOO_MANY_MODULES";
		break;
	 case 0xd7:
		return "WERR_NESTING_NOT_ALLOWED";
		break;
	 case 0xd8:
		return "WERR_EXE_MACHINE_TYPE_MISMATCH";
		break;
	 case 0xd9:
		return "WERR_EXE_CANNOT_MODIFY_SIGNED_BINARY";
		break;
	 case 0xda:
		return "WERR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY";
		break;
	 case 0xdc:
		return "WERR_FILE_CHECKED_OUT";
		break;
	 case 0xdd:
		return "WERR_CHECKOUT_REQUIRED";
		break;
	 case 0xde:
		return "WERR_BAD_FILE_TYPE";
		break;
	 case 0xdf:
		return "WERR_FILE_TOO_LARGE";
		break;
	 case 0xe0:
		return "WERR_FORMS_AUTH_REQUIRED";
		break;
	 case 0xe1:
		return "WERR_VIRUS_INFECTED";
		break;
	 case 0xe2:
		return "WERR_VIRUS_DELETED";
		break;
	 case 0xe5:
		return "WERR_PIPE_LOCAL";
		break;
	 case 0xe6:
		return "WERR_BAD_PIPE";
		break;
	 case 0xe7:
		return "WERR_PIPE_BUSY";
		break;
	 case 0xe8:
		return "WERR_NO_DATA";
		break;
	 case 0xe9:
		return "WERR_PIPE_NOT_CONNECTED";
		break;
	 case 0xea:
		return "WERR_MORE_DATA";
		break;
	 case 0xf0:
		return "WERR_VC_DISCONNECTED";
		break;
	 case 0xfe:
		return "WERR_INVALID_EA_NAME";
		break;
	 case 0xff:
		return "WERR_EA_LIST_INCONSISTENT";
		break;
	 case 0x102:
		return "WERR_WAIT_TIMEOUT";
		break;
	 case 0x103:
		return "WERR_NO_MORE_ITEMS";
		break;
	 case 0x10a:
		return "WERR_CANNOT_COPY";
		break;
	 case 0x10b:
		return "WERR_DIRECTORY";
		break;
	 case 0x113:
		return "WERR_EAS_DIDNT_FIT";
		break;
	 case 0x114:
		return "WERR_EA_FILE_CORRUPT";
		break;
	 case 0x115:
		return "WERR_EA_TABLE_FULL";
		break;
	 case 0x116:
		return "WERR_INVALID_EA_HANDLE";
		break;
	 case 0x11a:
		return "WERR_EAS_NOT_SUPPORTED";
		break;
	 case 0x120:
		return "WERR_NOT_OWNER";
		break;
	 case 0x12a:
		return "WERR_TOO_MANY_POSTS";
		break;
	 case 0x12b:
		return "WERR_PARTIAL_COPY";
		break;
	 case 0x12c:
		return "WERR_OPLOCK_NOT_GRANTED";
		break;
	 case 0x12d:
		return "WERR_INVALID_OPLOCK_PROTOCOL";
		break;
	 case 0x12e:
		return "WERR_DISK_TOO_FRAGMENTED";
		break;
	 case 0x12f:
		return "WERR_DELETE_PENDING";
		break;
	 case 0x13d:
		return "WERR_MR_MID_NOT_FOUND";
		break;
	 case 0x13e:
		return "WERR_SCOPE_NOT_FOUND";
		break;
	 case 0x15e:
		return "WERR_FAIL_NOACTION_REBOOT";
		break;
	 case 0x15f:
		return "WERR_FAIL_SHUTDOWN";
		break;
	 case 0x160:
		return "WERR_FAIL_RESTART";
		break;
	 case 0x161:
		return "WERR_MAX_SESSIONS_REACHED";
		break;
	 case 0x190:
		return "WERR_THREAD_MODE_ALREADY_BACKGROUND";
		break;
	 case 0x191:
		return "WERR_THREAD_MODE_NOT_BACKGROUND";
		break;
	 case 0x192:
		return "WERR_PROCESS_MODE_ALREADY_BACKGROUND";
		break;
	 case 0x193:
		return "WERR_PROCESS_MODE_NOT_BACKGROUND";
		break;
	 case 0x1e7:
		return "WERR_INVALID_ADDRESS";
		break;
	 case 0x1f4:
		return "WERR_USER_PROFILE_LOAD";
		break;
	 case 0x216:
		return "WERR_ARITHMETIC_OVERFLOW";
		break;
	 case 0x217:
		return "WERR_PIPE_CONNECTED";
		break;
	 case 0x218:
		return "WERR_PIPE_LISTENING";
		break;
	 case 0x219:
		return "WERR_VERIFIER_STOP";
		break;
	 case 0x21a:
		return "WERR_ABIOS_ERROR";
		break;
	 case 0x21b:
		return "WERR_WX86_WARNING";
		break;
	 case 0x21c:
		return "WERR_WX86_ERROR";
		break;
	 case 0x21d:
		return "WERR_TIMER_NOT_CANCELED";
		break;
	 case 0x21e:
		return "WERR_UNWIND";
		break;
	 case 0x21f:
		return "WERR_BAD_STACK";
		break;
	 case 0x220:
		return "WERR_INVALID_UNWIND_TARGET";
		break;
	 case 0x221:
		return "WERR_INVALID_PORT_ATTRIBUTES";
		break;
	 case 0x222:
		return "WERR_PORT_MESSAGE_TOO_LONG";
		break;
	 case 0x223:
		return "WERR_INVALID_QUOTA_LOWER";
		break;
	 case 0x224:
		return "WERR_DEVICE_ALREADY_ATTACHED";
		break;
	 case 0x225:
		return "WERR_INSTRUCTION_MISALIGNMENT";
		break;
	 case 0x226:
		return "WERR_PROFILING_NOT_STARTED";
		break;
	 case 0x227:
		return "WERR_PROFILING_NOT_STOPPED";
		break;
	 case 0x228:
		return "WERR_COULD_NOT_INTERPRET";
		break;
	 case 0x229:
		return "WERR_PROFILING_AT_LIMIT";
		break;
	 case 0x22a:
		return "WERR_CANT_WAIT";
		break;
	 case 0x22b:
		return "WERR_CANT_TERMINATE_SELF";
		break;
	 case 0x22c:
		return "WERR_UNEXPECTED_MM_CREATE_ERR";
		break;
	 case 0x22d:
		return "WERR_UNEXPECTED_MM_MAP_ERROR";
		break;
	 case 0x22e:
		return "WERR_UNEXPECTED_MM_EXTEND_ERR";
		break;
	 case 0x22f:
		return "WERR_BAD_FUNCTION_TABLE";
		break;
	 case 0x230:
		return "WERR_NO_GUID_TRANSLATION";
		break;
	 case 0x231:
		return "WERR_INVALID_LDT_SIZE";
		break;
	 case 0x233:
		return "WERR_INVALID_LDT_OFFSET";
		break;
	 case 0x234:
		return "WERR_INVALID_LDT_DESCRIPTOR";
		break;
	 case 0x235:
		return "WERR_TOO_MANY_THREADS";
		break;
	 case 0x236:
		return "WERR_THREAD_NOT_IN_PROCESS";
		break;
	 case 0x237:
		return "WERR_PAGEFILE_QUOTA_EXCEEDED";
		break;
	 case 0x238:
		return "WERR_LOGON_SERVER_CONFLICT";
		break;
	 case 0x239:
		return "WERR_SYNCHRONIZATION_REQUIRED";
		break;
	 case 0x23a:
		return "WERR_NET_OPEN_FAILED";
		break;
	 case 0x23b:
		return "WERR_IO_PRIVILEGE_FAILED";
		break;
	 case 0x23c:
		return "WERR_CONTROL_C_EXIT";
		break;
	 case 0x23d:
		return "WERR_MISSING_SYSTEMFILE";
		break;
	 case 0x23e:
		return "WERR_UNHANDLED_EXCEPTION";
		break;
	 case 0x23f:
		return "WERR_APP_INIT_FAILURE";
		break;
	 case 0x240:
		return "WERR_PAGEFILE_CREATE_FAILED";
		break;
	 case 0x241:
		return "WERR_INVALID_IMAGE_HASH";
		break;
	 case 0x242:
		return "WERR_NO_PAGEFILE";
		break;
	 case 0x243:
		return "WERR_ILLEGAL_FLOAT_CONTEXT";
		break;
	 case 0x244:
		return "WERR_NO_EVENT_PAIR";
		break;
	 case 0x245:
		return "WERR_DOMAIN_CTRLR_CONFIG_ERROR";
		break;
	 case 0x246:
		return "WERR_ILLEGAL_CHARACTER";
		break;
	 case 0x247:
		return "WERR_UNDEFINED_CHARACTER";
		break;
	 case 0x248:
		return "WERR_FLOPPY_VOLUME";
		break;
	 case 0x249:
		return "WERR_BIOS_FAILED_TO_CONNECT_INTERRUPT";
		break;
	 case 0x24a:
		return "WERR_BACKUP_CONTROLLER";
		break;
	 case 0x24b:
		return "WERR_MUTANT_LIMIT_EXCEEDED";
		break;
	 case 0x24c:
		return "WERR_FS_DRIVER_REQUIRED";
		break;
	 case 0x24d:
		return "WERR_CANNOT_LOAD_REGISTRY_FILE";
		break;
	 case 0x24e:
		return "WERR_DEBUG_ATTACH_FAILED";
		break;
	 case 0x24f:
		return "WERR_SYSTEM_PROCESS_TERMINATED";
		break;
	 case 0x250:
		return "WERR_DATA_NOT_ACCEPTED";
		break;
	 case 0x251:
		return "WERR_VDM_HARD_ERROR";
		break;
	 case 0x252:
		return "WERR_DRIVER_CANCEL_TIMEOUT";
		break;
	 case 0x253:
		return "WERR_REPLY_MESSAGE_MISMATCH";
		break;
	 case 0x254:
		return "WERR_LOST_WRITEBEHIND_DATA";
		break;
	 case 0x255:
		return "WERR_CLIENT_SERVER_PARAMETERS_INVALID";
		break;
	 case 0x256:
		return "WERR_NOT_TINY_STREAM";
		break;
	 case 0x257:
		return "WERR_STACK_OVERFLOW_READ";
		break;
	 case 0x258:
		return "WERR_CONVERT_TO_LARGE";
		break;
	 case 0x259:
		return "WERR_FOUND_OUT_OF_SCOPE";
		break;
	 case 0x25a:
		return "WERR_ALLOCATE_BUCKET";
		break;
	 case 0x25b:
		return "WERR_MARSHALL_OVERFLOW";
		break;
	 case 0x25c:
		return "WERR_INVALID_VARIANT";
		break;
	 case 0x25d:
		return "WERR_BAD_COMPRESSION_BUFFER";
		break;
	 case 0x25e:
		return "WERR_AUDIT_FAILED";
		break;
	 case 0x25f:
		return "WERR_TIMER_RESOLUTION_NOT_SET";
		break;
	 case 0x260:
		return "WERR_INSUFFICIENT_LOGON_INFO";
		break;
	 case 0x261:
		return "WERR_BAD_DLL_ENTRYPOINT";
		break;
	 case 0x262:
		return "WERR_BAD_SERVICE_ENTRYPOINT";
		break;
	 case 0x263:
		return "WERR_IP_ADDRESS_CONFLICT1";
		break;
	 case 0x264:
		return "WERR_IP_ADDRESS_CONFLICT2";
		break;
	 case 0x265:
		return "WERR_REGISTRY_QUOTA_LIMIT";
		break;
	 case 0x266:
		return "WERR_NO_CALLBACK_ACTIVE";
		break;
	 case 0x267:
		return "WERR_PWD_TOO_SHORT";
		break;
	 case 0x268:
		return "WERR_PWD_TOO_RECENT";
		break;
	 case 0x269:
		return "WERR_PWD_HISTORY_CONFLICT";
		break;
	 case 0x26a:
		return "WERR_UNSUPPORTED_COMPRESSION";
		break;
	 case 0x26b:
		return "WERR_INVALID_HW_PROFILE";
		break;
	 case 0x26c:
		return "WERR_INVALID_PLUGPLAY_DEVICE_PATH";
		break;
	 case 0x26d:
		return "WERR_QUOTA_LIST_INCONSISTENT";
		break;
	 case 0x26e:
		return "WERR_EVALUATION_EXPIRATION";
		break;
	 case 0x26f:
		return "WERR_ILLEGAL_DLL_RELOCATION";
		break;
	 case 0x270:
		return "WERR_DLL_INIT_FAILED_LOGOFF";
		break;
	 case 0x271:
		return "WERR_VALIDATE_CONTINUE";
		break;
	 case 0x272:
		return "WERR_NO_MORE_MATCHES";
		break;
	 case 0x273:
		return "WERR_RANGE_LIST_CONFLICT";
		break;
	 case 0x274:
		return "WERR_SERVER_SID_MISMATCH";
		break;
	 case 0x275:
		return "WERR_CANT_ENABLE_DENY_ONLY";
		break;
	 case 0x276:
		return "WERR_FLOAT_MULTIPLE_FAULTS";
		break;
	 case 0x277:
		return "WERR_FLOAT_MULTIPLE_TRAPS";
		break;
	 case 0x278:
		return "WERR_NOINTERFACE";
		break;
	 case 0x279:
		return "WERR_DRIVER_FAILED_SLEEP";
		break;
	 case 0x27a:
		return "WERR_CORRUPT_SYSTEM_FILE";
		break;
	 case 0x27b:
		return "WERR_COMMITMENT_MINIMUM";
		break;
	 case 0x27c:
		return "WERR_PNP_RESTART_ENUMERATION";
		break;
	 case 0x27d:
		return "WERR_SYSTEM_IMAGE_BAD_SIGNATURE";
		break;
	 case 0x27e:
		return "WERR_PNP_REBOOT_REQUIRED";
		break;
	 case 0x27f:
		return "WERR_INSUFFICIENT_POWER";
		break;
	 case 0x281:
		return "WERR_SYSTEM_SHUTDOWN";
		break;
	 case 0x282:
		return "WERR_PORT_NOT_SET";
		break;
	 case 0x283:
		return "WERR_DS_VERSION_CHECK_FAILURE";
		break;
	 case 0x284:
		return "WERR_RANGE_NOT_FOUND";
		break;
	 case 0x286:
		return "WERR_NOT_SAFE_MODE_DRIVER";
		break;
	 case 0x287:
		return "WERR_FAILED_DRIVER_ENTRY";
		break;
	 case 0x288:
		return "WERR_DEVICE_ENUMERATION_ERROR";
		break;
	 case 0x289:
		return "WERR_MOUNT_POINT_NOT_RESOLVED";
		break;
	 case 0x28a:
		return "WERR_INVALID_DEVICE_OBJECT_PARAMETER";
		break;
	 case 0x28b:
		return "WERR_MCA_OCCURED";
		break;
	 case 0x28c:
		return "WERR_DRIVER_DATABASE_ERROR";
		break;
	 case 0x28d:
		return "WERR_SYSTEM_HIVE_TOO_LARGE";
		break;
	 case 0x28e:
		return "WERR_DRIVER_FAILED_PRIOR_UNLOAD";
		break;
	 case 0x28f:
		return "WERR_VOLSNAP_PREPARE_HIBERNATE";
		break;
	 case 0x290:
		return "WERR_HIBERNATION_FAILURE";
		break;
	 case 0x299:
		return "WERR_FILE_SYSTEM_LIMITATION";
		break;
	 case 0x29c:
		return "WERR_ASSERTION_FAILURE";
		break;
	 case 0x29d:
		return "WERR_ACPI_ERROR";
		break;
	 case 0x29e:
		return "WERR_WOW_ASSERTION";
		break;
	 case 0x29f:
		return "WERR_PNP_BAD_MPS_TABLE";
		break;
	 case 0x2a0:
		return "WERR_PNP_TRANSLATION_FAILED";
		break;
	 case 0x2a1:
		return "WERR_PNP_IRQ_TRANSLATION_FAILED";
		break;
	 case 0x2a2:
		return "WERR_PNP_INVALID_ID";
		break;
	 case 0x2a3:
		return "WERR_WAKE_SYSTEM_DEBUGGER";
		break;
	 case 0x2a4:
		return "WERR_HANDLES_CLOSED";
		break;
	 case 0x2a5:
		return "WERR_EXTRANEOUS_INFORMATION";
		break;
	 case 0x2a6:
		return "WERR_RXACT_COMMIT_NECESSARY";
		break;
	 case 0x2a7:
		return "WERR_MEDIA_CHECK";
		break;
	 case 0x2a8:
		return "WERR_GUID_SUBSTITUTION_MADE";
		break;
	 case 0x2a9:
		return "WERR_STOPPED_ON_SYMLINK";
		break;
	 case 0x2aa:
		return "WERR_LONGJUMP";
		break;
	 case 0x2ab:
		return "WERR_PLUGPLAY_QUERY_VETOED";
		break;
	 case 0x2ac:
		return "WERR_UNWIND_CONSOLIDATE";
		break;
	 case 0x2ad:
		return "WERR_REGISTRY_HIVE_RECOVERED";
		break;
	 case 0x2ae:
		return "WERR_DLL_MIGHT_BE_INSECURE";
		break;
	 case 0x2af:
		return "WERR_DLL_MIGHT_BE_INCOMPATIBLE";
		break;
	 case 0x2b0:
		return "WERR_DBG_EXCEPTION_NOT_HANDLED";
		break;
	 case 0x2b1:
		return "WERR_DBG_REPLY_LATER";
		break;
	 case 0x2b2:
		return "WERR_DBG_UNABLE_TO_PROVIDE_HANDLE";
		break;
	 case 0x2b3:
		return "WERR_DBG_TERMINATE_THREAD";
		break;
	 case 0x2b4:
		return "WERR_DBG_TERMINATE_PROCESS";
		break;
	 case 0x2b5:
		return "WERR_DBG_CONTROL_C";
		break;
	 case 0x2b6:
		return "WERR_DBG_PRINTEXCEPTION_C";
		break;
	 case 0x2b7:
		return "WERR_DBG_RIPEXCEPTION";
		break;
	 case 0x2b8:
		return "WERR_DBG_CONTROL_BREAK";
		break;
	 case 0x2b9:
		return "WERR_DBG_COMMAND_EXCEPTION";
		break;
	 case 0x2ba:
		return "WERR_OBJECT_NAME_EXISTS";
		break;
	 case 0x2bb:
		return "WERR_THREAD_WAS_SUSPENDED";
		break;
	 case 0x2bc:
		return "WERR_IMAGE_NOT_AT_BASE";
		break;
	 case 0x2bd:
		return "WERR_RXACT_STATE_CREATED";
		break;
	 case 0x2be:
		return "WERR_SEGMENT_NOTIFICATION";
		break;
	 case 0x2bf:
		return "WERR_BAD_CURRENT_DIRECTORY";
		break;
	 case 0x2c0:
		return "WERR_FT_READ_RECOVERY_FROM_BACKUP";
		break;
	 case 0x2c1:
		return "WERR_FT_WRITE_RECOVERY";
		break;
	 case 0x2c2:
		return "WERR_IMAGE_MACHINE_TYPE_MISMATCH";
		break;
	 case 0x2c3:
		return "WERR_RECEIVE_PARTIAL";
		break;
	 case 0x2c4:
		return "WERR_RECEIVE_EXPEDITED";
		break;
	 case 0x2c5:
		return "WERR_RECEIVE_PARTIAL_EXPEDITED";
		break;
	 case 0x2c6:
		return "WERR_EVENT_DONE";
		break;
	 case 0x2c7:
		return "WERR_EVENT_PENDING";
		break;
	 case 0x2c8:
		return "WERR_CHECKING_FILE_SYSTEM";
		break;
	 case 0x2c9:
		return "WERR_FATAL_APP_EXIT";
		break;
	 case 0x2ca:
		return "WERR_PREDEFINED_HANDLE";
		break;
	 case 0x2cb:
		return "WERR_WAS_UNLOCKED";
		break;
	 case 0x2cd:
		return "WERR_WAS_LOCKED";
		break;
	 case 0x2cf:
		return "WERR_ALREADY_WIN32";
		break;
	 case 0x2d0:
		return "WERR_IMAGE_MACHINE_TYPE_MISMATCH_EXE";
		break;
	 case 0x2d1:
		return "WERR_NO_YIELD_PERFORMED";
		break;
	 case 0x2d2:
		return "WERR_TIMER_RESUME_IGNORED";
		break;
	 case 0x2d3:
		return "WERR_ARBITRATION_UNHANDLED";
		break;
	 case 0x2d4:
		return "WERR_CARDBUS_NOT_SUPPORTED";
		break;
	 case 0x2d5:
		return "WERR_MP_PROCESSOR_MISMATCH";
		break;
	 case 0x2d6:
		return "WERR_HIBERNATED";
		break;
	 case 0x2d7:
		return "WERR_RESUME_HIBERNATION";
		break;
	 case 0x2d8:
		return "WERR_FIRMWARE_UPDATED";
		break;
	 case 0x2d9:
		return "WERR_DRIVERS_LEAKING_LOCKED_PAGES";
		break;
	 case 0x2da:
		return "WERR_WAKE_SYSTEM";
		break;
	 case 0x2df:
		return "WERR_ABANDONED_WAIT_0";
		break;
	 case 0x2e4:
		return "WERR_ELEVATION_REQUIRED";
		break;
	 case 0x2e5:
		return "WERR_REPARSE";
		break;
	 case 0x2e6:
		return "WERR_OPLOCK_BREAK_IN_PROGRESS";
		break;
	 case 0x2e7:
		return "WERR_VOLUME_MOUNTED";
		break;
	 case 0x2e8:
		return "WERR_RXACT_COMMITTED";
		break;
	 case 0x2e9:
		return "WERR_NOTIFY_CLEANUP";
		break;
	 case 0x2ea:
		return "WERR_PRIMARY_TRANSPORT_CONNECT_FAILED";
		break;
	 case 0x2eb:
		return "WERR_PAGE_FAULT_TRANSITION";
		break;
	 case 0x2ec:
		return "WERR_PAGE_FAULT_DEMAND_ZERO";
		break;
	 case 0x2ed:
		return "WERR_PAGE_FAULT_COPY_ON_WRITE";
		break;
	 case 0x2ee:
		return "WERR_PAGE_FAULT_GUARD_PAGE";
		break;
	 case 0x2ef:
		return "WERR_PAGE_FAULT_PAGING_FILE";
		break;
	 case 0x2f0:
		return "WERR_CACHE_PAGE_LOCKED";
		break;
	 case 0x2f1:
		return "WERR_CRASH_DUMP";
		break;
	 case 0x2f2:
		return "WERR_BUFFER_ALL_ZEROS";
		break;
	 case 0x2f3:
		return "WERR_REPARSE_OBJECT";
		break;
	 case 0x2f4:
		return "WERR_RESOURCE_REQUIREMENTS_CHANGED";
		break;
	 case 0x2f5:
		return "WERR_TRANSLATION_COMPLETE";
		break;
	 case 0x2f6:
		return "WERR_NOTHING_TO_TERMINATE";
		break;
	 case 0x2f7:
		return "WERR_PROCESS_NOT_IN_JOB";
		break;
	 case 0x2f8:
		return "WERR_PROCESS_IN_JOB";
		break;
	 case 0x2f9:
		return "WERR_VOLSNAP_HIBERNATE_READY";
		break;
	 case 0x2fa:
		return "WERR_FSFILTER_OP_COMPLETED_SUCCESSFULLY";
		break;
	 case 0x2fb:
		return "WERR_INTERRUPT_VECTOR_ALREADY_CONNECTED";
		break;
	 case 0x2fc:
		return "WERR_INTERRUPT_STILL_CONNECTED";
		break;
	 case 0x2fd:
		return "WERR_WAIT_FOR_OPLOCK";
		break;
	 case 0x2fe:
		return "WERR_DBG_EXCEPTION_HANDLED";
		break;
	 case 0x2ff:
		return "WERR_DBG_CONTINUE";
		break;
	 case 0x300:
		return "WERR_CALLBACK_POP_STACK";
		break;
	 case 0x301:
		return "WERR_COMPRESSION_DISABLED";
		break;
	 case 0x302:
		return "WERR_CANTFETCHBACKWARDS";
		break;
	 case 0x303:
		return "WERR_CANTSCROLLBACKWARDS";
		break;
	 case 0x304:
		return "WERR_ROWSNOTRELEASED";
		break;
	 case 0x305:
		return "WERR_BAD_ACCESSOR_FLAGS";
		break;
	 case 0x306:
		return "WERR_ERRORS_ENCOUNTERED";
		break;
	 case 0x307:
		return "WERR_NOT_CAPABLE";
		break;
	 case 0x308:
		return "WERR_REQUEST_OUT_OF_SEQUENCE";
		break;
	 case 0x309:
		return "WERR_VERSION_PARSE_ERROR";
		break;
	 case 0x30a:
		return "WERR_BADSTARTPOSITION";
		break;
	 case 0x30b:
		return "WERR_MEMORY_HARDWARE";
		break;
	 case 0x30c:
		return "WERR_DISK_REPAIR_DISABLED";
		break;
	 case 0x30d:
		return "WERR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE";
		break;
	 case 0x30e:
		return "WERR_SYSTEM_POWERSTATE_TRANSITION";
		break;
	 case 0x30f:
		return "WERR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION";
		break;
	 case 0x310:
		return "WERR_MCA_EXCEPTION";
		break;
	 case 0x311:
		return "WERR_ACCESS_AUDIT_BY_POLICY";
		break;
	 case 0x312:
		return "WERR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY";
		break;
	 case 0x313:
		return "WERR_ABANDON_HIBERFILE";
		break;
	 case 0x314:
		return "WERR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED";
		break;
	 case 0x315:
		return "WERR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR";
		break;
	 case 0x316:
		return "WERR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR";
		break;
	 case 0x3e2:
		return "WERR_EA_ACCESS_DENIED";
		break;
	 case 0x3e3:
		return "WERR_OPERATION_ABORTED";
		break;
	 case 0x3e4:
		return "WERR_IO_INCOMPLETE";
		break;
	 case 0x3e5:
		return "WERR_IO_PENDING";
		break;
	 case 0x3e6:
		return "WERR_NOACCESS";
		break;
	 case 0x3e7:
		return "WERR_SWAPERROR";
		break;
	 case 0x3e9:
		return "WERR_STACK_OVERFLOW";
		break;
	 case 0x3ea:
		return "WERR_INVALID_MESSAGE";
		break;
	 case 0x3eb:
		return "WERR_CAN_NOT_COMPLETE";
		break;
	 case 0x3ec:
		return "WERR_INVALID_FLAGS";
		break;
	 case 0x3ed:
		return "WERR_UNRECOGNIZED_VOLUME";
		break;
	 case 0x3ee:
		return "WERR_FILE_INVALID";
		break;
	 case 0x3ef:
		return "WERR_FULLSCREEN_MODE";
		break;
	 case 0x3f0:
		return "WERR_NO_TOKEN";
		break;
	 case 0x3f1:
		return "WERR_BADDB";
		break;
	 case 0x3f2:
		return "WERR_BADKEY";
		break;
	 case 0x3f3:
		return "WERR_CANTOPEN";
		break;
	 case 0x3f4:
		return "WERR_CANTREAD";
		break;
	 case 0x3f5:
		return "WERR_CANTWRITE";
		break;
	 case 0x3f6:
		return "WERR_REGISTRY_RECOVERED";
		break;
	 case 0x3f7:
		return "WERR_REGISTRY_CORRUPT";
		break;
	 case 0x3f8:
		return "WERR_REGISTRY_IO_FAILED";
		break;
	 case 0x3f9:
		return "WERR_NOT_REGISTRY_FILE";
		break;
	 case 0x3fa:
		return "WERR_KEY_DELETED";
		break;
	 case 0x3fb:
		return "WERR_NO_LOG_SPACE";
		break;
	 case 0x3fc:
		return "WERR_KEY_HAS_CHILDREN";
		break;
	 case 0x3fd:
		return "WERR_CHILD_MUST_BE_VOLATILE";
		break;
	 case 0x3fe:
		return "WERR_NOTIFY_ENUM_DIR";
		break;
	 case 0x41b:
		return "WERR_DEPENDENT_SERVICES_RUNNING";
		break;
	 case 0x41c:
		return "WERR_INVALID_SERVICE_CONTROL";
		break;
	 case 0x41d:
		return "WERR_SERVICE_REQUEST_TIMEOUT";
		break;
	 case 0x41e:
		return "WERR_SERVICE_NO_THREAD";
		break;
	 case 0x41f:
		return "WERR_SERVICE_DATABASE_LOCKED";
		break;
	 case 0x420:
		return "WERR_SERVICE_ALREADY_RUNNING";
		break;
	 case 0x421:
		return "WERR_INVALID_SERVICE_ACCOUNT";
		break;
	 case 0x422:
		return "WERR_SERVICE_DISABLED";
		break;
	 case 0x423:
		return "WERR_CIRCULAR_DEPENDENCY";
		break;
	 case 0x424:
		return "WERR_SERVICE_DOES_NOT_EXIST";
		break;
	 case 0x425:
		return "WERR_SERVICE_CANNOT_ACCEPT_CTRL";
		break;
	 case 0x426:
		return "WERR_SERVICE_NOT_ACTIVE";
		break;
	 case 0x427:
		return "WERR_FAILED_SERVICE_CONTROLLER_CONNECT";
		break;
	 case 0x428:
		return "WERR_EXCEPTION_IN_SERVICE";
		break;
	 case 0x429:
		return "WERR_DATABASE_DOES_NOT_EXIST";
		break;
	 case 0x42a:
		return "WERR_SERVICE_SPECIFIC_ERROR";
		break;
	 case 0x42b:
		return "WERR_PROCESS_ABORTED";
		break;
	 case 0x42c:
		return "WERR_SERVICE_DEPENDENCY_FAIL";
		break;
	 case 0x42d:
		return "WERR_SERVICE_LOGON_FAILED";
		break;
	 case 0x42e:
		return "WERR_SERVICE_START_HANG";
		break;
	 case 0x42f:
		return "WERR_INVALID_SERVICE_LOCK";
		break;
	 case 0x430:
		return "WERR_SERVICE_MARKED_FOR_DELETE";
		break;
	 case 0x431:
		return "WERR_SERVICE_EXISTS";
		break;
	 case 0x432:
		return "WERR_ALREADY_RUNNING_LKG";
		break;
	 case 0x433:
		return "WERR_SERVICE_DEPENDENCY_DELETED";
		break;
	 case 0x434:
		return "WERR_BOOT_ALREADY_ACCEPTED";
		break;
	 case 0x435:
		return "WERR_SERVICE_NEVER_STARTED";
		break;
	 case 0x436:
		return "WERR_DUPLICATE_SERVICE_NAME";
		break;
	 case 0x437:
		return "WERR_DIFFERENT_SERVICE_ACCOUNT";
		break;
	 case 0x438:
		return "WERR_CANNOT_DETECT_DRIVER_FAILURE";
		break;
	 case 0x439:
		return "WERR_CANNOT_DETECT_PROCESS_ABORT";
		break;
	 case 0x43a:
		return "WERR_NO_RECOVERY_PROGRAM";
		break;
	 case 0x43b:
		return "WERR_SERVICE_NOT_IN_EXE";
		break;
	 case 0x43c:
		return "WERR_NOT_SAFEBOOT_SERVICE";
		break;
	 case 0x44c:
		return "WERR_END_OF_MEDIA";
		break;
	 case 0x44d:
		return "WERR_FILEMARK_DETECTED";
		break;
	 case 0x44e:
		return "WERR_BEGINNING_OF_MEDIA";
		break;
	 case 0x44f:
		return "WERR_SETMARK_DETECTED";
		break;
	 case 0x450:
		return "WERR_NO_DATA_DETECTED";
		break;
	 case 0x451:
		return "WERR_PARTITION_FAILURE";
		break;
	 case 0x452:
		return "WERR_INVALID_BLOCK_LENGTH";
		break;
	 case 0x453:
		return "WERR_DEVICE_NOT_PARTITIONED";
		break;
	 case 0x454:
		return "WERR_UNABLE_TO_LOCK_MEDIA";
		break;
	 case 0x455:
		return "WERR_UNABLE_TO_UNLOAD_MEDIA";
		break;
	 case 0x456:
		return "WERR_MEDIA_CHANGED";
		break;
	 case 0x457:
		return "WERR_BUS_RESET";
		break;
	 case 0x458:
		return "WERR_NO_MEDIA_IN_DRIVE";
		break;
	 case 0x459:
		return "WERR_NO_UNICODE_TRANSLATION";
		break;
	 case 0x45a:
		return "WERR_DLL_INIT_FAILED";
		break;
	 case 0x45b:
		return "WERR_SHUTDOWN_IN_PROGRESS";
		break;
	 case 0x45c:
		return "WERR_NO_SHUTDOWN_IN_PROGRESS";
		break;
	 case 0x45d:
		return "WERR_IO_DEVICE";
		break;
	 case 0x45e:
		return "WERR_SERIAL_NO_DEVICE";
		break;
	 case 0x45f:
		return "WERR_IRQ_BUSY";
		break;
	 case 0x460:
		return "WERR_MORE_WRITES";
		break;
	 case 0x461:
		return "WERR_COUNTER_TIMEOUT";
		break;
	 case 0x462:
		return "WERR_FLOPPY_ID_MARK_NOT_FOUND";
		break;
	 case 0x463:
		return "WERR_FLOPPY_WRONG_CYLINDER";
		break;
	 case 0x464:
		return "WERR_FLOPPY_UNKNOWN_ERROR";
		break;
	 case 0x465:
		return "WERR_FLOPPY_BAD_REGISTERS";
		break;
	 case 0x466:
		return "WERR_DISK_RECALIBRATE_FAILED";
		break;
	 case 0x467:
		return "WERR_DISK_OPERATION_FAILED";
		break;
	 case 0x468:
		return "WERR_DISK_RESET_FAILED";
		break;
	 case 0x469:
		return "WERR_EOM_OVERFLOW";
		break;
	 case 0x46a:
		return "WERR_NOT_ENOUGH_SERVER_MEMORY";
		break;
	 case 0x46b:
		return "WERR_POSSIBLE_DEADLOCK";
		break;
	 case 0x46c:
		return "WERR_MAPPED_ALIGNMENT";
		break;
	 case 0x474:
		return "WERR_SET_POWER_STATE_VETOED";
		break;
	 case 0x475:
		return "WERR_SET_POWER_STATE_FAILED";
		break;
	 case 0x476:
		return "WERR_TOO_MANY_LINKS";
		break;
	 case 0x47e:
		return "WERR_OLD_WIN_VERSION";
		break;
	 case 0x47f:
		return "WERR_APP_WRONG_OS";
		break;
	 case 0x480:
		return "WERR_SINGLE_INSTANCE_APP";
		break;
	 case 0x481:
		return "WERR_RMODE_APP";
		break;
	 case 0x482:
		return "WERR_INVALID_DLL";
		break;
	 case 0x483:
		return "WERR_NO_ASSOCIATION";
		break;
	 case 0x484:
		return "WERR_DDE_FAIL";
		break;
	 case 0x485:
		return "WERR_DLL_NOT_FOUND";
		break;
	 case 0x486:
		return "WERR_NO_MORE_USER_HANDLES";
		break;
	 case 0x487:
		return "WERR_MESSAGE_SYNC_ONLY";
		break;
	 case 0x488:
		return "WERR_SOURCE_ELEMENT_EMPTY";
		break;
	 case 0x489:
		return "WERR_DESTINATION_ELEMENT_FULL";
		break;
	 case 0x48a:
		return "WERR_ILLEGAL_ELEMENT_ADDRESS";
		break;
	 case 0x48b:
		return "WERR_MAGAZINE_NOT_PRESENT";
		break;
	 case 0x48c:
		return "WERR_DEVICE_REINITIALIZATION_NEEDED";
		break;
	 case 0x48d:
		return "WERR_DEVICE_REQUIRES_CLEANING";
		break;
	 case 0x48e:
		return "WERR_DEVICE_DOOR_OPEN";
		break;
	 case 0x48f:
		return "WERR_DEVICE_NOT_CONNECTED";
		break;
	 case 0x490:
		return "WERR_NOT_FOUND";
		break;
	 case 0x491:
		return "WERR_NO_MATCH";
		break;
	 case 0x492:
		return "WERR_SET_NOT_FOUND";
		break;
	 case 0x493:
		return "WERR_POINT_NOT_FOUND";
		break;
	 case 0x494:
		return "WERR_NO_TRACKING_SERVICE";
		break;
	 case 0x495:
		return "WERR_NO_VOLUME_ID";
		break;
	 case 0x497:
		return "WERR_UNABLE_TO_REMOVE_REPLACED";
		break;
	 case 0x498:
		return "WERR_UNABLE_TO_MOVE_REPLACEMENT";
		break;
	 case 0x499:
		return "WERR_UNABLE_TO_MOVE_REPLACEMENT_2";
		break;
	 case 0x49a:
		return "WERR_JOURNAL_DELETE_IN_PROGRESS";
		break;
	 case 0x49b:
		return "WERR_JOURNAL_NOT_ACTIVE";
		break;
	 case 0x49c:
		return "WERR_POTENTIAL_FILE_FOUND";
		break;
	 case 0x49d:
		return "WERR_JOURNAL_ENTRY_DELETED";
		break;
	 case 0x4a6:
		return "WERR_SHUTDOWN_IS_SCHEDULED";
		break;
	 case 0x4a7:
		return "WERR_SHUTDOWN_USERS_LOGGED_ON";
		break;
	 case 0x4b0:
		return "WERR_BAD_DEVICE";
		break;
	 case 0x4b1:
		return "WERR_CONNECTION_UNAVAIL";
		break;
	 case 0x4b2:
		return "WERR_DEVICE_ALREADY_REMEMBERED";
		break;
	 case 0x4b3:
		return "WERR_NO_NET_OR_BAD_PATH";
		break;
	 case 0x4b4:
		return "WERR_BAD_PROVIDER";
		break;
	 case 0x4b5:
		return "WERR_CANNOT_OPEN_PROFILE";
		break;
	 case 0x4b6:
		return "WERR_BAD_PROFILE";
		break;
	 case 0x4b7:
		return "WERR_NOT_CONTAINER";
		break;
	 case 0x4b8:
		return "WERR_EXTENDED_ERROR";
		break;
	 case 0x4b9:
		return "WERR_INVALID_GROUPNAME";
		break;
	 case 0x4ba:
		return "WERR_INVALID_COMPUTERNAME";
		break;
	 case 0x4bb:
		return "WERR_INVALID_EVENTNAME";
		break;
	 case 0x4bc:
		return "WERR_INVALID_DOMAINNAME";
		break;
	 case 0x4bd:
		return "WERR_INVALID_SERVICENAME";
		break;
	 case 0x4be:
		return "WERR_INVALID_NETNAME";
		break;
	 case 0x4bf:
		return "WERR_INVALID_SHARENAME";
		break;
	 case 0x4c0:
		return "WERR_INVALID_PASSWORDNAME";
		break;
	 case 0x4c1:
		return "WERR_INVALID_MESSAGENAME";
		break;
	 case 0x4c2:
		return "WERR_INVALID_MESSAGEDEST";
		break;
	 case 0x4c3:
		return "WERR_SESSION_CREDENTIAL_CONFLICT";
		break;
	 case 0x4c4:
		return "WERR_REMOTE_SESSION_LIMIT_EXCEEDED";
		break;
	 case 0x4c5:
		return "WERR_DUP_DOMAINNAME";
		break;
	 case 0x4c6:
		return "WERR_NO_NETWORK";
		break;
	 case 0x4c7:
		return "WERR_CANCELLED";
		break;
	 case 0x4c8:
		return "WERR_USER_MAPPED_FILE";
		break;
	 case 0x4c9:
		return "WERR_CONNECTION_REFUSED";
		break;
	 case 0x4ca:
		return "WERR_GRACEFUL_DISCONNECT";
		break;
	 case 0x4cb:
		return "WERR_ADDRESS_ALREADY_ASSOCIATED";
		break;
	 case 0x4cc:
		return "WERR_ADDRESS_NOT_ASSOCIATED";
		break;
	 case 0x4cd:
		return "WERR_CONNECTION_INVALID";
		break;
	 case 0x4ce:
		return "WERR_CONNECTION_ACTIVE";
		break;
	 case 0x4cf:
		return "WERR_NETWORK_UNREACHABLE";
		break;
	 case 0x4d0:
		return "WERR_HOST_UNREACHABLE";
		break;
	 case 0x4d1:
		return "WERR_PROTOCOL_UNREACHABLE";
		break;
	 case 0x4d2:
		return "WERR_PORT_UNREACHABLE";
		break;
	 case 0x4d3:
		return "WERR_REQUEST_ABORTED";
		break;
	 case 0x4d4:
		return "WERR_CONNECTION_ABORTED";
		break;
	 case 0x4d5:
		return "WERR_RETRY";
		break;
	 case 0x4d6:
		return "WERR_CONNECTION_COUNT_LIMIT";
		break;
	 case 0x4d7:
		return "WERR_LOGIN_TIME_RESTRICTION";
		break;
	 case 0x4d8:
		return "WERR_LOGIN_WKSTA_RESTRICTION";
		break;
	 case 0x4d9:
		return "WERR_INCORRECT_ADDRESS";
		break;
	 case 0x4da:
		return "WERR_ALREADY_REGISTERED";
		break;
	 case 0x4db:
		return "WERR_SERVICE_NOT_FOUND";
		break;
	 case 0x4dc:
		return "WERR_NOT_AUTHENTICATED";
		break;
	 case 0x4dd:
		return "WERR_NOT_LOGGED_ON";
		break;
	 case 0x4de:
		return "WERR_CONTINUE";
		break;
	 case 0x4df:
		return "WERR_ALREADY_INITIALIZED";
		break;
	 case 0x4e0:
		return "WERR_NO_MORE_DEVICES";
		break;
	 case 0x4e1:
		return "WERR_NO_SUCH_SITE";
		break;
	 case 0x4e2:
		return "WERR_DOMAIN_CONTROLLER_EXISTS";
		break;
	 case 0x4e3:
		return "WERR_ONLY_IF_CONNECTED";
		break;
	 case 0x4e4:
		return "WERR_OVERRIDE_NOCHANGES";
		break;
	 case 0x4e5:
		return "WERR_BAD_USER_PROFILE";
		break;
	 case 0x4e6:
		return "WERR_NOT_SUPPORTED_ON_SBS";
		break;
	 case 0x4e7:
		return "WERR_SERVER_SHUTDOWN_IN_PROGRESS";
		break;
	 case 0x4e8:
		return "WERR_HOST_DOWN";
		break;
	 case 0x4e9:
		return "WERR_NON_ACCOUNT_SID";
		break;
	 case 0x4ea:
		return "WERR_NON_DOMAIN_SID";
		break;
	 case 0x4eb:
		return "WERR_APPHELP_BLOCK";
		break;
	 case 0x4ec:
		return "WERR_ACCESS_DISABLED_BY_POLICY";
		break;
	 case 0x4ed:
		return "WERR_REG_NAT_CONSUMPTION";
		break;
	 case 0x4ee:
		return "WERR_CSCSHARE_OFFLINE";
		break;
	 case 0x4ef:
		return "WERR_PKINIT_FAILURE";
		break;
	 case 0x4f0:
		return "WERR_SMARTCARD_SUBSYSTEM_FAILURE";
		break;
	 case 0x4f1:
		return "WERR_DOWNGRADE_DETECTED";
		break;
	 case 0x4f7:
		return "WERR_MACHINE_LOCKED";
		break;
	 case 0x4f9:
		return "WERR_CALLBACK_SUPPLIED_INVALID_DATA";
		break;
	 case 0x4fa:
		return "WERR_SYNC_FOREGROUND_REFRESH_REQUIRED";
		break;
	 case 0x4fb:
		return "WERR_DRIVER_BLOCKED";
		break;
	 case 0x4fc:
		return "WERR_INVALID_IMPORT_OF_NON_DLL";
		break;
	 case 0x4fd:
		return "WERR_ACCESS_DISABLED_WEBBLADE";
		break;
	 case 0x4fe:
		return "WERR_ACCESS_DISABLED_WEBBLADE_TAMPER";
		break;
	 case 0x4ff:
		return "WERR_RECOVERY_FAILURE";
		break;
	 case 0x500:
		return "WERR_ALREADY_FIBER";
		break;
	 case 0x501:
		return "WERR_ALREADY_THREAD";
		break;
	 case 0x502:
		return "WERR_STACK_BUFFER_OVERRUN";
		break;
	 case 0x503:
		return "WERR_PARAMETER_QUOTA_EXCEEDED";
		break;
	 case 0x504:
		return "WERR_DEBUGGER_INACTIVE";
		break;
	 case 0x505:
		return "WERR_DELAY_LOAD_FAILED";
		break;
	 case 0x506:
		return "WERR_VDM_DISALLOWED";
		break;
	 case 0x507:
		return "WERR_UNIDENTIFIED_ERROR";
		break;
	 case 0x508:
		return "WERR_INVALID_CRUNTIME_PARAMETER";
		break;
	 case 0x509:
		return "WERR_BEYOND_VDL";
		break;
	 case 0x50a:
		return "WERR_INCOMPATIBLE_SERVICE_SID_TYPE";
		break;
	 case 0x50b:
		return "WERR_DRIVER_PROCESS_TERMINATED";
		break;
	 case 0x50c:
		return "WERR_IMPLEMENTATION_LIMIT";
		break;
	 case 0x50d:
		return "WERR_PROCESS_IS_PROTECTED";
		break;
	 case 0x50e:
		return "WERR_SERVICE_NOTIFY_CLIENT_LAGGING";
		break;
	 case 0x50f:
		return "WERR_DISK_QUOTA_EXCEEDED";
		break;
	 case 0x510:
		return "WERR_CONTENT_BLOCKED";
		break;
	 case 0x511:
		return "WERR_INCOMPATIBLE_SERVICE_PRIVILEGE";
		break;
	 case 0x513:
		return "WERR_INVALID_LABEL";
		break;
	 case 0x514:
		return "WERR_NOT_ALL_ASSIGNED";
		break;
	 case 0x515:
		return "WERR_SOME_NOT_MAPPED";
		break;
	 case 0x516:
		return "WERR_NO_QUOTAS_FOR_ACCOUNT";
		break;
	 case 0x517:
		return "WERR_LOCAL_USER_SESSION_KEY";
		break;
	 case 0x518:
		return "WERR_NULL_LM_PASSWORD";
		break;
	 case 0x519:
		return "WERR_UNKNOWN_REVISION";
		break;
	 case 0x51a:
		return "WERR_REVISION_MISMATCH";
		break;
	 case 0x51b:
		return "WERR_INVALID_OWNER";
		break;
	 case 0x51d:
		return "WERR_NO_IMPERSONATION_TOKEN";
		break;
	 case 0x51e:
		return "WERR_CANT_DISABLE_MANDATORY";
		break;
	 case 0x51f:
		return "WERR_NO_LOGON_SERVERS";
		break;
	 case 0x520:
		return "WERR_NO_SUCH_LOGON_SESSION";
		break;
	 case 0x521:
		return "WERR_NO_SUCH_PRIVILEGE";
		break;
	 case 0x522:
		return "WERR_PRIVILEGE_NOT_HELD";
		break;
	 case 0x523:
		return "WERR_INVALID_ACCOUNT_NAME";
		break;
	 case 0x524:
		return "WERR_USER_EXISTS";
		break;
	 case 0x525:
		return "WERR_NO_SUCH_USER";
		break;
	 case 0x526:
		return "WERR_GROUP_EXISTS";
		break;
	 case 0x527:
		return "WERR_NO_SUCH_GROUP";
		break;
	 case 0x528:
		return "WERR_MEMBER_IN_GROUP";
		break;
	 case 0x529:
		return "WERR_MEMBER_NOT_IN_GROUP";
		break;
	 case 0x52a:
		return "WERR_LAST_ADMIN";
		break;
	 case 0x52b:
		return "WERR_WRONG_PASSWORD";
		break;
	 case 0x52c:
		return "WERR_ILL_FORMED_PASSWORD";
		break;
	 case 0x52d:
		return "WERR_PASSWORD_RESTRICTION";
		break;
	 case 0x52e:
		return "WERR_LOGON_FAILURE";
		break;
	 case 0x52f:
		return "WERR_ACCOUNT_RESTRICTION";
		break;
	 case 0x530:
		return "WERR_INVALID_LOGON_HOURS";
		break;
	 case 0x531:
		return "WERR_INVALID_WORKSTATION";
		break;
	 case 0x532:
		return "WERR_PASSWORD_EXPIRED";
		break;
	 case 0x533:
		return "WERR_ACCOUNT_DISABLED";
		break;
	 case 0x534:
		return "WERR_NONE_MAPPED";
		break;
	 case 0x535:
		return "WERR_TOO_MANY_LUIDS_REQUESTED";
		break;
	 case 0x536:
		return "WERR_LUIDS_EXHAUSTED";
		break;
	 case 0x537:
		return "WERR_INVALID_SUB_AUTHORITY";
		break;
	 case 0x538:
		return "WERR_INVALID_ACL";
		break;
	 case 0x539:
		return "WERR_INVALID_SID";
		break;
	 case 0x53a:
		return "WERR_INVALID_SECURITY_DESCR";
		break;
	 case 0x53c:
		return "WERR_BAD_INHERITANCE_ACL";
		break;
	 case 0x53d:
		return "WERR_SERVER_DISABLED";
		break;
	 case 0x53e:
		return "WERR_SERVER_NOT_DISABLED";
		break;
	 case 0x53f:
		return "WERR_INVALID_ID_AUTHORITY";
		break;
	 case 0x540:
		return "WERR_ALLOTTED_SPACE_EXCEEDED";
		break;
	 case 0x541:
		return "WERR_INVALID_GROUP_ATTRIBUTES";
		break;
	 case 0x542:
		return "WERR_BAD_IMPERSONATION_LEVEL";
		break;
	 case 0x543:
		return "WERR_CANT_OPEN_ANONYMOUS";
		break;
	 case 0x544:
		return "WERR_BAD_VALIDATION_CLASS";
		break;
	 case 0x545:
		return "WERR_BAD_TOKEN_TYPE";
		break;
	 case 0x546:
		return "WERR_NO_SECURITY_ON_OBJECT";
		break;
	 case 0x547:
		return "WERR_CANT_ACCESS_DOMAIN_INFO";
		break;
	 case 0x548:
		return "WERR_INVALID_SERVER_STATE";
		break;
	 case 0x549:
		return "WERR_INVALID_DOMAIN_STATE";
		break;
	 case 0x54a:
		return "WERR_INVALID_DOMAIN_ROLE";
		break;
	 case 0x54b:
		return "WERR_NO_SUCH_DOMAIN";
		break;
	 case 0x54c:
		return "WERR_DOMAIN_EXISTS";
		break;
	 case 0x54d:
		return "WERR_DOMAIN_LIMIT_EXCEEDED";
		break;
	 case 0x54e:
		return "WERR_INTERNAL_DB_CORRUPTION";
		break;
	 case 0x54f:
		return "WERR_INTERNAL_ERROR";
		break;
	 case 0x550:
		return "WERR_GENERIC_NOT_MAPPED";
		break;
	 case 0x551:
		return "WERR_BAD_DESCRIPTOR_FORMAT";
		break;
	 case 0x552:
		return "WERR_NOT_LOGON_PROCESS";
		break;
	 case 0x553:
		return "WERR_LOGON_SESSION_EXISTS";
		break;
	 case 0x554:
		return "WERR_NO_SUCH_PACKAGE";
		break;
	 case 0x555:
		return "WERR_BAD_LOGON_SESSION_STATE";
		break;
	 case 0x556:
		return "WERR_LOGON_SESSION_COLLISION";
		break;
	 case 0x557:
		return "WERR_INVALID_LOGON_TYPE";
		break;
	 case 0x558:
		return "WERR_CANNOT_IMPERSONATE";
		break;
	 case 0x559:
		return "WERR_RXACT_INVALID_STATE";
		break;
	 case 0x55a:
		return "WERR_RXACT_COMMIT_FAILURE";
		break;
	 case 0x55b:
		return "WERR_SPECIAL_ACCOUNT";
		break;
	 case 0x55c:
		return "WERR_SPECIAL_GROUP";
		break;
	 case 0x55d:
		return "WERR_SPECIAL_USER";
		break;
	 case 0x55e:
		return "WERR_MEMBERS_PRIMARY_GROUP";
		break;
	 case 0x55f:
		return "WERR_TOKEN_ALREADY_IN_USE";
		break;
	 case 0x560:
		return "WERR_NO_SUCH_ALIAS";
		break;
	 case 0x561:
		return "WERR_MEMBER_NOT_IN_ALIAS";
		break;
	 case 0x562:
		return "WERR_MEMBER_IN_ALIAS";
		break;
	 case 0x563:
		return "WERR_ALIAS_EXISTS";
		break;
	 case 0x564:
		return "WERR_LOGON_NOT_GRANTED";
		break;
	 case 0x565:
		return "WERR_TOO_MANY_SECRETS";
		break;
	 case 0x566:
		return "WERR_SECRET_TOO_LONG";
		break;
	 case 0x567:
		return "WERR_INTERNAL_DB_ERROR";
		break;
	 case 0x568:
		return "WERR_TOO_MANY_CONTEXT_IDS";
		break;
	 case 0x569:
		return "WERR_LOGON_TYPE_NOT_GRANTED";
		break;
	 case 0x56a:
		return "WERR_NT_CROSS_ENCRYPTION_REQUIRED";
		break;
	 case 0x56b:
		return "WERR_NO_SUCH_MEMBER";
		break;
	 case 0x56c:
		return "WERR_INVALID_MEMBER";
		break;
	 case 0x56d:
		return "WERR_TOO_MANY_SIDS";
		break;
	 case 0x56e:
		return "WERR_LM_CROSS_ENCRYPTION_REQUIRED";
		break;
	 case 0x56f:
		return "WERR_NO_INHERITANCE";
		break;
	 case 0x570:
		return "WERR_FILE_CORRUPT";
		break;
	 case 0x571:
		return "WERR_DISK_CORRUPT";
		break;
	 case 0x572:
		return "WERR_NO_USER_SESSION_KEY";
		break;
	 case 0x573:
		return "WERR_LICENSE_QUOTA_EXCEEDED";
		break;
	 case 0x574:
		return "WERR_WRONG_TARGET_NAME";
		break;
	 case 0x575:
		return "WERR_MUTUAL_AUTH_FAILED";
		break;
	 case 0x576:
		return "WERR_TIME_SKEW";
		break;
	 case 0x577:
		return "WERR_CURRENT_DOMAIN_NOT_ALLOWED";
		break;
	 case 0x578:
		return "WERR_INVALID_WINDOW_HANDLE";
		break;
	 case 0x579:
		return "WERR_INVALID_MENU_HANDLE";
		break;
	 case 0x57a:
		return "WERR_INVALID_CURSOR_HANDLE";
		break;
	 case 0x57b:
		return "WERR_INVALID_ACCEL_HANDLE";
		break;
	 case 0x57c:
		return "WERR_INVALID_HOOK_HANDLE";
		break;
	 case 0x57d:
		return "WERR_INVALID_DWP_HANDLE";
		break;
	 case 0x57e:
		return "WERR_TLW_WITH_WSCHILD";
		break;
	 case 0x57f:
		return "WERR_CANNOT_FIND_WND_CLASS";
		break;
	 case 0x580:
		return "WERR_WINDOW_OF_OTHER_THREAD";
		break;
	 case 0x581:
		return "WERR_HOTKEY_ALREADY_REGISTERED";
		break;
	 case 0x582:
		return "WERR_CLASS_ALREADY_EXISTS";
		break;
	 case 0x583:
		return "WERR_CLASS_DOES_NOT_EXIST";
		break;
	 case 0x584:
		return "WERR_CLASS_HAS_WINDOWS";
		break;
	 case 0x585:
		return "WERR_INVALID_INDEX";
		break;
	 case 0x586:
		return "WERR_INVALID_ICON_HANDLE";
		break;
	 case 0x587:
		return "WERR_PRIVATE_DIALOG_INDEX";
		break;
	 case 0x588:
		return "WERR_LISTBOX_ID_NOT_FOUND";
		break;
	 case 0x589:
		return "WERR_NO_WILDCARD_CHARACTERS";
		break;
	 case 0x58a:
		return "WERR_CLIPBOARD_NOT_OPEN";
		break;
	 case 0x58b:
		return "WERR_HOTKEY_NOT_REGISTERED";
		break;
	 case 0x58c:
		return "WERR_WINDOW_NOT_DIALOG";
		break;
	 case 0x58d:
		return "WERR_CONTROL_ID_NOT_FOUND";
		break;
	 case 0x58e:
		return "WERR_INVALID_COMBOBOX_MESSAGE";
		break;
	 case 0x58f:
		return "WERR_WINDOW_NOT_COMBOBOX";
		break;
	 case 0x590:
		return "WERR_INVALID_EDIT_HEIGHT";
		break;
	 case 0x591:
		return "WERR_DC_NOT_FOUND";
		break;
	 case 0x592:
		return "WERR_INVALID_HOOK_FILTER";
		break;
	 case 0x593:
		return "WERR_INVALID_FILTER_PROC";
		break;
	 case 0x594:
		return "WERR_HOOK_NEEDS_HMOD";
		break;
	 case 0x595:
		return "WERR_GLOBAL_ONLY_HOOK";
		break;
	 case 0x596:
		return "WERR_JOURNAL_HOOK_SET";
		break;
	 case 0x597:
		return "WERR_HOOK_NOT_INSTALLED";
		break;
	 case 0x598:
		return "WERR_INVALID_LB_MESSAGE";
		break;
	 case 0x599:
		return "WERR_SETCOUNT_ON_BAD_LB";
		break;
	 case 0x59a:
		return "WERR_LB_WITHOUT_TABSTOPS";
		break;
	 case 0x59b:
		return "WERR_DESTROY_OBJECT_OF_OTHER_THREAD";
		break;
	 case 0x59c:
		return "WERR_CHILD_WINDOW_MENU";
		break;
	 case 0x59d:
		return "WERR_NO_SYSTEM_MENU";
		break;
	 case 0x59e:
		return "WERR_INVALID_MSGBOX_STYLE";
		break;
	 case 0x59f:
		return "WERR_INVALID_SPI_VALUE";
		break;
	 case 0x5a0:
		return "WERR_SCREEN_ALREADY_LOCKED";
		break;
	 case 0x5a1:
		return "WERR_HWNDS_HAVE_DIFF_PARENT";
		break;
	 case 0x5a2:
		return "WERR_NOT_CHILD_WINDOW";
		break;
	 case 0x5a3:
		return "WERR_INVALID_GW_COMMAND";
		break;
	 case 0x5a4:
		return "WERR_INVALID_THREAD_ID";
		break;
	 case 0x5a5:
		return "WERR_NON_MDICHILD_WINDOW";
		break;
	 case 0x5a6:
		return "WERR_POPUP_ALREADY_ACTIVE";
		break;
	 case 0x5a7:
		return "WERR_NO_SCROLLBARS";
		break;
	 case 0x5a8:
		return "WERR_INVALID_SCROLLBAR_RANGE";
		break;
	 case 0x5a9:
		return "WERR_INVALID_SHOWWIN_COMMAND";
		break;
	 case 0x5aa:
		return "WERR_NO_SYSTEM_RESOURCES";
		break;
	 case 0x5ab:
		return "WERR_NONPAGED_SYSTEM_RESOURCES";
		break;
	 case 0x5ac:
		return "WERR_PAGED_SYSTEM_RESOURCES";
		break;
	 case 0x5ad:
		return "WERR_WORKING_SET_QUOTA";
		break;
	 case 0x5ae:
		return "WERR_PAGEFILE_QUOTA";
		break;
	 case 0x5af:
		return "WERR_COMMITMENT_LIMIT";
		break;
	 case 0x5b0:
		return "WERR_MENU_ITEM_NOT_FOUND";
		break;
	 case 0x5b1:
		return "WERR_INVALID_KEYBOARD_HANDLE";
		break;
	 case 0x5b2:
		return "WERR_HOOK_TYPE_NOT_ALLOWED";
		break;
	 case 0x5b3:
		return "WERR_REQUIRES_INTERACTIVE_WINDOWSTATION";
		break;
	 case 0x5b4:
		return "WERR_TIMEOUT";
		break;
	 case 0x5b5:
		return "WERR_INVALID_MONITOR_HANDLE";
		break;
	 case 0x5b6:
		return "WERR_INCORRECT_SIZE";
		break;
	 case 0x5b7:
		return "WERR_SYMLINK_CLASS_DISABLED";
		break;
	 case 0x5b8:
		return "WERR_SYMLINK_NOT_SUPPORTED";
		break;
	 case 0x5dc:
		return "WERR_EVENTLOG_FILE_CORRUPT";
		break;
	 case 0x5dd:
		return "WERR_EVENTLOG_CANT_START";
		break;
	 case 0x5de:
		return "WERR_LOG_FILE_FULL";
		break;
	 case 0x5df:
		return "WERR_EVENTLOG_FILE_CHANGED";
		break;
	 case 0x60e:
		return "WERR_INVALID_TASK_NAME";
		break;
	 case 0x60f:
		return "WERR_INVALID_TASK_INDEX";
		break;
	 case 0x610:
		return "WERR_THREAD_ALREADY_IN_TASK";
		break;
	 case 0x641:
		return "WERR_INSTALL_SERVICE_FAILURE";
		break;
	 case 0x642:
		return "WERR_INSTALL_USEREXIT";
		break;
	 case 0x643:
		return "WERR_INSTALL_FAILURE";
		break;
	 case 0x644:
		return "WERR_INSTALL_SUSPEND";
		break;
	 case 0x645:
		return "WERR_UNKNOWN_PRODUCT";
		break;
	 case 0x646:
		return "WERR_UNKNOWN_FEATURE";
		break;
	 case 0x647:
		return "WERR_UNKNOWN_COMPONENT";
		break;
	 case 0x648:
		return "WERR_UNKNOWN_PROPERTY";
		break;
	 case 0x649:
		return "WERR_INVALID_HANDLE_STATE";
		break;
	 case 0x64a:
		return "WERR_BAD_CONFIGURATION";
		break;
	 case 0x64b:
		return "WERR_INDEX_ABSENT";
		break;
	 case 0x64c:
		return "WERR_INSTALL_SOURCE_ABSENT";
		break;
	 case 0x64d:
		return "WERR_INSTALL_PACKAGE_VERSION";
		break;
	 case 0x64e:
		return "WERR_PRODUCT_UNINSTALLED";
		break;
	 case 0x64f:
		return "WERR_BAD_QUERY_SYNTAX";
		break;
	 case 0x650:
		return "WERR_INVALID_FIELD";
		break;
	 case 0x651:
		return "WERR_DEVICE_REMOVED";
		break;
	 case 0x652:
		return "WERR_INSTALL_ALREADY_RUNNING";
		break;
	 case 0x653:
		return "WERR_INSTALL_PACKAGE_OPEN_FAILED";
		break;
	 case 0x654:
		return "WERR_INSTALL_PACKAGE_INVALID";
		break;
	 case 0x655:
		return "WERR_INSTALL_UI_FAILURE";
		break;
	 case 0x656:
		return "WERR_INSTALL_LOG_FAILURE";
		break;
	 case 0x657:
		return "WERR_INSTALL_LANGUAGE_UNSUPPORTED";
		break;
	 case 0x658:
		return "WERR_INSTALL_TRANSFORM_FAILURE";
		break;
	 case 0x659:
		return "WERR_INSTALL_PACKAGE_REJECTED";
		break;
	 case 0x65a:
		return "WERR_FUNCTION_NOT_CALLED";
		break;
	 case 0x65b:
		return "WERR_FUNCTION_FAILED";
		break;
	 case 0x65c:
		return "WERR_INVALID_TABLE";
		break;
	 case 0x65d:
		return "WERR_DATATYPE_MISMATCH";
		break;
	 case 0x65e:
		return "WERR_UNSUPPORTED_TYPE";
		break;
	 case 0x65f:
		return "WERR_CREATE_FAILED";
		break;
	 case 0x660:
		return "WERR_INSTALL_TEMP_UNWRITABLE";
		break;
	 case 0x661:
		return "WERR_INSTALL_PLATFORM_UNSUPPORTED";
		break;
	 case 0x662:
		return "WERR_INSTALL_NOTUSED";
		break;
	 case 0x663:
		return "WERR_PATCH_PACKAGE_OPEN_FAILED";
		break;
	 case 0x664:
		return "WERR_PATCH_PACKAGE_INVALID";
		break;
	 case 0x665:
		return "WERR_PATCH_PACKAGE_UNSUPPORTED";
		break;
	 case 0x666:
		return "WERR_PRODUCT_VERSION";
		break;
	 case 0x667:
		return "WERR_INVALID_COMMAND_LINE";
		break;
	 case 0x668:
		return "WERR_INSTALL_REMOTE_DISALLOWED";
		break;
	 case 0x669:
		return "WERR_SUCCESS_REBOOT_INITIATED";
		break;
	 case 0x66a:
		return "WERR_PATCH_TARGET_NOT_FOUND";
		break;
	 case 0x66b:
		return "WERR_PATCH_PACKAGE_REJECTED";
		break;
	 case 0x66c:
		return "WERR_INSTALL_TRANSFORM_REJECTED";
		break;
	 case 0x66d:
		return "WERR_INSTALL_REMOTE_PROHIBITED";
		break;
	 case 0x66e:
		return "WERR_PATCH_REMOVAL_UNSUPPORTED";
		break;
	 case 0x66f:
		return "WERR_UNKNOWN_PATCH";
		break;
	 case 0x670:
		return "WERR_PATCH_NO_SEQUENCE";
		break;
	 case 0x671:
		return "WERR_PATCH_REMOVAL_DISALLOWED";
		break;
	 case 0x672:
		return "WERR_INVALID_PATCH_XML";
		break;
	 case 0x673:
		return "WERR_PATCH_MANAGED_ADVERTISED_PRODUCT";
		break;
	 case 0x674:
		return "WERR_INSTALL_SERVICE_SAFEBOOT";
		break;
	 case 0x6a4:
		return "WERR_RPC_S_INVALID_STRING_BINDING";
		break;
	 case 0x6a5:
		return "WERR_RPC_S_WRONG_KIND_OF_BINDING";
		break;
	 case 0x6a6:
		return "WERR_RPC_S_INVALID_BINDING";
		break;
	 case 0x6a7:
		return "WERR_RPC_S_PROTSEQ_NOT_SUPPORTED";
		break;
	 case 0x6a8:
		return "WERR_RPC_S_INVALID_RPC_PROTSEQ";
		break;
	 case 0x6a9:
		return "WERR_RPC_S_INVALID_STRING_UUID";
		break;
	 case 0x6aa:
		return "WERR_RPC_S_INVALID_ENDPOINT_FORMAT";
		break;
	 case 0x6ab:
		return "WERR_RPC_S_INVALID_NET_ADDR";
		break;
	 case 0x6ac:
		return "WERR_RPC_S_NO_ENDPOINT_FOUND";
		break;
	 case 0x6ad:
		return "WERR_RPC_S_INVALID_TIMEOUT";
		break;
	 case 0x6ae:
		return "WERR_RPC_S_OBJECT_NOT_FOUND";
		break;
	 case 0x6af:
		return "WERR_RPC_S_ALREADY_REGISTERED";
		break;
	 case 0x6b0:
		return "WERR_RPC_S_TYPE_ALREADY_REGISTERED";
		break;
	 case 0x6b1:
		return "WERR_RPC_S_ALREADY_LISTENING";
		break;
	 case 0x6b2:
		return "WERR_RPC_S_NO_PROTSEQS_REGISTERED";
		break;
	 case 0x6b3:
		return "WERR_RPC_S_NOT_LISTENING";
		break;
	 case 0x6b4:
		return "WERR_RPC_S_UNKNOWN_MGR_TYPE";
		break;
	 case 0x6b5:
		return "WERR_RPC_S_UNKNOWN_IF";
		break;
	 case 0x6b6:
		return "WERR_RPC_S_NO_BINDINGS";
		break;
	 case 0x6b7:
		return "WERR_RPC_S_NO_PROTSEQS";
		break;
	 case 0x6b8:
		return "WERR_RPC_S_CANT_CREATE_ENDPOINT";
		break;
	 case 0x6b9:
		return "WERR_RPC_S_OUT_OF_RESOURCES";
		break;
	 case 0x6ba:
		return "WERR_RPC_S_SERVER_UNAVAILABLE";
		break;
	 case 0x6bb:
		return "WERR_RPC_S_SERVER_TOO_BUSY";
		break;
	 case 0x6bc:
		return "WERR_RPC_S_INVALID_NETWORK_OPTIONS";
		break;
	 case 0x6bd:
		return "WERR_RPC_S_NO_CALL_ACTIVE";
		break;
	 case 0x6be:
		return "WERR_RPC_S_CALL_FAILED";
		break;
	 case 0x6bf:
		return "WERR_RPC_S_CALL_FAILED_DNE";
		break;
	 case 0x6c0:
		return "WERR_RPC_S_PROTOCOL_ERROR";
		break;
	 case 0x6c1:
		return "WERR_RPC_S_PROXY_ACCESS_DENIED";
		break;
	 case 0x6c2:
		return "WERR_RPC_S_UNSUPPORTED_TRANS_SYN";
		break;
	 case 0x6c4:
		return "WERR_RPC_S_UNSUPPORTED_TYPE";
		break;
	 case 0x6c5:
		return "WERR_RPC_S_INVALID_TAG";
		break;
	 case 0x6c6:
		return "WERR_RPC_S_INVALID_BOUND";
		break;
	 case 0x6c7:
		return "WERR_RPC_S_NO_ENTRY_NAME";
		break;
	 case 0x6c8:
		return "WERR_RPC_S_INVALID_NAME_SYNTAX";
		break;
	 case 0x6c9:
		return "WERR_RPC_S_UNSUPPORTED_NAME_SYNTAX";
		break;
	 case 0x6cb:
		return "WERR_RPC_S_UUID_NO_ADDRESS";
		break;
	 case 0x6cc:
		return "WERR_RPC_S_DUPLICATE_ENDPOINT";
		break;
	 case 0x6cd:
		return "WERR_RPC_S_UNKNOWN_AUTHN_TYPE";
		break;
	 case 0x6ce:
		return "WERR_RPC_S_MAX_CALLS_TOO_SMALL";
		break;
	 case 0x6cf:
		return "WERR_RPC_S_STRING_TOO_LONG";
		break;
	 case 0x6d0:
		return "WERR_RPC_S_PROTSEQ_NOT_FOUND";
		break;
	 case 0x6d1:
		return "WERR_RPC_S_PROCNUM_OUT_OF_RANGE";
		break;
	 case 0x6d2:
		return "WERR_RPC_S_BINDING_HAS_NO_AUTH";
		break;
	 case 0x6d3:
		return "WERR_RPC_S_UNKNOWN_AUTHN_SERVICE";
		break;
	 case 0x6d4:
		return "WERR_RPC_S_UNKNOWN_AUTHN_LEVEL";
		break;
	 case 0x6d5:
		return "WERR_RPC_S_INVALID_AUTH_IDENTITY";
		break;
	 case 0x6d6:
		return "WERR_RPC_S_UNKNOWN_AUTHZ_SERVICE";
		break;
	 case 0x6d7:
		return "WERR_EPT_S_INVALID_ENTRY";
		break;
	 case 0x6d8:
		return "WERR_EPT_S_CANT_PERFORM_OP";
		break;
	 case 0x6d9:
		return "WERR_EPT_S_NOT_REGISTERED";
		break;
	 case 0x6da:
		return "WERR_RPC_S_NOTHING_TO_EXPORT";
		break;
	 case 0x6db:
		return "WERR_RPC_S_INCOMPLETE_NAME";
		break;
	 case 0x6dc:
		return "WERR_RPC_S_INVALID_VERS_OPTION";
		break;
	 case 0x6dd:
		return "WERR_RPC_S_NO_MORE_MEMBERS";
		break;
	 case 0x6de:
		return "WERR_RPC_S_NOT_ALL_OBJS_UNEXPORTED";
		break;
	 case 0x6df:
		return "WERR_RPC_S_INTERFACE_NOT_FOUND";
		break;
	 case 0x6e0:
		return "WERR_RPC_S_ENTRY_ALREADY_EXISTS";
		break;
	 case 0x6e1:
		return "WERR_RPC_S_ENTRY_NOT_FOUND";
		break;
	 case 0x6e2:
		return "WERR_RPC_S_NAME_SERVICE_UNAVAILABLE";
		break;
	 case 0x6e3:
		return "WERR_RPC_S_INVALID_NAF_ID";
		break;
	 case 0x6e4:
		return "WERR_RPC_S_CANNOT_SUPPORT";
		break;
	 case 0x6e5:
		return "WERR_RPC_S_NO_CONTEXT_AVAILABLE";
		break;
	 case 0x6e6:
		return "WERR_RPC_S_INTERNAL_ERROR";
		break;
	 case 0x6e7:
		return "WERR_RPC_S_ZERO_DIVIDE";
		break;
	 case 0x6e8:
		return "WERR_RPC_S_ADDRESS_ERROR";
		break;
	 case 0x6e9:
		return "WERR_RPC_S_FP_DIV_ZERO";
		break;
	 case 0x6ea:
		return "WERR_RPC_S_FP_UNDERFLOW";
		break;
	 case 0x6eb:
		return "WERR_RPC_S_FP_OVERFLOW";
		break;
	 case 0x6ec:
		return "WERR_RPC_X_NO_MORE_ENTRIES";
		break;
	 case 0x6ed:
		return "WERR_RPC_X_SS_CHAR_TRANS_OPEN_FAIL";
		break;
	 case 0x6ee:
		return "WERR_RPC_X_SS_CHAR_TRANS_SHORT_FILE";
		break;
	 case 0x6ef:
		return "WERR_RPC_X_SS_IN_NULL_CONTEXT";
		break;
	 case 0x6f1:
		return "WERR_RPC_X_SS_CONTEXT_DAMAGED";
		break;
	 case 0x6f2:
		return "WERR_RPC_X_SS_HANDLES_MISMATCH";
		break;
	 case 0x6f3:
		return "WERR_RPC_X_SS_CANNOT_GET_CALL_HANDLE";
		break;
	 case 0x6f4:
		return "WERR_RPC_X_NULL_REF_POINTER";
		break;
	 case 0x6f5:
		return "WERR_RPC_X_ENUM_VALUE_OUT_OF_RANGE";
		break;
	 case 0x6f6:
		return "WERR_RPC_X_BYTE_COUNT_TOO_SMALL";
		break;
	 case 0x6f7:
		return "WERR_RPC_X_BAD_STUB_DATA";
		break;
	 case 0x6f8:
		return "WERR_INVALID_USER_BUFFER";
		break;
	 case 0x6f9:
		return "WERR_UNRECOGNIZED_MEDIA";
		break;
	 case 0x6fa:
		return "WERR_NO_TRUST_LSA_SECRET";
		break;
	 case 0x6fb:
		return "WERR_NO_TRUST_SAM_ACCOUNT";
		break;
	 case 0x6fc:
		return "WERR_TRUSTED_DOMAIN_FAILURE";
		break;
	 case 0x6fd:
		return "WERR_TRUSTED_RELATIONSHIP_FAILURE";
		break;
	 case 0x6fe:
		return "WERR_TRUST_FAILURE";
		break;
	 case 0x6ff:
		return "WERR_RPC_S_CALL_IN_PROGRESS";
		break;
	 case 0x700:
		return "WERR_NETLOGON_NOT_STARTED";
		break;
	 case 0x701:
		return "WERR_ACCOUNT_EXPIRED";
		break;
	 case 0x702:
		return "WERR_REDIRECTOR_HAS_OPEN_HANDLES";
		break;
	 case 0x703:
		return "WERR_PRINTER_DRIVER_ALREADY_INSTALLED";
		break;
	 case 0x704:
		return "WERR_UNKNOWN_PORT";
		break;
	 case 0x705:
		return "WERR_UNKNOWN_PRINTER_DRIVER";
		break;
	 case 0x706:
		return "WERR_UNKNOWN_PRINTPROCESSOR";
		break;
	 case 0x707:
		return "WERR_INVALID_SEPARATOR_FILE";
		break;
	 case 0x708:
		return "WERR_INVALID_PRIORITY";
		break;
	 case 0x709:
		return "WERR_INVALID_PRINTER_NAME";
		break;
	 case 0x70a:
		return "WERR_PRINTER_ALREADY_EXISTS";
		break;
	 case 0x70b:
		return "WERR_INVALID_PRINTER_COMMAND";
		break;
	 case 0x70c:
		return "WERR_INVALID_DATATYPE";
		break;
	 case 0x70d:
		return "WERR_INVALID_ENVIRONMENT";
		break;
	 case 0x70e:
		return "WERR_RPC_S_NO_MORE_BINDINGS";
		break;
	 case 0x70f:
		return "WERR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT";
		break;
	 case 0x710:
		return "WERR_NOLOGON_WORKSTATION_TRUST_ACCOUNT";
		break;
	 case 0x711:
		return "WERR_NOLOGON_SERVER_TRUST_ACCOUNT";
		break;
	 case 0x712:
		return "WERR_DOMAIN_TRUST_INCONSISTENT";
		break;
	 case 0x713:
		return "WERR_SERVER_HAS_OPEN_HANDLES";
		break;
	 case 0x714:
		return "WERR_RESOURCE_DATA_NOT_FOUND";
		break;
	 case 0x715:
		return "WERR_RESOURCE_TYPE_NOT_FOUND";
		break;
	 case 0x716:
		return "WERR_RESOURCE_NAME_NOT_FOUND";
		break;
	 case 0x717:
		return "WERR_RESOURCE_LANG_NOT_FOUND";
		break;
	 case 0x718:
		return "WERR_NOT_ENOUGH_QUOTA";
		break;
	 case 0x719:
		return "WERR_RPC_S_NO_INTERFACES";
		break;
	 case 0x71a:
		return "WERR_RPC_S_CALL_CANCELLED";
		break;
	 case 0x71b:
		return "WERR_RPC_S_BINDING_INCOMPLETE";
		break;
	 case 0x71c:
		return "WERR_RPC_S_COMM_FAILURE";
		break;
	 case 0x71d:
		return "WERR_RPC_S_UNSUPPORTED_AUTHN_LEVEL";
		break;
	 case 0x71e:
		return "WERR_RPC_S_NO_PRINC_NAME";
		break;
	 case 0x71f:
		return "WERR_RPC_S_NOT_RPC_ERROR";
		break;
	 case 0x720:
		return "WERR_RPC_S_UUID_LOCAL_ONLY";
		break;
	 case 0x721:
		return "WERR_RPC_S_SEC_PKG_ERROR";
		break;
	 case 0x722:
		return "WERR_RPC_S_NOT_CANCELLED";
		break;
	 case 0x723:
		return "WERR_RPC_X_INVALID_ES_ACTION";
		break;
	 case 0x724:
		return "WERR_RPC_X_WRONG_ES_VERSION";
		break;
	 case 0x725:
		return "WERR_RPC_X_WRONG_STUB_VERSION";
		break;
	 case 0x726:
		return "WERR_RPC_X_INVALID_PIPE_OBJECT";
		break;
	 case 0x727:
		return "WERR_RPC_X_WRONG_PIPE_ORDER";
		break;
	 case 0x728:
		return "WERR_RPC_X_WRONG_PIPE_VERSION";
		break;
	 case 0x76a:
		return "WERR_RPC_S_GROUP_MEMBER_NOT_FOUND";
		break;
	 case 0x76b:
		return "WERR_EPT_S_CANT_CREATE";
		break;
	 case 0x76c:
		return "WERR_RPC_S_INVALID_OBJECT";
		break;
	 case 0x76d:
		return "WERR_INVALID_TIME";
		break;
	 case 0x76e:
		return "WERR_INVALID_FORM_NAME";
		break;
	 case 0x76f:
		return "WERR_INVALID_FORM_SIZE";
		break;
	 case 0x770:
		return "WERR_ALREADY_WAITING";
		break;
	 case 0x771:
		return "WERR_PRINTER_DELETED";
		break;
	 case 0x772:
		return "WERR_INVALID_PRINTER_STATE";
		break;
	 case 0x773:
		return "WERR_PASSWORD_MUST_CHANGE";
		break;
	 case 0x774:
		return "WERR_DOMAIN_CONTROLLER_NOT_FOUND";
		break;
	 case 0x775:
		return "WERR_ACCOUNT_LOCKED_OUT";
		break;
	 case 0x776:
		return "WERR_OR_INVALID_OXID";
		break;
	 case 0x777:
		return "WERR_OR_INVALID_OID";
		break;
	 case 0x778:
		return "WERR_OR_INVALID_SET";
		break;
	 case 0x779:
		return "WERR_RPC_S_SEND_INCOMPLETE";
		break;
	 case 0x77a:
		return "WERR_RPC_S_INVALID_ASYNC_HANDLE";
		break;
	 case 0x77b:
		return "WERR_RPC_S_INVALID_ASYNC_CALL";
		break;
	 case 0x77c:
		return "WERR_RPC_X_PIPE_CLOSED";
		break;
	 case 0x77d:
		return "WERR_RPC_X_PIPE_DISCIPLINE_ERROR";
		break;
	 case 0x77e:
		return "WERR_RPC_X_PIPE_EMPTY";
		break;
	 case 0x77f:
		return "WERR_NO_SITENAME";
		break;
	 case 0x780:
		return "WERR_CANT_ACCESS_FILE";
		break;
	 case 0x781:
		return "WERR_CANT_RESOLVE_FILENAME";
		break;
	 case 0x782:
		return "WERR_RPC_S_ENTRY_TYPE_MISMATCH";
		break;
	 case 0x783:
		return "WERR_RPC_S_NOT_ALL_OBJS_EXPORTED";
		break;
	 case 0x784:
		return "WERR_RPC_S_INTERFACE_NOT_EXPORTED";
		break;
	 case 0x785:
		return "WERR_RPC_S_PROFILE_NOT_ADDED";
		break;
	 case 0x786:
		return "WERR_RPC_S_PRF_ELT_NOT_ADDED";
		break;
	 case 0x787:
		return "WERR_RPC_S_PRF_ELT_NOT_REMOVED";
		break;
	 case 0x788:
		return "WERR_RPC_S_GRP_ELT_NOT_ADDED";
		break;
	 case 0x789:
		return "WERR_RPC_S_GRP_ELT_NOT_REMOVED";
		break;
	 case 0x78a:
		return "WERR_KM_DRIVER_BLOCKED";
		break;
	 case 0x78b:
		return "WERR_CONTEXT_EXPIRED";
		break;
	 case 0x78c:
		return "WERR_PER_USER_TRUST_QUOTA_EXCEEDED";
		break;
	 case 0x78d:
		return "WERR_ALL_USER_TRUST_QUOTA_EXCEEDED";
		break;
	 case 0x78e:
		return "WERR_USER_DELETE_TRUST_QUOTA_EXCEEDED";
		break;
	 case 0x78f:
		return "WERR_AUTHENTICATION_FIREWALL_FAILED";
		break;
	 case 0x790:
		return "WERR_REMOTE_PRINT_CONNECTIONS_BLOCKED";
		break;
	 case 0x7d0:
		return "WERR_INVALID_PIXEL_FORMAT";
		break;
	 case 0x7d1:
		return "WERR_BAD_DRIVER";
		break;
	 case 0x7d2:
		return "WERR_INVALID_WINDOW_STYLE";
		break;
	 case 0x7d3:
		return "WERR_METAFILE_NOT_SUPPORTED";
		break;
	 case 0x7d4:
		return "WERR_TRANSFORM_NOT_SUPPORTED";
		break;
	 case 0x7d5:
		return "WERR_CLIPPING_NOT_SUPPORTED";
		break;
	 case 0x7da:
		return "WERR_INVALID_CMM";
		break;
	 case 0x7db:
		return "WERR_INVALID_PROFILE";
		break;
	 case 0x7dc:
		return "WERR_TAG_NOT_FOUND";
		break;
	 case 0x7dd:
		return "WERR_TAG_NOT_PRESENT";
		break;
	 case 0x7de:
		return "WERR_DUPLICATE_TAG";
		break;
	 case 0x7df:
		return "WERR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE";
		break;
	 case 0x7e0:
		return "WERR_PROFILE_NOT_FOUND";
		break;
	 case 0x7e1:
		return "WERR_INVALID_COLORSPACE";
		break;
	 case 0x7e2:
		return "WERR_ICM_NOT_ENABLED";
		break;
	 case 0x7e3:
		return "WERR_DELETING_ICM_XFORM";
		break;
	 case 0x7e4:
		return "WERR_INVALID_TRANSFORM";
		break;
	 case 0x7e5:
		return "WERR_COLORSPACE_MISMATCH";
		break;
	 case 0x7e6:
		return "WERR_INVALID_COLORINDEX";
		break;
	 case 0x7e7:
		return "WERR_PROFILE_DOES_NOT_MATCH_DEVICE";
		break;
	 case 0x836:
		return "WERR_NERR_NETNOTSTARTED";
		break;
	 case 0x837:
		return "WERR_NERR_UNKNOWNSERVER";
		break;
	 case 0x838:
		return "WERR_NERR_SHAREMEM";
		break;
	 case 0x839:
		return "WERR_NERR_NONETWORKRESOURCE";
		break;
	 case 0x83a:
		return "WERR_NERR_REMOTEONLY";
		break;
	 case 0x83b:
		return "WERR_NERR_DEVNOTREDIRECTED";
		break;
	 case 0x83c:
		return "WERR_CONNECTED_OTHER_PASSWORD";
		break;
	 case 0x83d:
		return "WERR_CONNECTED_OTHER_PASSWORD_DEFAULT";
		break;
	 case 0x842:
		return "WERR_NERR_SERVERNOTSTARTED";
		break;
	 case 0x843:
		return "WERR_NERR_ITEMNOTFOUND";
		break;
	 case 0x844:
		return "WERR_NERR_UNKNOWNDEVDIR";
		break;
	 case 0x845:
		return "WERR_NERR_REDIRECTEDPATH";
		break;
	 case 0x846:
		return "WERR_NERR_DUPLICATESHARE";
		break;
	 case 0x847:
		return "WERR_NERR_NOROOM";
		break;
	 case 0x849:
		return "WERR_NERR_TOOMANYITEMS";
		break;
	 case 0x84a:
		return "WERR_NERR_INVALIDMAXUSERS";
		break;
	 case 0x84b:
		return "WERR_NERR_BUFTOOSMALL";
		break;
	 case 0x84f:
		return "WERR_NERR_REMOTEERR";
		break;
	 case 0x853:
		return "WERR_NERR_LANMANINIERROR";
		break;
	 case 0x858:
		return "WERR_NERR_NETWORKERROR";
		break;
	 case 0x859:
		return "WERR_NERR_WKSTAINCONSISTENTSTATE";
		break;
	 case 0x85a:
		return "WERR_NERR_WKSTANOTSTARTED";
		break;
	 case 0x85b:
		return "WERR_NERR_BROWSERNOTSTARTED";
		break;
	 case 0x85c:
		return "WERR_NERR_INTERNALERROR";
		break;
	 case 0x85d:
		return "WERR_NERR_BADTRANSACTCONFIG";
		break;
	 case 0x85e:
		return "WERR_NERR_INVALIDAPI";
		break;
	 case 0x85f:
		return "WERR_NERR_BADEVENTNAME";
		break;
	 case 0x860:
		return "WERR_NERR_DUPNAMEREBOOT";
		break;
	 case 0x862:
		return "WERR_NERR_CFGCOMPNOTFOUND";
		break;
	 case 0x863:
		return "WERR_NERR_CFGPARAMNOTFOUND";
		break;
	 case 0x865:
		return "WERR_NERR_LINETOOLONG";
		break;
	 case 0x866:
		return "WERR_NERR_QNOTFOUND";
		break;
	 case 0x867:
		return "WERR_NERR_JOBNOTFOUND";
		break;
	 case 0x868:
		return "WERR_NERR_DESTNOTFOUND";
		break;
	 case 0x869:
		return "WERR_NERR_DESTEXISTS";
		break;
	 case 0x86a:
		return "WERR_NERR_QEXISTS";
		break;
	 case 0x86b:
		return "WERR_NERR_QNOROOM";
		break;
	 case 0x86c:
		return "WERR_NERR_JOBNOROOM";
		break;
	 case 0x86d:
		return "WERR_NERR_DESTNOROOM";
		break;
	 case 0x86e:
		return "WERR_NERR_DESTIDLE";
		break;
	 case 0x86f:
		return "WERR_NERR_DESTINVALIDOP";
		break;
	 case 0x870:
		return "WERR_NERR_PROCNORESPOND";
		break;
	 case 0x871:
		return "WERR_NERR_SPOOLERNOTLOADED";
		break;
	 case 0x872:
		return "WERR_NERR_DESTINVALIDSTATE";
		break;
	 case 0x873:
		return "WERR_NERR_QINVALIDSTATE";
		break;
	 case 0x874:
		return "WERR_NERR_JOBINVALIDSTATE";
		break;
	 case 0x875:
		return "WERR_NERR_SPOOLNOMEMORY";
		break;
	 case 0x876:
		return "WERR_NERR_DRIVERNOTFOUND";
		break;
	 case 0x877:
		return "WERR_NERR_DATATYPEINVALID";
		break;
	 case 0x878:
		return "WERR_NERR_PROCNOTFOUND";
		break;
	 case 0x884:
		return "WERR_NERR_SERVICETABLELOCKED";
		break;
	 case 0x885:
		return "WERR_NERR_SERVICETABLEFULL";
		break;
	 case 0x886:
		return "WERR_NERR_SERVICEINSTALLED";
		break;
	 case 0x887:
		return "WERR_NERR_SERVICEENTRYLOCKED";
		break;
	 case 0x888:
		return "WERR_NERR_SERVICENOTINSTALLED";
		break;
	 case 0x889:
		return "WERR_NERR_BADSERVICENAME";
		break;
	 case 0x88a:
		return "WERR_NERR_SERVICECTLTIMEOUT";
		break;
	 case 0x88b:
		return "WERR_NERR_SERVICECTLBUSY";
		break;
	 case 0x88c:
		return "WERR_NERR_BADSERVICEPROGNAME";
		break;
	 case 0x88d:
		return "WERR_NERR_SERVICENOTCTRL";
		break;
	 case 0x88e:
		return "WERR_NERR_SERVICEKILLPROC";
		break;
	 case 0x88f:
		return "WERR_NERR_SERVICECTLNOTVALID";
		break;
	 case 0x890:
		return "WERR_NERR_NOTINDISPATCHTBL";
		break;
	 case 0x891:
		return "WERR_NERR_BADCONTROLRECV";
		break;
	 case 0x892:
		return "WERR_NERR_SERVICENOTSTARTING";
		break;
	 case 0x898:
		return "WERR_NERR_ALREADYLOGGEDON";
		break;
	 case 0x899:
		return "WERR_NERR_NOTLOGGEDON";
		break;
	 case 0x89a:
		return "WERR_NERR_BADUSERNAME";
		break;
	 case 0x89b:
		return "WERR_NERR_BADPASSWORD";
		break;
	 case 0x89c:
		return "WERR_NERR_UNABLETOADDNAME_W";
		break;
	 case 0x89d:
		return "WERR_NERR_UNABLETOADDNAME_F";
		break;
	 case 0x89e:
		return "WERR_NERR_UNABLETODELNAME_W";
		break;
	 case 0x89f:
		return "WERR_NERR_UNABLETODELNAME_F";
		break;
	 case 0x8a1:
		return "WERR_NERR_LOGONSPAUSED";
		break;
	 case 0x8a2:
		return "WERR_NERR_LOGONSERVERCONFLICT";
		break;
	 case 0x8a3:
		return "WERR_NERR_LOGONNOUSERPATH";
		break;
	 case 0x8a4:
		return "WERR_NERR_LOGONSCRIPTERROR";
		break;
	 case 0x8a6:
		return "WERR_NERR_STANDALONELOGON";
		break;
	 case 0x8a7:
		return "WERR_NERR_LOGONSERVERNOTFOUND";
		break;
	 case 0x8a8:
		return "WERR_NERR_LOGONDOMAINEXISTS";
		break;
	 case 0x8a9:
		return "WERR_NERR_NONVALIDATEDLOGON";
		break;
	 case 0x8ab:
		return "WERR_NERR_ACFNOTFOUND";
		break;
	 case 0x8ac:
		return "WERR_NERR_GROUPNOTFOUND";
		break;
	 case 0x8ad:
		return "WERR_NERR_USERNOTFOUND";
		break;
	 case 0x8ae:
		return "WERR_NERR_RESOURCENOTFOUND";
		break;
	 case 0x8af:
		return "WERR_NERR_GROUPEXISTS";
		break;
	 case 0x8b0:
		return "WERR_NERR_USEREXISTS";
		break;
	 case 0x8b1:
		return "WERR_NERR_RESOURCEEXISTS";
		break;
	 case 0x8b2:
		return "WERR_NERR_NOTPRIMARY";
		break;
	 case 0x8b3:
		return "WERR_NERR_ACFNOTLOADED";
		break;
	 case 0x8b4:
		return "WERR_NERR_ACFNOROOM";
		break;
	 case 0x8b5:
		return "WERR_NERR_ACFFILEIOFAIL";
		break;
	 case 0x8b6:
		return "WERR_NERR_ACFTOOMANYLISTS";
		break;
	 case 0x8b7:
		return "WERR_NERR_USERLOGON";
		break;
	 case 0x8b8:
		return "WERR_NERR_ACFNOPARENT";
		break;
	 case 0x8b9:
		return "WERR_NERR_CANNOTGROWSEGMENT";
		break;
	 case 0x8ba:
		return "WERR_NERR_SPEGROUPOP";
		break;
	 case 0x8bb:
		return "WERR_NERR_NOTINCACHE";
		break;
	 case 0x8bc:
		return "WERR_NERR_USERINGROUP";
		break;
	 case 0x8bd:
		return "WERR_NERR_USERNOTINGROUP";
		break;
	 case 0x8be:
		return "WERR_NERR_ACCOUNTUNDEFINED";
		break;
	 case 0x8bf:
		return "WERR_NERR_ACCOUNTEXPIRED";
		break;
	 case 0x8c0:
		return "WERR_NERR_INVALIDWORKSTATION";
		break;
	 case 0x8c1:
		return "WERR_NERR_INVALIDLOGONHOURS";
		break;
	 case 0x8c2:
		return "WERR_NERR_PASSWORDEXPIRED";
		break;
	 case 0x8c3:
		return "WERR_NERR_PASSWORDCANTCHANGE";
		break;
	 case 0x8c4:
		return "WERR_NERR_PASSWORDHISTCONFLICT";
		break;
	 case 0x8c5:
		return "WERR_NERR_PASSWORDTOOSHORT";
		break;
	 case 0x8c6:
		return "WERR_NERR_PASSWORDTOORECENT";
		break;
	 case 0x8c7:
		return "WERR_NERR_INVALIDDATABASE";
		break;
	 case 0x8c8:
		return "WERR_NERR_DATABASEUPTODATE";
		break;
	 case 0x8c9:
		return "WERR_NERR_SYNCREQUIRED";
		break;
	 case 0x8ca:
		return "WERR_NERR_USENOTFOUND";
		break;
	 case 0x8cb:
		return "WERR_NERR_BADASGTYPE";
		break;
	 case 0x8cc:
		return "WERR_NERR_DEVICEISSHARED";
		break;
	 case 0x8de:
		return "WERR_NERR_NOCOMPUTERNAME";
		break;
	 case 0x8df:
		return "WERR_NERR_MSGALREADYSTARTED";
		break;
	 case 0x8e0:
		return "WERR_NERR_MSGINITFAILED";
		break;
	 case 0x8e1:
		return "WERR_NERR_NAMENOTFOUND";
		break;
	 case 0x8e2:
		return "WERR_NERR_ALREADYFORWARDED";
		break;
	 case 0x8e3:
		return "WERR_NERR_ADDFORWARDED";
		break;
	 case 0x8e4:
		return "WERR_NERR_ALREADYEXISTS";
		break;
	 case 0x8e5:
		return "WERR_NERR_TOOMANYNAMES";
		break;
	 case 0x8e6:
		return "WERR_NERR_DELCOMPUTERNAME";
		break;
	 case 0x8e7:
		return "WERR_NERR_LOCALFORWARD";
		break;
	 case 0x8e8:
		return "WERR_NERR_GRPMSGPROCESSOR";
		break;
	 case 0x8e9:
		return "WERR_NERR_PAUSEDREMOTE";
		break;
	 case 0x8ea:
		return "WERR_NERR_BADRECEIVE";
		break;
	 case 0x8eb:
		return "WERR_NERR_NAMEINUSE";
		break;
	 case 0x8ec:
		return "WERR_NERR_MSGNOTSTARTED";
		break;
	 case 0x8ed:
		return "WERR_NERR_NOTLOCALNAME";
		break;
	 case 0x8ee:
		return "WERR_NERR_NOFORWARDNAME";
		break;
	 case 0x8ef:
		return "WERR_NERR_REMOTEFULL";
		break;
	 case 0x8f0:
		return "WERR_NERR_NAMENOTFORWARDED";
		break;
	 case 0x8f1:
		return "WERR_NERR_TRUNCATEDBROADCAST";
		break;
	 case 0x8f6:
		return "WERR_NERR_INVALIDDEVICE";
		break;
	 case 0x8f7:
		return "WERR_NERR_WRITEFAULT";
		break;
	 case 0x8f9:
		return "WERR_NERR_DUPLICATENAME";
		break;
	 case 0x8fa:
		return "WERR_NERR_DELETELATER";
		break;
	 case 0x8fb:
		return "WERR_NERR_INCOMPLETEDEL";
		break;
	 case 0x8fc:
		return "WERR_NERR_MULTIPLENETS";
		break;
	 case 0x906:
		return "WERR_NERR_NETNAMENOTFOUND";
		break;
	 case 0x907:
		return "WERR_NERR_DEVICENOTSHARED";
		break;
	 case 0x908:
		return "WERR_NERR_CLIENTNAMENOTFOUND";
		break;
	 case 0x90a:
		return "WERR_NERR_FILEIDNOTFOUND";
		break;
	 case 0x90b:
		return "WERR_NERR_EXECFAILURE";
		break;
	 case 0x90c:
		return "WERR_NERR_TMPFILE";
		break;
	 case 0x90d:
		return "WERR_NERR_TOOMUCHDATA";
		break;
	 case 0x90e:
		return "WERR_NERR_DEVICESHARECONFLICT";
		break;
	 case 0x90f:
		return "WERR_NERR_BROWSERTABLEINCOMPLETE";
		break;
	 case 0x910:
		return "WERR_NERR_NOTLOCALDOMAIN";
		break;
	 case 0x911:
		return "WERR_NERR_ISDFSSHARE";
		break;
	 case 0x91b:
		return "WERR_NERR_DEVINVALIDOPCODE";
		break;
	 case 0x91c:
		return "WERR_NERR_DEVNOTFOUND";
		break;
	 case 0x91d:
		return "WERR_NERR_DEVNOTOPEN";
		break;
	 case 0x91e:
		return "WERR_NERR_BADQUEUEDEVSTRING";
		break;
	 case 0x91f:
		return "WERR_NERR_BADQUEUEPRIORITY";
		break;
	 case 0x921:
		return "WERR_NERR_NOCOMMDEVS";
		break;
	 case 0x922:
		return "WERR_NERR_QUEUENOTFOUND";
		break;
	 case 0x924:
		return "WERR_NERR_BADDEVSTRING";
		break;
	 case 0x925:
		return "WERR_NERR_BADDEV";
		break;
	 case 0x926:
		return "WERR_NERR_INUSEBYSPOOLER";
		break;
	 case 0x927:
		return "WERR_NERR_COMMDEVINUSE";
		break;
	 case 0x92f:
		return "WERR_NERR_INVALIDCOMPUTER";
		break;
	 case 0x932:
		return "WERR_NERR_MAXLENEXCEEDED";
		break;
	 case 0x934:
		return "WERR_NERR_BADCOMPONENT";
		break;
	 case 0x935:
		return "WERR_NERR_CANTTYPE";
		break;
	 case 0x93a:
		return "WERR_NERR_TOOMANYENTRIES";
		break;
	 case 0x942:
		return "WERR_NERR_PROFILEFILETOOBIG";
		break;
	 case 0x943:
		return "WERR_NERR_PROFILEOFFSET";
		break;
	 case 0x944:
		return "WERR_NERR_PROFILECLEANUP";
		break;
	 case 0x945:
		return "WERR_NERR_PROFILEUNKNOWNCMD";
		break;
	 case 0x946:
		return "WERR_NERR_PROFILELOADERR";
		break;
	 case 0x947:
		return "WERR_NERR_PROFILESAVEERR";
		break;
	 case 0x949:
		return "WERR_NERR_LOGOVERFLOW";
		break;
	 case 0x94a:
		return "WERR_NERR_LOGFILECHANGED";
		break;
	 case 0x94b:
		return "WERR_NERR_LOGFILECORRUPT";
		break;
	 case 0x94c:
		return "WERR_NERR_SOURCEISDIR";
		break;
	 case 0x94d:
		return "WERR_NERR_BADSOURCE";
		break;
	 case 0x94e:
		return "WERR_NERR_BADDEST";
		break;
	 case 0x94f:
		return "WERR_NERR_DIFFERENTSERVERS";
		break;
	 case 0x951:
		return "WERR_NERR_RUNSRVPAUSED";
		break;
	 case 0x955:
		return "WERR_NERR_ERRCOMMRUNSRV";
		break;
	 case 0x957:
		return "WERR_NERR_ERROREXECINGGHOST";
		break;
	 case 0x958:
		return "WERR_NERR_SHARENOTFOUND";
		break;
	 case 0x960:
		return "WERR_NERR_INVALIDLANA";
		break;
	 case 0x961:
		return "WERR_NERR_OPENFILES";
		break;
	 case 0x962:
		return "WERR_NERR_ACTIVECONNS";
		break;
	 case 0x963:
		return "WERR_NERR_BADPASSWORDCORE";
		break;
	 case 0x964:
		return "WERR_NERR_DEVINUSE";
		break;
	 case 0x965:
		return "WERR_NERR_LOCALDRIVE";
		break;
	 case 0x97e:
		return "WERR_NERR_ALERTEXISTS";
		break;
	 case 0x97f:
		return "WERR_NERR_TOOMANYALERTS";
		break;
	 case 0x980:
		return "WERR_NERR_NOSUCHALERT";
		break;
	 case 0x981:
		return "WERR_NERR_BADRECIPIENT";
		break;
	 case 0x982:
		return "WERR_NERR_ACCTLIMITEXCEEDED";
		break;
	 case 0x988:
		return "WERR_NERR_INVALIDLOGSEEK";
		break;
	 case 0x992:
		return "WERR_NERR_BADUASCONFIG";
		break;
	 case 0x993:
		return "WERR_NERR_INVALIDUASOP";
		break;
	 case 0x994:
		return "WERR_NERR_LASTADMIN";
		break;
	 case 0x995:
		return "WERR_NERR_DCNOTFOUND";
		break;
	 case 0x996:
		return "WERR_NERR_LOGONTRACKINGERROR";
		break;
	 case 0x997:
		return "WERR_NERR_NETLOGONNOTSTARTED";
		break;
	 case 0x998:
		return "WERR_NERR_CANNOTGROWUASFILE";
		break;
	 case 0x999:
		return "WERR_NERR_TIMEDIFFATDC";
		break;
	 case 0x99a:
		return "WERR_NERR_PASSWORDMISMATCH";
		break;
	 case 0x99c:
		return "WERR_NERR_NOSUCHSERVER";
		break;
	 case 0x99d:
		return "WERR_NERR_NOSUCHSESSION";
		break;
	 case 0x99e:
		return "WERR_NERR_NOSUCHCONNECTION";
		break;
	 case 0x99f:
		return "WERR_NERR_TOOMANYSERVERS";
		break;
	 case 0x9a0:
		return "WERR_NERR_TOOMANYSESSIONS";
		break;
	 case 0x9a1:
		return "WERR_NERR_TOOMANYCONNECTIONS";
		break;
	 case 0x9a2:
		return "WERR_NERR_TOOMANYFILES";
		break;
	 case 0x9a3:
		return "WERR_NERR_NOALTERNATESERVERS";
		break;
	 case 0x9a6:
		return "WERR_NERR_TRYDOWNLEVEL";
		break;
	 case 0x9b0:
		return "WERR_NERR_UPSDRIVERNOTSTARTED";
		break;
	 case 0x9b1:
		return "WERR_NERR_UPSINVALIDCONFIG";
		break;
	 case 0x9b2:
		return "WERR_NERR_UPSINVALIDCOMMPORT";
		break;
	 case 0x9b3:
		return "WERR_NERR_UPSSIGNALASSERTED";
		break;
	 case 0x9b4:
		return "WERR_NERR_UPSSHUTDOWNFAILED";
		break;
	 case 0x9c4:
		return "WERR_NERR_BADDOSRETCODE";
		break;
	 case 0x9c5:
		return "WERR_NERR_PROGNEEDSEXTRAMEM";
		break;
	 case 0x9c6:
		return "WERR_NERR_BADDOSFUNCTION";
		break;
	 case 0x9c7:
		return "WERR_NERR_REMOTEBOOTFAILED";
		break;
	 case 0x9c8:
		return "WERR_NERR_BADFILECHECKSUM";
		break;
	 case 0x9c9:
		return "WERR_NERR_NORPLBOOTSYSTEM";
		break;
	 case 0x9ca:
		return "WERR_NERR_RPLLOADRNETBIOSERR";
		break;
	 case 0x9cb:
		return "WERR_NERR_RPLLOADRDISKERR";
		break;
	 case 0x9cc:
		return "WERR_NERR_IMAGEPARAMERR";
		break;
	 case 0x9cd:
		return "WERR_NERR_TOOMANYIMAGEPARAMS";
		break;
	 case 0x9ce:
		return "WERR_NERR_NONDOSFLOPPYUSED";
		break;
	 case 0x9cf:
		return "WERR_NERR_RPLBOOTRESTART";
		break;
	 case 0x9d0:
		return "WERR_NERR_RPLSRVRCALLFAILED";
		break;
	 case 0x9d1:
		return "WERR_NERR_CANTCONNECTRPLSRVR";
		break;
	 case 0x9d2:
		return "WERR_NERR_CANTOPENIMAGEFILE";
		break;
	 case 0x9d3:
		return "WERR_NERR_CALLINGRPLSRVR";
		break;
	 case 0x9d4:
		return "WERR_NERR_STARTINGRPLBOOT";
		break;
	 case 0x9d5:
		return "WERR_NERR_RPLBOOTSERVICETERM";
		break;
	 case 0x9d6:
		return "WERR_NERR_RPLBOOTSTARTFAILED";
		break;
	 case 0x9d7:
		return "WERR_NERR_RPL_CONNECTED";
		break;
	 case 0x9f6:
		return "WERR_NERR_BROWSERCONFIGUREDTONOTRUN";
		break;
	 case 0xa32:
		return "WERR_NERR_RPLNOADAPTERSSTARTED";
		break;
	 case 0xa33:
		return "WERR_NERR_RPLBADREGISTRY";
		break;
	 case 0xa34:
		return "WERR_NERR_RPLBADDATABASE";
		break;
	 case 0xa35:
		return "WERR_NERR_RPLRPLFILESSHARE";
		break;
	 case 0xa36:
		return "WERR_NERR_RPLNOTRPLSERVER";
		break;
	 case 0xa37:
		return "WERR_NERR_RPLCANNOTENUM";
		break;
	 case 0xa38:
		return "WERR_NERR_RPLWKSTAINFOCORRUPTED";
		break;
	 case 0xa39:
		return "WERR_NERR_RPLWKSTANOTFOUND";
		break;
	 case 0xa3a:
		return "WERR_NERR_RPLWKSTANAMEUNAVAILABLE";
		break;
	 case 0xa3b:
		return "WERR_NERR_RPLPROFILEINFOCORRUPTED";
		break;
	 case 0xa3c:
		return "WERR_NERR_RPLPROFILENOTFOUND";
		break;
	 case 0xa3d:
		return "WERR_NERR_RPLPROFILENAMEUNAVAILABLE";
		break;
	 case 0xa3e:
		return "WERR_NERR_RPLPROFILENOTEMPTY";
		break;
	 case 0xa3f:
		return "WERR_NERR_RPLCONFIGINFOCORRUPTED";
		break;
	 case 0xa40:
		return "WERR_NERR_RPLCONFIGNOTFOUND";
		break;
	 case 0xa41:
		return "WERR_NERR_RPLADAPTERINFOCORRUPTED";
		break;
	 case 0xa42:
		return "WERR_NERR_RPLINTERNAL";
		break;
	 case 0xa43:
		return "WERR_NERR_RPLVENDORINFOCORRUPTED";
		break;
	 case 0xa44:
		return "WERR_NERR_RPLBOOTINFOCORRUPTED";
		break;
	 case 0xa45:
		return "WERR_NERR_RPLWKSTANEEDSUSERACCT";
		break;
	 case 0xa46:
		return "WERR_NERR_RPLNEEDSRPLUSERACCT";
		break;
	 case 0xa47:
		return "WERR_NERR_RPLBOOTNOTFOUND";
		break;
	 case 0xa48:
		return "WERR_NERR_RPLINCOMPATIBLEPROFILE";
		break;
	 case 0xa49:
		return "WERR_NERR_RPLADAPTERNAMEUNAVAILABLE";
		break;
	 case 0xa4a:
		return "WERR_NERR_RPLCONFIGNOTEMPTY";
		break;
	 case 0xa4b:
		return "WERR_NERR_RPLBOOTINUSE";
		break;
	 case 0xa4c:
		return "WERR_NERR_RPLBACKUPDATABASE";
		break;
	 case 0xa4d:
		return "WERR_NERR_RPLADAPTERNOTFOUND";
		break;
	 case 0xa4e:
		return "WERR_NERR_RPLVENDORNOTFOUND";
		break;
	 case 0xa4f:
		return "WERR_NERR_RPLVENDORNAMEUNAVAILABLE";
		break;
	 case 0xa50:
		return "WERR_NERR_RPLBOOTNAMEUNAVAILABLE";
		break;
	 case 0xa51:
		return "WERR_NERR_RPLCONFIGNAMEUNAVAILABLE";
		break;
	 case 0xa64:
		return "WERR_NERR_DFSINTERNALCORRUPTION";
		break;
	 case 0xa65:
		return "WERR_NERR_DFSVOLUMEDATACORRUPT";
		break;
	 case 0xa66:
		return "WERR_NERR_DFSNOSUCHVOLUME";
		break;
	 case 0xa67:
		return "WERR_NERR_DFSVOLUMEALREADYEXISTS";
		break;
	 case 0xa68:
		return "WERR_NERR_DFSALREADYSHARED";
		break;
	 case 0xa69:
		return "WERR_NERR_DFSNOSUCHSHARE";
		break;
	 case 0xa6a:
		return "WERR_NERR_DFSNOTALEAFVOLUME";
		break;
	 case 0xa6b:
		return "WERR_NERR_DFSLEAFVOLUME";
		break;
	 case 0xa6c:
		return "WERR_NERR_DFSVOLUMEHASMULTIPLESERVERS";
		break;
	 case 0xa6d:
		return "WERR_NERR_DFSCANTCREATEJUNCTIONPOINT";
		break;
	 case 0xa6e:
		return "WERR_NERR_DFSSERVERNOTDFSAWARE";
		break;
	 case 0xa6f:
		return "WERR_NERR_DFSBADRENAMEPATH";
		break;
	 case 0xa70:
		return "WERR_NERR_DFSVOLUMEISOFFLINE";
		break;
	 case 0xa71:
		return "WERR_NERR_DFSNOSUCHSERVER";
		break;
	 case 0xa72:
		return "WERR_NERR_DFSCYCLICALNAME";
		break;
	 case 0xa73:
		return "WERR_NERR_DFSNOTSUPPORTEDINSERVERDFS";
		break;
	 case 0xa74:
		return "WERR_NERR_DFSDUPLICATESERVICE";
		break;
	 case 0xa75:
		return "WERR_NERR_DFSCANTREMOVELASTSERVERSHARE";
		break;
	 case 0xa76:
		return "WERR_NERR_DFSVOLUMEISINTERDFS";
		break;
	 case 0xa77:
		return "WERR_NERR_DFSINCONSISTENT";
		break;
	 case 0xa78:
		return "WERR_NERR_DFSSERVERUPGRADED";
		break;
	 case 0xa79:
		return "WERR_NERR_DFSDATAISIDENTICAL";
		break;
	 case 0xa7a:
		return "WERR_NERR_DFSCANTREMOVEDFSROOT";
		break;
	 case 0xa7b:
		return "WERR_NERR_DFSCHILDORPARENTINDFS";
		break;
	 case 0xa82:
		return "WERR_NERR_DFSINTERNALERROR";
		break;
	 case 0xa83:
		return "WERR_NERR_SETUPALREADYJOINED";
		break;
	 case 0xa84:
		return "WERR_NERR_SETUPNOTJOINED";
		break;
	 case 0xa85:
		return "WERR_NERR_SETUPDOMAINCONTROLLER";
		break;
	 case 0xa86:
		return "WERR_NERR_DEFAULTJOINREQUIRED";
		break;
	 case 0xa87:
		return "WERR_NERR_INVALIDWORKGROUPNAME";
		break;
	 case 0xa88:
		return "WERR_NERR_NAMEUSESINCOMPATIBLECODEPAGE";
		break;
	 case 0xa89:
		return "WERR_NERR_COMPUTERACCOUNTNOTFOUND";
		break;
	 case 0xa8a:
		return "WERR_NERR_PERSONALSKU";
		break;
	 case 0xa8d:
		return "WERR_NERR_PASSWORDMUSTCHANGE";
		break;
	 case 0xa8e:
		return "WERR_NERR_ACCOUNTLOCKEDOUT";
		break;
	 case 0xa8f:
		return "WERR_NERR_PASSWORDTOOLONG";
		break;
	 case 0xa90:
		return "WERR_NERR_PASSWORDNOTCOMPLEXENOUGH";
		break;
	 case 0xa91:
		return "WERR_NERR_PASSWORDFILTERERROR";
		break;
	 case 0xbb8:
		return "WERR_UNKNOWN_PRINT_MONITOR";
		break;
	 case 0xbb9:
		return "WERR_PRINTER_DRIVER_IN_USE";
		break;
	 case 0xbba:
		return "WERR_SPOOL_FILE_NOT_FOUND";
		break;
	 case 0xbbb:
		return "WERR_SPL_NO_STARTDOC";
		break;
	 case 0xbbc:
		return "WERR_SPL_NO_ADDJOB";
		break;
	 case 0xbbd:
		return "WERR_PRINT_PROCESSOR_ALREADY_INSTALLED";
		break;
	 case 0xbbe:
		return "WERR_PRINT_MONITOR_ALREADY_INSTALLED";
		break;
	 case 0xbbf:
		return "WERR_INVALID_PRINT_MONITOR";
		break;
	 case 0xbc0:
		return "WERR_PRINT_MONITOR_IN_USE";
		break;
	 case 0xbc1:
		return "WERR_PRINTER_HAS_JOBS_QUEUED";
		break;
	 case 0xbc2:
		return "WERR_SUCCESS_REBOOT_REQUIRED";
		break;
	 case 0xbc3:
		return "WERR_SUCCESS_RESTART_REQUIRED";
		break;
	 case 0xbc4:
		return "WERR_PRINTER_NOT_FOUND";
		break;
	 case 0xbc5:
		return "WERR_PRINTER_DRIVER_WARNED";
		break;
	 case 0xbc6:
		return "WERR_PRINTER_DRIVER_BLOCKED";
		break;
	 case 0xbc7:
		return "WERR_PRINTER_DRIVER_PACKAGE_IN_USE";
		break;
	 case 0xbc8:
		return "WERR_CORE_DRIVER_PACKAGE_NOT_FOUND";
		break;
	 case 0xbc9:
		return "WERR_FAIL_REBOOT_REQUIRED";
		break;
	 case 0xbca:
		return "WERR_FAIL_REBOOT_INITIATED";
		break;
	 case 0xbcb:
		return "WERR_PRINTER_DRIVER_DOWNLOAD_NEEDED";
		break;
	 case 0xbce:
		return "WERR_PRINTER_NOT_SHAREABLE";
		break;
	 case 0xf6e:
		return "WERR_IO_REISSUE_AS_CACHED";
		break;
	 case 0xfa0:
		return "WERR_WINS_INTERNAL";
		break;
	 case 0xfa1:
		return "WERR_CAN_NOT_DEL_LOCAL_WINS";
		break;
	 case 0xfa2:
		return "WERR_STATIC_INIT";
		break;
	 case 0xfa3:
		return "WERR_INC_BACKUP";
		break;
	 case 0xfa4:
		return "WERR_FULL_BACKUP";
		break;
	 case 0xfa5:
		return "WERR_REC_NON_EXISTENT";
		break;
	 case 0xfa6:
		return "WERR_RPL_NOT_ALLOWED";
		break;
	 case 0xfd2:
		return "WERR_PEERDIST_ERROR_CONTENTINFO_VERSION_UNSUPPORTED";
		break;
	 case 0xfd3:
		return "WERR_PEERDIST_ERROR_CANNOT_PARSE_CONTENTINFO";
		break;
	 case 0xfd4:
		return "WERR_PEERDIST_ERROR_MISSING_DATA";
		break;
	 case 0xfd5:
		return "WERR_PEERDIST_ERROR_NO_MORE";
		break;
	 case 0xfd6:
		return "WERR_PEERDIST_ERROR_NOT_INITIALIZED";
		break;
	 case 0xfd7:
		return "WERR_PEERDIST_ERROR_ALREADY_INITIALIZED";
		break;
	 case 0xfd8:
		return "WERR_PEERDIST_ERROR_SHUTDOWN_IN_PROGRESS";
		break;
	 case 0xfd9:
		return "WERR_PEERDIST_ERROR_INVALIDATED";
		break;
	 case 0xfda:
		return "WERR_PEERDIST_ERROR_ALREADY_EXISTS";
		break;
	 case 0xfdb:
		return "WERR_PEERDIST_ERROR_OPERATION_NOTFOUND";
		break;
	 case 0xfdc:
		return "WERR_PEERDIST_ERROR_ALREADY_COMPLETED";
		break;
	 case 0xfdd:
		return "WERR_PEERDIST_ERROR_OUT_OF_BOUNDS";
		break;
	 case 0xfde:
		return "WERR_PEERDIST_ERROR_VERSION_UNSUPPORTED";
		break;
	 case 0xfdf:
		return "WERR_PEERDIST_ERROR_INVALID_CONFIGURATION";
		break;
	 case 0xfe0:
		return "WERR_PEERDIST_ERROR_NOT_LICENSED";
		break;
	 case 0xfe1:
		return "WERR_PEERDIST_ERROR_SERVICE_UNAVAILABLE";
		break;
	 case 0x1004:
		return "WERR_DHCP_ADDRESS_CONFLICT";
		break;
	 case 0x1068:
		return "WERR_WMI_GUID_NOT_FOUND";
		break;
	 case 0x1069:
		return "WERR_WMI_INSTANCE_NOT_FOUND";
		break;
	 case 0x106a:
		return "WERR_WMI_ITEMID_NOT_FOUND";
		break;
	 case 0x106b:
		return "WERR_WMI_TRY_AGAIN";
		break;
	 case 0x106c:
		return "WERR_WMI_DP_NOT_FOUND";
		break;
	 case 0x106d:
		return "WERR_WMI_UNRESOLVED_INSTANCE_REF";
		break;
	 case 0x106e:
		return "WERR_WMI_ALREADY_ENABLED";
		break;
	 case 0x106f:
		return "WERR_WMI_GUID_DISCONNECTED";
		break;
	 case 0x1070:
		return "WERR_WMI_SERVER_UNAVAILABLE";
		break;
	 case 0x1071:
		return "WERR_WMI_DP_FAILED";
		break;
	 case 0x1072:
		return "WERR_WMI_INVALID_MOF";
		break;
	 case 0x1073:
		return "WERR_WMI_INVALID_REGINFO";
		break;
	 case 0x1074:
		return "WERR_WMI_ALREADY_DISABLED";
		break;
	 case 0x1075:
		return "WERR_WMI_READ_ONLY";
		break;
	 case 0x1076:
		return "WERR_WMI_SET_FAILURE";
		break;
	 case 0x10cc:
		return "WERR_INVALID_MEDIA";
		break;
	 case 0x10cd:
		return "WERR_INVALID_LIBRARY";
		break;
	 case 0x10ce:
		return "WERR_INVALID_MEDIA_POOL";
		break;
	 case 0x10cf:
		return "WERR_DRIVE_MEDIA_MISMATCH";
		break;
	 case 0x10d0:
		return "WERR_MEDIA_OFFLINE";
		break;
	 case 0x10d1:
		return "WERR_LIBRARY_OFFLINE";
		break;
	 case 0x10d2:
		return "WERR_EMPTY";
		break;
	 case 0x10d3:
		return "WERR_NOT_EMPTY";
		break;
	 case 0x10d4:
		return "WERR_MEDIA_UNAVAILABLE";
		break;
	 case 0x10d5:
		return "WERR_RESOURCE_DISABLED";
		break;
	 case 0x10d6:
		return "WERR_INVALID_CLEANER";
		break;
	 case 0x10d7:
		return "WERR_UNABLE_TO_CLEAN";
		break;
	 case 0x10d8:
		return "WERR_OBJECT_NOT_FOUND";
		break;
	 case 0x10d9:
		return "WERR_DATABASE_FAILURE";
		break;
	 case 0x10da:
		return "WERR_DATABASE_FULL";
		break;
	 case 0x10db:
		return "WERR_MEDIA_INCOMPATIBLE";
		break;
	 case 0x10dc:
		return "WERR_RESOURCE_NOT_PRESENT";
		break;
	 case 0x10dd:
		return "WERR_INVALID_OPERATION";
		break;
	 case 0x10de:
		return "WERR_MEDIA_NOT_AVAILABLE";
		break;
	 case 0x10df:
		return "WERR_DEVICE_NOT_AVAILABLE";
		break;
	 case 0x10e0:
		return "WERR_REQUEST_REFUSED";
		break;
	 case 0x10e1:
		return "WERR_INVALID_DRIVE_OBJECT";
		break;
	 case 0x10e2:
		return "WERR_LIBRARY_FULL";
		break;
	 case 0x10e3:
		return "WERR_MEDIUM_NOT_ACCESSIBLE";
		break;
	 case 0x10e4:
		return "WERR_UNABLE_TO_LOAD_MEDIUM";
		break;
	 case 0x10e5:
		return "WERR_UNABLE_TO_INVENTORY_DRIVE";
		break;
	 case 0x10e6:
		return "WERR_UNABLE_TO_INVENTORY_SLOT";
		break;
	 case 0x10e7:
		return "WERR_UNABLE_TO_INVENTORY_TRANSPORT";
		break;
	 case 0x10e8:
		return "WERR_TRANSPORT_FULL";
		break;
	 case 0x10e9:
		return "WERR_CONTROLLING_IEPORT";
		break;
	 case 0x10ea:
		return "WERR_UNABLE_TO_EJECT_MOUNTED_MEDIA";
		break;
	 case 0x10eb:
		return "WERR_CLEANER_SLOT_SET";
		break;
	 case 0x10ec:
		return "WERR_CLEANER_SLOT_NOT_SET";
		break;
	 case 0x10ed:
		return "WERR_CLEANER_CARTRIDGE_SPENT";
		break;
	 case 0x10ee:
		return "WERR_UNEXPECTED_OMID";
		break;
	 case 0x10ef:
		return "WERR_CANT_DELETE_LAST_ITEM";
		break;
	 case 0x10f0:
		return "WERR_MESSAGE_EXCEEDS_MAX_SIZE";
		break;
	 case 0x10f1:
		return "WERR_VOLUME_CONTAINS_SYS_FILES";
		break;
	 case 0x10f2:
		return "WERR_INDIGENOUS_TYPE";
		break;
	 case 0x10f3:
		return "WERR_NO_SUPPORTING_DRIVES";
		break;
	 case 0x10f4:
		return "WERR_CLEANER_CARTRIDGE_INSTALLED";
		break;
	 case 0x10f5:
		return "WERR_IEPORT_FULL";
		break;
	 case 0x10fe:
		return "WERR_FILE_OFFLINE";
		break;
	 case 0x10ff:
		return "WERR_REMOTE_STORAGE_NOT_ACTIVE";
		break;
	 case 0x1100:
		return "WERR_REMOTE_STORAGE_MEDIA_ERROR";
		break;
	 case 0x1126:
		return "WERR_NOT_A_REPARSE_POINT";
		break;
	 case 0x1127:
		return "WERR_REPARSE_ATTRIBUTE_CONFLICT";
		break;
	 case 0x1128:
		return "WERR_INVALID_REPARSE_DATA";
		break;
	 case 0x1129:
		return "WERR_REPARSE_TAG_INVALID";
		break;
	 case 0x112a:
		return "WERR_REPARSE_TAG_MISMATCH";
		break;
	 case 0x1194:
		return "WERR_VOLUME_NOT_SIS_ENABLED";
		break;
	 case 0x1389:
		return "WERR_DEPENDENT_RESOURCE_EXISTS";
		break;
	 case 0x138a:
		return "WERR_DEPENDENCY_NOT_FOUND";
		break;
	 case 0x138b:
		return "WERR_DEPENDENCY_ALREADY_EXISTS";
		break;
	 case 0x138c:
		return "WERR_RESOURCE_NOT_ONLINE";
		break;
	 case 0x138d:
		return "WERR_HOST_NODE_NOT_AVAILABLE";
		break;
	 case 0x138e:
		return "WERR_RESOURCE_NOT_AVAILABLE";
		break;
	 case 0x138f:
		return "WERR_RESOURCE_NOT_FOUND";
		break;
	 case 0x1390:
		return "WERR_SHUTDOWN_CLUSTER";
		break;
	 case 0x1391:
		return "WERR_CANT_EVICT_ACTIVE_NODE";
		break;
	 case 0x1392:
		return "WERR_OBJECT_ALREADY_EXISTS";
		break;
	 case 0x1393:
		return "WERR_OBJECT_IN_LIST";
		break;
	 case 0x1394:
		return "WERR_GROUP_NOT_AVAILABLE";
		break;
	 case 0x1395:
		return "WERR_GROUP_NOT_FOUND";
		break;
	 case 0x1396:
		return "WERR_GROUP_NOT_ONLINE";
		break;
	 case 0x1397:
		return "WERR_HOST_NODE_NOT_RESOURCE_OWNER";
		break;
	 case 0x1398:
		return "WERR_HOST_NODE_NOT_GROUP_OWNER";
		break;
	 case 0x1399:
		return "WERR_RESMON_CREATE_FAILED";
		break;
	 case 0x139a:
		return "WERR_RESMON_ONLINE_FAILED";
		break;
	 case 0x139b:
		return "WERR_RESOURCE_ONLINE";
		break;
	 case 0x139c:
		return "WERR_QUORUM_RESOURCE";
		break;
	 case 0x139d:
		return "WERR_NOT_QUORUM_CAPABLE";
		break;
	 case 0x139e:
		return "WERR_CLUSTER_SHUTTING_DOWN";
		break;
	 case 0x139f:
		return "WERR_INVALID_STATE";
		break;
	 case 0x13a0:
		return "WERR_RESOURCE_PROPERTIES_STORED";
		break;
	 case 0x13a1:
		return "WERR_NOT_QUORUM_CLASS";
		break;
	 case 0x13a2:
		return "WERR_CORE_RESOURCE";
		break;
	 case 0x13a3:
		return "WERR_QUORUM_RESOURCE_ONLINE_FAILED";
		break;
	 case 0x13a4:
		return "WERR_QUORUMLOG_OPEN_FAILED";
		break;
	 case 0x13a5:
		return "WERR_CLUSTERLOG_CORRUPT";
		break;
	 case 0x13a6:
		return "WERR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE";
		break;
	 case 0x13a7:
		return "WERR_CLUSTERLOG_EXCEEDS_MAXSIZE";
		break;
	 case 0x13a8:
		return "WERR_CLUSTERLOG_CHKPOINT_NOT_FOUND";
		break;
	 case 0x13a9:
		return "WERR_CLUSTERLOG_NOT_ENOUGH_SPACE";
		break;
	 case 0x13aa:
		return "WERR_QUORUM_OWNER_ALIVE";
		break;
	 case 0x13ab:
		return "WERR_NETWORK_NOT_AVAILABLE";
		break;
	 case 0x13ac:
		return "WERR_NODE_NOT_AVAILABLE";
		break;
	 case 0x13ad:
		return "WERR_ALL_NODES_NOT_AVAILABLE";
		break;
	 case 0x13ae:
		return "WERR_RESOURCE_FAILED";
		break;
	 case 0x13af:
		return "WERR_CLUSTER_INVALID_NODE";
		break;
	 case 0x13b0:
		return "WERR_CLUSTER_NODE_EXISTS";
		break;
	 case 0x13b1:
		return "WERR_CLUSTER_JOIN_IN_PROGRESS";
		break;
	 case 0x13b2:
		return "WERR_CLUSTER_NODE_NOT_FOUND";
		break;
	 case 0x13b3:
		return "WERR_CLUSTER_LOCAL_NODE_NOT_FOUND";
		break;
	 case 0x13b4:
		return "WERR_CLUSTER_NETWORK_EXISTS";
		break;
	 case 0x13b5:
		return "WERR_CLUSTER_NETWORK_NOT_FOUND";
		break;
	 case 0x13b6:
		return "WERR_CLUSTER_NETINTERFACE_EXISTS";
		break;
	 case 0x13b7:
		return "WERR_CLUSTER_NETINTERFACE_NOT_FOUND";
		break;
	 case 0x13b8:
		return "WERR_CLUSTER_INVALID_REQUEST";
		break;
	 case 0x13b9:
		return "WERR_CLUSTER_INVALID_NETWORK_PROVIDER";
		break;
	 case 0x13ba:
		return "WERR_CLUSTER_NODE_DOWN";
		break;
	 case 0x13bb:
		return "WERR_CLUSTER_NODE_UNREACHABLE";
		break;
	 case 0x13bc:
		return "WERR_CLUSTER_NODE_NOT_MEMBER";
		break;
	 case 0x13bd:
		return "WERR_CLUSTER_JOIN_NOT_IN_PROGRESS";
		break;
	 case 0x13be:
		return "WERR_CLUSTER_INVALID_NETWORK";
		break;
	 case 0x13c0:
		return "WERR_CLUSTER_NODE_UP";
		break;
	 case 0x13c1:
		return "WERR_CLUSTER_IPADDR_IN_USE";
		break;
	 case 0x13c2:
		return "WERR_CLUSTER_NODE_NOT_PAUSED";
		break;
	 case 0x13c3:
		return "WERR_CLUSTER_NO_SECURITY_CONTEXT";
		break;
	 case 0x13c4:
		return "WERR_CLUSTER_NETWORK_NOT_INTERNAL";
		break;
	 case 0x13c5:
		return "WERR_CLUSTER_NODE_ALREADY_UP";
		break;
	 case 0x13c6:
		return "WERR_CLUSTER_NODE_ALREADY_DOWN";
		break;
	 case 0x13c7:
		return "WERR_CLUSTER_NETWORK_ALREADY_ONLINE";
		break;
	 case 0x13c8:
		return "WERR_CLUSTER_NETWORK_ALREADY_OFFLINE";
		break;
	 case 0x13c9:
		return "WERR_CLUSTER_NODE_ALREADY_MEMBER";
		break;
	 case 0x13ca:
		return "WERR_CLUSTER_LAST_INTERNAL_NETWORK";
		break;
	 case 0x13cb:
		return "WERR_CLUSTER_NETWORK_HAS_DEPENDENTS";
		break;
	 case 0x13cc:
		return "WERR_INVALID_OPERATION_ON_QUORUM";
		break;
	 case 0x13cd:
		return "WERR_DEPENDENCY_NOT_ALLOWED";
		break;
	 case 0x13ce:
		return "WERR_CLUSTER_NODE_PAUSED";
		break;
	 case 0x13cf:
		return "WERR_NODE_CANT_HOST_RESOURCE";
		break;
	 case 0x13d0:
		return "WERR_CLUSTER_NODE_NOT_READY";
		break;
	 case 0x13d1:
		return "WERR_CLUSTER_NODE_SHUTTING_DOWN";
		break;
	 case 0x13d2:
		return "WERR_CLUSTER_JOIN_ABORTED";
		break;
	 case 0x13d3:
		return "WERR_CLUSTER_INCOMPATIBLE_VERSIONS";
		break;
	 case 0x13d4:
		return "WERR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED";
		break;
	 case 0x13d5:
		return "WERR_CLUSTER_SYSTEM_CONFIG_CHANGED";
		break;
	 case 0x13d6:
		return "WERR_CLUSTER_RESOURCE_TYPE_NOT_FOUND";
		break;
	 case 0x13d7:
		return "WERR_CLUSTER_RESTYPE_NOT_SUPPORTED";
		break;
	 case 0x13d8:
		return "WERR_CLUSTER_RESNAME_NOT_FOUND";
		break;
	 case 0x13d9:
		return "WERR_CLUSTER_NO_RPC_PACKAGES_REGISTERED";
		break;
	 case 0x13da:
		return "WERR_CLUSTER_OWNER_NOT_IN_PREFLIST";
		break;
	 case 0x13db:
		return "WERR_CLUSTER_DATABASE_SEQMISMATCH";
		break;
	 case 0x13dc:
		return "WERR_RESMON_INVALID_STATE";
		break;
	 case 0x13dd:
		return "WERR_CLUSTER_GUM_NOT_LOCKER";
		break;
	 case 0x13de:
		return "WERR_QUORUM_DISK_NOT_FOUND";
		break;
	 case 0x13df:
		return "WERR_DATABASE_BACKUP_CORRUPT";
		break;
	 case 0x13e0:
		return "WERR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT";
		break;
	 case 0x13e1:
		return "WERR_RESOURCE_PROPERTY_UNCHANGEABLE";
		break;
	 case 0x1702:
		return "WERR_CLUSTER_MEMBERSHIP_INVALID_STATE";
		break;
	 case 0x1703:
		return "WERR_CLUSTER_QUORUMLOG_NOT_FOUND";
		break;
	 case 0x1704:
		return "WERR_CLUSTER_MEMBERSHIP_HALT";
		break;
	 case 0x1705:
		return "WERR_CLUSTER_INSTANCE_ID_MISMATCH";
		break;
	 case 0x1706:
		return "WERR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP";
		break;
	 case 0x1707:
		return "WERR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH";
		break;
	 case 0x1708:
		return "WERR_CLUSTER_EVICT_WITHOUT_CLEANUP";
		break;
	 case 0x1709:
		return "WERR_CLUSTER_PARAMETER_MISMATCH";
		break;
	 case 0x170a:
		return "WERR_NODE_CANNOT_BE_CLUSTERED";
		break;
	 case 0x170b:
		return "WERR_CLUSTER_WRONG_OS_VERSION";
		break;
	 case 0x170c:
		return "WERR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME";
		break;
	 case 0x170d:
		return "WERR_CLUSCFG_ALREADY_COMMITTED";
		break;
	 case 0x170e:
		return "WERR_CLUSCFG_ROLLBACK_FAILED";
		break;
	 case 0x170f:
		return "WERR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT";
		break;
	 case 0x1710:
		return "WERR_CLUSTER_OLD_VERSION";
		break;
	 case 0x1711:
		return "WERR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME";
		break;
	 case 0x1712:
		return "WERR_CLUSTER_NO_NET_ADAPTERS";
		break;
	 case 0x1713:
		return "WERR_CLUSTER_POISONED";
		break;
	 case 0x1714:
		return "WERR_CLUSTER_GROUP_MOVING";
		break;
	 case 0x1715:
		return "WERR_CLUSTER_RESOURCE_TYPE_BUSY";
		break;
	 case 0x1716:
		return "WERR_RESOURCE_CALL_TIMED_OUT";
		break;
	 case 0x1717:
		return "WERR_INVALID_CLUSTER_IPV6_ADDRESS";
		break;
	 case 0x1718:
		return "WERR_CLUSTER_INTERNAL_INVALID_FUNCTION";
		break;
	 case 0x1719:
		return "WERR_CLUSTER_PARAMETER_OUT_OF_BOUNDS";
		break;
	 case 0x171a:
		return "WERR_CLUSTER_PARTIAL_SEND";
		break;
	 case 0x171b:
		return "WERR_CLUSTER_REGISTRY_INVALID_FUNCTION";
		break;
	 case 0x171c:
		return "WERR_CLUSTER_INVALID_STRING_TERMINATION";
		break;
	 case 0x171d:
		return "WERR_CLUSTER_INVALID_STRING_FORMAT";
		break;
	 case 0x171e:
		return "WERR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS";
		break;
	 case 0x171f:
		return "WERR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS";
		break;
	 case 0x1720:
		return "WERR_CLUSTER_NULL_DATA";
		break;
	 case 0x1721:
		return "WERR_CLUSTER_PARTIAL_READ";
		break;
	 case 0x1722:
		return "WERR_CLUSTER_PARTIAL_WRITE";
		break;
	 case 0x1723:
		return "WERR_CLUSTER_CANT_DESERIALIZE_DATA";
		break;
	 case 0x1724:
		return "WERR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT";
		break;
	 case 0x1725:
		return "WERR_CLUSTER_NO_QUORUM";
		break;
	 case 0x1726:
		return "WERR_CLUSTER_INVALID_IPV6_NETWORK";
		break;
	 case 0x1727:
		return "WERR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK";
		break;
	 case 0x1728:
		return "WERR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP";
		break;
	 case 0x1770:
		return "WERR_ENCRYPTION_FAILED";
		break;
	 case 0x1771:
		return "WERR_DECRYPTION_FAILED";
		break;
	 case 0x1772:
		return "WERR_FILE_ENCRYPTED";
		break;
	 case 0x1773:
		return "WERR_NO_RECOVERY_POLICY";
		break;
	 case 0x1774:
		return "WERR_NO_EFS";
		break;
	 case 0x1775:
		return "WERR_WRONG_EFS";
		break;
	 case 0x1776:
		return "WERR_NO_USER_KEYS";
		break;
	 case 0x1777:
		return "WERR_FILE_NOT_ENCRYPTED";
		break;
	 case 0x1778:
		return "WERR_NOT_EXPORT_FORMAT";
		break;
	 case 0x1779:
		return "WERR_FILE_READ_ONLY";
		break;
	 case 0x177a:
		return "WERR_DIR_EFS_DISALLOWED";
		break;
	 case 0x177b:
		return "WERR_EFS_SERVER_NOT_TRUSTED";
		break;
	 case 0x177c:
		return "WERR_BAD_RECOVERY_POLICY";
		break;
	 case 0x177d:
		return "WERR_EFS_ALG_BLOB_TOO_BIG";
		break;
	 case 0x177e:
		return "WERR_VOLUME_NOT_SUPPORT_EFS";
		break;
	 case 0x177f:
		return "WERR_EFS_DISABLED";
		break;
	 case 0x1780:
		return "WERR_EFS_VERSION_NOT_SUPPORT";
		break;
	 case 0x1781:
		return "WERR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE";
		break;
	 case 0x1782:
		return "WERR_CS_ENCRYPTION_UNSUPPORTED_SERVER";
		break;
	 case 0x1783:
		return "WERR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE";
		break;
	 case 0x1784:
		return "WERR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE";
		break;
	 case 0x1785:
		return "WERR_CS_ENCRYPTION_FILE_NOT_CSE";
		break;
	 case 0x17e6:
		return "WERR_NO_BROWSER_SERVERS_FOUND";
		break;
	 case 0x1838:
		return "WERR_SCHED_E_SERVICE_NOT_LOCALSYSTEM";
		break;
	 case 0x19c8:
		return "WERR_LOG_SECTOR_INVALID";
		break;
	 case 0x19c9:
		return "WERR_LOG_SECTOR_PARITY_INVALID";
		break;
	 case 0x19ca:
		return "WERR_LOG_SECTOR_REMAPPED";
		break;
	 case 0x19cb:
		return "WERR_LOG_BLOCK_INCOMPLETE";
		break;
	 case 0x19cc:
		return "WERR_LOG_INVALID_RANGE";
		break;
	 case 0x19cd:
		return "WERR_LOG_BLOCKS_EXHAUSTED";
		break;
	 case 0x19ce:
		return "WERR_LOG_READ_CONTEXT_INVALID";
		break;
	 case 0x19cf:
		return "WERR_LOG_RESTART_INVALID";
		break;
	 case 0x19d0:
		return "WERR_LOG_BLOCK_VERSION";
		break;
	 case 0x19d1:
		return "WERR_LOG_BLOCK_INVALID";
		break;
	 case 0x19d2:
		return "WERR_LOG_READ_MODE_INVALID";
		break;
	 case 0x19d3:
		return "WERR_LOG_NO_RESTART";
		break;
	 case 0x19d4:
		return "WERR_LOG_METADATA_CORRUPT";
		break;
	 case 0x19d5:
		return "WERR_LOG_METADATA_INVALID";
		break;
	 case 0x19d6:
		return "WERR_LOG_METADATA_INCONSISTENT";
		break;
	 case 0x19d7:
		return "WERR_LOG_RESERVATION_INVALID";
		break;
	 case 0x19d8:
		return "WERR_LOG_CANT_DELETE";
		break;
	 case 0x19d9:
		return "WERR_LOG_CONTAINER_LIMIT_EXCEEDED";
		break;
	 case 0x19da:
		return "WERR_LOG_START_OF_LOG";
		break;
	 case 0x19db:
		return "WERR_LOG_POLICY_ALREADY_INSTALLED";
		break;
	 case 0x19dc:
		return "WERR_LOG_POLICY_NOT_INSTALLED";
		break;
	 case 0x19dd:
		return "WERR_LOG_POLICY_INVALID";
		break;
	 case 0x19de:
		return "WERR_LOG_POLICY_CONFLICT";
		break;
	 case 0x19df:
		return "WERR_LOG_PINNED_ARCHIVE_TAIL";
		break;
	 case 0x19e0:
		return "WERR_LOG_RECORD_NONEXISTENT";
		break;
	 case 0x19e1:
		return "WERR_LOG_RECORDS_RESERVED_INVALID";
		break;
	 case 0x19e2:
		return "WERR_LOG_SPACE_RESERVED_INVALID";
		break;
	 case 0x19e3:
		return "WERR_LOG_TAIL_INVALID";
		break;
	 case 0x19e4:
		return "WERR_LOG_FULL";
		break;
	 case 0x19e5:
		return "WERR_COULD_NOT_RESIZE_LOG";
		break;
	 case 0x19e6:
		return "WERR_LOG_MULTIPLEXED";
		break;
	 case 0x19e7:
		return "WERR_LOG_DEDICATED";
		break;
	 case 0x19e8:
		return "WERR_LOG_ARCHIVE_NOT_IN_PROGRESS";
		break;
	 case 0x19e9:
		return "WERR_LOG_ARCHIVE_IN_PROGRESS";
		break;
	 case 0x19ea:
		return "WERR_LOG_EPHEMERAL";
		break;
	 case 0x19eb:
		return "WERR_LOG_NOT_ENOUGH_CONTAINERS";
		break;
	 case 0x19ec:
		return "WERR_LOG_CLIENT_ALREADY_REGISTERED";
		break;
	 case 0x19ed:
		return "WERR_LOG_CLIENT_NOT_REGISTERED";
		break;
	 case 0x19ee:
		return "WERR_LOG_FULL_HANDLER_IN_PROGRESS";
		break;
	 case 0x19ef:
		return "WERR_LOG_CONTAINER_READ_FAILED";
		break;
	 case 0x19f0:
		return "WERR_LOG_CONTAINER_WRITE_FAILED";
		break;
	 case 0x19f1:
		return "WERR_LOG_CONTAINER_OPEN_FAILED";
		break;
	 case 0x19f2:
		return "WERR_LOG_CONTAINER_STATE_INVALID";
		break;
	 case 0x19f3:
		return "WERR_LOG_STATE_INVALID";
		break;
	 case 0x19f4:
		return "WERR_LOG_PINNED";
		break;
	 case 0x19f5:
		return "WERR_LOG_METADATA_FLUSH_FAILED";
		break;
	 case 0x19f6:
		return "WERR_LOG_INCONSISTENT_SECURITY";
		break;
	 case 0x19f7:
		return "WERR_LOG_APPENDED_FLUSH_FAILED";
		break;
	 case 0x19f8:
		return "WERR_LOG_PINNED_RESERVATION";
		break;
	 case 0x1a2c:
		return "WERR_INVALID_TRANSACTION";
		break;
	 case 0x1a2d:
		return "WERR_TRANSACTION_NOT_ACTIVE";
		break;
	 case 0x1a2e:
		return "WERR_TRANSACTION_REQUEST_NOT_VALID";
		break;
	 case 0x1a2f:
		return "WERR_TRANSACTION_NOT_REQUESTED";
		break;
	 case 0x1a30:
		return "WERR_TRANSACTION_ALREADY_ABORTED";
		break;
	 case 0x1a31:
		return "WERR_TRANSACTION_ALREADY_COMMITTED";
		break;
	 case 0x1a32:
		return "WERR_TM_INITIALIZATION_FAILED";
		break;
	 case 0x1a33:
		return "WERR_RESOURCEMANAGER_READ_ONLY";
		break;
	 case 0x1a34:
		return "WERR_TRANSACTION_NOT_JOINED";
		break;
	 case 0x1a35:
		return "WERR_TRANSACTION_SUPERIOR_EXISTS";
		break;
	 case 0x1a36:
		return "WERR_CRM_PROTOCOL_ALREADY_EXISTS";
		break;
	 case 0x1a37:
		return "WERR_TRANSACTION_PROPAGATION_FAILED";
		break;
	 case 0x1a38:
		return "WERR_CRM_PROTOCOL_NOT_FOUND";
		break;
	 case 0x1a39:
		return "WERR_TRANSACTION_INVALID_MARSHALL_BUFFER";
		break;
	 case 0x1a3a:
		return "WERR_CURRENT_TRANSACTION_NOT_VALID";
		break;
	 case 0x1a3b:
		return "WERR_TRANSACTION_NOT_FOUND";
		break;
	 case 0x1a3c:
		return "WERR_RESOURCEMANAGER_NOT_FOUND";
		break;
	 case 0x1a3d:
		return "WERR_ENLISTMENT_NOT_FOUND";
		break;
	 case 0x1a3e:
		return "WERR_TRANSACTIONMANAGER_NOT_FOUND";
		break;
	 case 0x1a3f:
		return "WERR_TRANSACTIONMANAGER_NOT_ONLINE";
		break;
	 case 0x1a40:
		return "WERR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION";
		break;
	 case 0x1a90:
		return "WERR_TRANSACTIONAL_CONFLICT";
		break;
	 case 0x1a91:
		return "WERR_RM_NOT_ACTIVE";
		break;
	 case 0x1a92:
		return "WERR_RM_METADATA_CORRUPT";
		break;
	 case 0x1a93:
		return "WERR_DIRECTORY_NOT_RM";
		break;
	 case 0x1a95:
		return "WERR_TRANSACTIONS_UNSUPPORTED_REMOTE";
		break;
	 case 0x1a96:
		return "WERR_LOG_RESIZE_INVALID_SIZE";
		break;
	 case 0x1a97:
		return "WERR_OBJECT_NO_LONGER_EXISTS";
		break;
	 case 0x1a98:
		return "WERR_STREAM_MINIVERSION_NOT_FOUND";
		break;
	 case 0x1a99:
		return "WERR_STREAM_MINIVERSION_NOT_VALID";
		break;
	 case 0x1a9a:
		return "WERR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION";
		break;
	 case 0x1a9b:
		return "WERR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT";
		break;
	 case 0x1a9c:
		return "WERR_CANT_CREATE_MORE_STREAM_MINIVERSIONS";
		break;
	 case 0x1a9e:
		return "WERR_REMOTE_FILE_VERSION_MISMATCH";
		break;
	 case 0x1a9f:
		return "WERR_HANDLE_NO_LONGER_VALID";
		break;
	 case 0x1aa0:
		return "WERR_NO_TXF_METADATA";
		break;
	 case 0x1aa1:
		return "WERR_LOG_CORRUPTION_DETECTED";
		break;
	 case 0x1aa2:
		return "WERR_CANT_RECOVER_WITH_HANDLE_OPEN";
		break;
	 case 0x1aa3:
		return "WERR_RM_DISCONNECTED";
		break;
	 case 0x1aa4:
		return "WERR_ENLISTMENT_NOT_SUPERIOR";
		break;
	 case 0x1aa5:
		return "WERR_RECOVERY_NOT_NEEDED";
		break;
	 case 0x1aa6:
		return "WERR_RM_ALREADY_STARTED";
		break;
	 case 0x1aa7:
		return "WERR_FILE_IDENTITY_NOT_PERSISTENT";
		break;
	 case 0x1aa8:
		return "WERR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY";
		break;
	 case 0x1aa9:
		return "WERR_CANT_CROSS_RM_BOUNDARY";
		break;
	 case 0x1aaa:
		return "WERR_TXF_DIR_NOT_EMPTY";
		break;
	 case 0x1aab:
		return "WERR_INDOUBT_TRANSACTIONS_EXIST";
		break;
	 case 0x1aac:
		return "WERR_TM_VOLATILE";
		break;
	 case 0x1aad:
		return "WERR_ROLLBACK_TIMER_EXPIRED";
		break;
	 case 0x1aae:
		return "WERR_TXF_ATTRIBUTE_CORRUPT";
		break;
	 case 0x1aaf:
		return "WERR_EFS_NOT_ALLOWED_IN_TRANSACTION";
		break;
	 case 0x1ab0:
		return "WERR_TRANSACTIONAL_OPEN_NOT_ALLOWED";
		break;
	 case 0x1ab1:
		return "WERR_LOG_GROWTH_FAILED";
		break;
	 case 0x1ab2:
		return "WERR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE";
		break;
	 case 0x1ab3:
		return "WERR_TXF_METADATA_ALREADY_PRESENT";
		break;
	 case 0x1ab4:
		return "WERR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET";
		break;
	 case 0x1ab5:
		return "WERR_TRANSACTION_REQUIRED_PROMOTION";
		break;
	 case 0x1ab6:
		return "WERR_CANNOT_EXECUTE_FILE_IN_TRANSACTION";
		break;
	 case 0x1ab7:
		return "WERR_TRANSACTIONS_NOT_FROZEN";
		break;
	 case 0x1ab8:
		return "WERR_TRANSACTION_FREEZE_IN_PROGRESS";
		break;
	 case 0x1ab9:
		return "WERR_NOT_SNAPSHOT_VOLUME";
		break;
	 case 0x1aba:
		return "WERR_NO_SAVEPOINT_WITH_OPEN_FILES";
		break;
	 case 0x1abb:
		return "WERR_DATA_LOST_REPAIR";
		break;
	 case 0x1abc:
		return "WERR_SPARSE_NOT_ALLOWED_IN_TRANSACTION";
		break;
	 case 0x1abd:
		return "WERR_TM_IDENTITY_MISMATCH";
		break;
	 case 0x1abe:
		return "WERR_FLOATED_SECTION";
		break;
	 case 0x1abf:
		return "WERR_CANNOT_ACCEPT_TRANSACTED_WORK";
		break;
	 case 0x1ac0:
		return "WERR_CANNOT_ABORT_TRANSACTIONS";
		break;
	 case 0x1b59:
		return "WERR_CTX_WINSTATION_NAME_INVALID";
		break;
	 case 0x1b5a:
		return "WERR_CTX_INVALID_PD";
		break;
	 case 0x1b5b:
		return "WERR_CTX_PD_NOT_FOUND";
		break;
	 case 0x1b5c:
		return "WERR_CTX_WD_NOT_FOUND";
		break;
	 case 0x1b5d:
		return "WERR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY";
		break;
	 case 0x1b5e:
		return "WERR_CTX_SERVICE_NAME_COLLISION";
		break;
	 case 0x1b5f:
		return "WERR_CTX_CLOSE_PENDING";
		break;
	 case 0x1b60:
		return "WERR_CTX_NO_OUTBUF";
		break;
	 case 0x1b61:
		return "WERR_CTX_MODEM_INF_NOT_FOUND";
		break;
	 case 0x1b62:
		return "WERR_CTX_INVALID_MODEMNAME";
		break;
	 case 0x1b63:
		return "WERR_CTX_MODEM_RESPONSE_ERROR";
		break;
	 case 0x1b64:
		return "WERR_CTX_MODEM_RESPONSE_TIMEOUT";
		break;
	 case 0x1b65:
		return "WERR_CTX_MODEM_RESPONSE_NO_CARRIER";
		break;
	 case 0x1b66:
		return "WERR_CTX_MODEM_RESPONSE_NO_DIALTONE";
		break;
	 case 0x1b67:
		return "WERR_CTX_MODEM_RESPONSE_BUSY";
		break;
	 case 0x1b68:
		return "WERR_CTX_MODEM_RESPONSE_VOICE";
		break;
	 case 0x1b69:
		return "WERR_CTX_TD_ERROR";
		break;
	 case 0x1b6e:
		return "WERR_CTX_WINSTATION_NOT_FOUND";
		break;
	 case 0x1b6f:
		return "WERR_CTX_WINSTATION_ALREADY_EXISTS";
		break;
	 case 0x1b70:
		return "WERR_CTX_WINSTATION_BUSY";
		break;
	 case 0x1b71:
		return "WERR_CTX_BAD_VIDEO_MODE";
		break;
	 case 0x1b7b:
		return "WERR_CTX_GRAPHICS_INVALID";
		break;
	 case 0x1b7d:
		return "WERR_CTX_LOGON_DISABLED";
		break;
	 case 0x1b7e:
		return "WERR_CTX_NOT_CONSOLE";
		break;
	 case 0x1b80:
		return "WERR_CTX_CLIENT_QUERY_TIMEOUT";
		break;
	 case 0x1b81:
		return "WERR_CTX_CONSOLE_DISCONNECT";
		break;
	 case 0x1b82:
		return "WERR_CTX_CONSOLE_CONNECT";
		break;
	 case 0x1b84:
		return "WERR_CTX_SHADOW_DENIED";
		break;
	 case 0x1b85:
		return "WERR_CTX_WINSTATION_ACCESS_DENIED";
		break;
	 case 0x1b89:
		return "WERR_CTX_INVALID_WD";
		break;
	 case 0x1b8a:
		return "WERR_CTX_SHADOW_INVALID";
		break;
	 case 0x1b8b:
		return "WERR_CTX_SHADOW_DISABLED";
		break;
	 case 0x1b8c:
		return "WERR_CTX_CLIENT_LICENSE_IN_USE";
		break;
	 case 0x1b8d:
		return "WERR_CTX_CLIENT_LICENSE_NOT_SET";
		break;
	 case 0x1b8e:
		return "WERR_CTX_LICENSE_NOT_AVAILABLE";
		break;
	 case 0x1b8f:
		return "WERR_CTX_LICENSE_CLIENT_INVALID";
		break;
	 case 0x1b90:
		return "WERR_CTX_LICENSE_EXPIRED";
		break;
	 case 0x1b91:
		return "WERR_CTX_SHADOW_NOT_RUNNING";
		break;
	 case 0x1b92:
		return "WERR_CTX_SHADOW_ENDED_BY_MODE_CHANGE";
		break;
	 case 0x1b93:
		return "WERR_ACTIVATION_COUNT_EXCEEDED";
		break;
	 case 0x1b94:
		return "WERR_CTX_WINSTATIONS_DISABLED";
		break;
	 case 0x1b95:
		return "WERR_CTX_ENCRYPTION_LEVEL_REQUIRED";
		break;
	 case 0x1b96:
		return "WERR_CTX_SESSION_IN_USE";
		break;
	 case 0x1b97:
		return "WERR_CTX_NO_FORCE_LOGOFF";
		break;
	 case 0x1b98:
		return "WERR_CTX_ACCOUNT_RESTRICTION";
		break;
	 case 0x1b99:
		return "WERR_RDP_PROTOCOL_ERROR";
		break;
	 case 0x1b9a:
		return "WERR_CTX_CDM_CONNECT";
		break;
	 case 0x1b9b:
		return "WERR_CTX_CDM_DISCONNECT";
		break;
	 case 0x1b9c:
		return "WERR_CTX_SECURITY_LAYER_ERROR";
		break;
	 case 0x1b9d:
		return "WERR_TS_INCOMPATIBLE_SESSIONS";
		break;
	 case 0x1f41:
		return "WERR_FRS_ERR_INVALID_API_SEQUENCE";
		break;
	 case 0x1f42:
		return "WERR_FRS_ERR_STARTING_SERVICE";
		break;
	 case 0x1f43:
		return "WERR_FRS_ERR_STOPPING_SERVICE";
		break;
	 case 0x1f44:
		return "WERR_FRS_ERR_INTERNAL_API";
		break;
	 case 0x1f45:
		return "WERR_FRS_ERR_INTERNAL";
		break;
	 case 0x1f46:
		return "WERR_FRS_ERR_SERVICE_COMM";
		break;
	 case 0x1f47:
		return "WERR_FRS_ERR_INSUFFICIENT_PRIV";
		break;
	 case 0x1f48:
		return "WERR_FRS_ERR_AUTHENTICATION";
		break;
	 case 0x1f49:
		return "WERR_FRS_ERR_PARENT_INSUFFICIENT_PRIV";
		break;
	 case 0x1f4a:
		return "WERR_FRS_ERR_PARENT_AUTHENTICATION";
		break;
	 case 0x1f4b:
		return "WERR_FRS_ERR_CHILD_TO_PARENT_COMM";
		break;
	 case 0x1f4c:
		return "WERR_FRS_ERR_PARENT_TO_CHILD_COMM";
		break;
	 case 0x1f4d:
		return "WERR_FRS_ERR_SYSVOL_POPULATE";
		break;
	 case 0x1f4e:
		return "WERR_FRS_ERR_SYSVOL_POPULATE_TIMEOUT";
		break;
	 case 0x1f4f:
		return "WERR_FRS_ERR_SYSVOL_IS_BUSY";
		break;
	 case 0x1f50:
		return "WERR_FRS_ERR_SYSVOL_DEMOTE";
		break;
	 case 0x1f51:
		return "WERR_FRS_ERR_INVALID_SERVICE_PARAMETER";
		break;
	 case 0x2008:
		return "WERR_DS_NOT_INSTALLED";
		break;
	 case 0x2009:
		return "WERR_DS_MEMBERSHIP_EVALUATED_LOCALLY";
		break;
	 case 0x200a:
		return "WERR_DS_NO_ATTRIBUTE_OR_VALUE";
		break;
	 case 0x200b:
		return "WERR_DS_INVALID_ATTRIBUTE_SYNTAX";
		break;
	 case 0x200c:
		return "WERR_DS_ATTRIBUTE_TYPE_UNDEFINED";
		break;
	 case 0x200d:
		return "WERR_DS_ATTRIBUTE_OR_VALUE_EXISTS";
		break;
	 case 0x200e:
		return "WERR_DS_BUSY";
		break;
	 case 0x200f:
		return "WERR_DS_UNAVAILABLE";
		break;
	 case 0x2010:
		return "WERR_DS_NO_RIDS_ALLOCATED";
		break;
	 case 0x2011:
		return "WERR_DS_NO_MORE_RIDS";
		break;
	 case 0x2012:
		return "WERR_DS_INCORRECT_ROLE_OWNER";
		break;
	 case 0x2013:
		return "WERR_DS_RIDMGR_INIT_ERROR";
		break;
	 case 0x2014:
		return "WERR_DS_OBJ_CLASS_VIOLATION";
		break;
	 case 0x2015:
		return "WERR_DS_CANT_ON_NON_LEAF";
		break;
	 case 0x2016:
		return "WERR_DS_CANT_ON_RDN";
		break;
	 case 0x2017:
		return "WERR_DS_CANT_MOD_OBJ_CLASS";
		break;
	 case 0x2018:
		return "WERR_DS_CROSS_DOM_MOVE_ERROR";
		break;
	 case 0x2019:
		return "WERR_DS_GC_NOT_AVAILABLE";
		break;
	 case 0x201a:
		return "WERR_SHARED_POLICY";
		break;
	 case 0x201b:
		return "WERR_POLICY_OBJECT_NOT_FOUND";
		break;
	 case 0x201c:
		return "WERR_POLICY_ONLY_IN_DS";
		break;
	 case 0x201d:
		return "WERR_PROMOTION_ACTIVE";
		break;
	 case 0x201e:
		return "WERR_NO_PROMOTION_ACTIVE";
		break;
	 case 0x2020:
		return "WERR_DS_OPERATIONS_ERROR";
		break;
	 case 0x2021:
		return "WERR_DS_PROTOCOL_ERROR";
		break;
	 case 0x2022:
		return "WERR_DS_TIMELIMIT_EXCEEDED";
		break;
	 case 0x2023:
		return "WERR_DS_SIZELIMIT_EXCEEDED";
		break;
	 case 0x2024:
		return "WERR_DS_ADMIN_LIMIT_EXCEEDED";
		break;
	 case 0x2025:
		return "WERR_DS_COMPARE_FALSE";
		break;
	 case 0x2026:
		return "WERR_DS_COMPARE_TRUE";
		break;
	 case 0x2027:
		return "WERR_DS_AUTH_METHOD_NOT_SUPPORTED";
		break;
	 case 0x2028:
		return "WERR_DS_STRONG_AUTH_REQUIRED";
		break;
	 case 0x2029:
		return "WERR_DS_INAPPROPRIATE_AUTH";
		break;
	 case 0x202a:
		return "WERR_DS_AUTH_UNKNOWN";
		break;
	 case 0x202b:
		return "WERR_DS_REFERRAL";
		break;
	 case 0x202c:
		return "WERR_DS_UNAVAILABLE_CRIT_EXTENSION";
		break;
	 case 0x202d:
		return "WERR_DS_CONFIDENTIALITY_REQUIRED";
		break;
	 case 0x202e:
		return "WERR_DS_INAPPROPRIATE_MATCHING";
		break;
	 case 0x202f:
		return "WERR_DS_CONSTRAINT_VIOLATION";
		break;
	 case 0x2030:
		return "WERR_DS_NO_SUCH_OBJECT";
		break;
	 case 0x2031:
		return "WERR_DS_ALIAS_PROBLEM";
		break;
	 case 0x2032:
		return "WERR_DS_INVALID_DN_SYNTAX";
		break;
	 case 0x2033:
		return "WERR_DS_IS_LEAF";
		break;
	 case 0x2034:
		return "WERR_DS_ALIAS_DEREF_PROBLEM";
		break;
	 case 0x2035:
		return "WERR_DS_UNWILLING_TO_PERFORM";
		break;
	 case 0x2036:
		return "WERR_DS_LOOP_DETECT";
		break;
	 case 0x2037:
		return "WERR_DS_NAMING_VIOLATION";
		break;
	 case 0x2038:
		return "WERR_DS_OBJECT_RESULTS_TOO_LARGE";
		break;
	 case 0x2039:
		return "WERR_DS_AFFECTS_MULTIPLE_DSAS";
		break;
	 case 0x203a:
		return "WERR_DS_SERVER_DOWN";
		break;
	 case 0x203b:
		return "WERR_DS_LOCAL_ERROR";
		break;
	 case 0x203c:
		return "WERR_DS_ENCODING_ERROR";
		break;
	 case 0x203d:
		return "WERR_DS_DECODING_ERROR";
		break;
	 case 0x203e:
		return "WERR_DS_FILTER_UNKNOWN";
		break;
	 case 0x203f:
		return "WERR_DS_PARAM_ERROR";
		break;
	 case 0x2040:
		return "WERR_DS_NOT_SUPPORTED";
		break;
	 case 0x2041:
		return "WERR_DS_NO_RESULTS_RETURNED";
		break;
	 case 0x2042:
		return "WERR_DS_CONTROL_NOT_FOUND";
		break;
	 case 0x2043:
		return "WERR_DS_CLIENT_LOOP";
		break;
	 case 0x2044:
		return "WERR_DS_REFERRAL_LIMIT_EXCEEDED";
		break;
	 case 0x2045:
		return "WERR_DS_SORT_CONTROL_MISSING";
		break;
	 case 0x2046:
		return "WERR_DS_OFFSET_RANGE_ERROR";
		break;
	 case 0x206d:
		return "WERR_DS_ROOT_MUST_BE_NC";
		break;
	 case 0x206e:
		return "WERR_DS_ADD_REPLICA_INHIBITED";
		break;
	 case 0x206f:
		return "WERR_DS_ATT_NOT_DEF_IN_SCHEMA";
		break;
	 case 0x2070:
		return "WERR_DS_MAX_OBJ_SIZE_EXCEEDED";
		break;
	 case 0x2071:
		return "WERR_DS_OBJ_STRING_NAME_EXISTS";
		break;
	 case 0x2072:
		return "WERR_DS_NO_RDN_DEFINED_IN_SCHEMA";
		break;
	 case 0x2073:
		return "WERR_DS_RDN_DOESNT_MATCH_SCHEMA";
		break;
	 case 0x2074:
		return "WERR_DS_NO_REQUESTED_ATTS_FOUND";
		break;
	 case 0x2075:
		return "WERR_DS_USER_BUFFER_TO_SMALL";
		break;
	 case 0x2076:
		return "WERR_DS_ATT_IS_NOT_ON_OBJ";
		break;
	 case 0x2077:
		return "WERR_DS_ILLEGAL_MOD_OPERATION";
		break;
	 case 0x2078:
		return "WERR_DS_OBJ_TOO_LARGE";
		break;
	 case 0x2079:
		return "WERR_DS_BAD_INSTANCE_TYPE";
		break;
	 case 0x207a:
		return "WERR_DS_MASTERDSA_REQUIRED";
		break;
	 case 0x207b:
		return "WERR_DS_OBJECT_CLASS_REQUIRED";
		break;
	 case 0x207c:
		return "WERR_DS_MISSING_REQUIRED_ATT";
		break;
	 case 0x207d:
		return "WERR_DS_ATT_NOT_DEF_FOR_CLASS";
		break;
	 case 0x207e:
		return "WERR_DS_ATT_ALREADY_EXISTS";
		break;
	 case 0x2080:
		return "WERR_DS_CANT_ADD_ATT_VALUES";
		break;
	 case 0x2081:
		return "WERR_DS_SINGLE_VALUE_CONSTRAINT";
		break;
	 case 0x2082:
		return "WERR_DS_RANGE_CONSTRAINT";
		break;
	 case 0x2083:
		return "WERR_DS_ATT_VAL_ALREADY_EXISTS";
		break;
	 case 0x2084:
		return "WERR_DS_CANT_REM_MISSING_ATT";
		break;
	 case 0x2085:
		return "WERR_DS_CANT_REM_MISSING_ATT_VAL";
		break;
	 case 0x2086:
		return "WERR_DS_ROOT_CANT_BE_SUBREF";
		break;
	 case 0x2087:
		return "WERR_DS_NO_CHAINING";
		break;
	 case 0x2088:
		return "WERR_DS_NO_CHAINED_EVAL";
		break;
	 case 0x2089:
		return "WERR_DS_NO_PARENT_OBJECT";
		break;
	 case 0x208a:
		return "WERR_DS_PARENT_IS_AN_ALIAS";
		break;
	 case 0x208b:
		return "WERR_DS_CANT_MIX_MASTER_AND_REPS";
		break;
	 case 0x208c:
		return "WERR_DS_CHILDREN_EXIST";
		break;
	 case 0x208d:
		return "WERR_DS_OBJ_NOT_FOUND";
		break;
	 case 0x208e:
		return "WERR_DS_ALIASED_OBJ_MISSING";
		break;
	 case 0x208f:
		return "WERR_DS_BAD_NAME_SYNTAX";
		break;
	 case 0x2090:
		return "WERR_DS_ALIAS_POINTS_TO_ALIAS";
		break;
	 case 0x2091:
		return "WERR_DS_CANT_DEREF_ALIAS";
		break;
	 case 0x2092:
		return "WERR_DS_OUT_OF_SCOPE";
		break;
	 case 0x2093:
		return "WERR_DS_OBJECT_BEING_REMOVED";
		break;
	 case 0x2094:
		return "WERR_DS_CANT_DELETE_DSA_OBJ";
		break;
	 case 0x2095:
		return "WERR_DS_GENERIC_ERROR";
		break;
	 case 0x2096:
		return "WERR_DS_DSA_MUST_BE_INT_MASTER";
		break;
	 case 0x2097:
		return "WERR_DS_CLASS_NOT_DSA";
		break;
	 case 0x2098:
		return "WERR_DS_INSUFF_ACCESS_RIGHTS";
		break;
	 case 0x2099:
		return "WERR_DS_ILLEGAL_SUPERIOR";
		break;
	 case 0x209a:
		return "WERR_DS_ATTRIBUTE_OWNED_BY_SAM";
		break;
	 case 0x209b:
		return "WERR_DS_NAME_TOO_MANY_PARTS";
		break;
	 case 0x209c:
		return "WERR_DS_NAME_TOO_LONG";
		break;
	 case 0x209d:
		return "WERR_DS_NAME_VALUE_TOO_LONG";
		break;
	 case 0x209e:
		return "WERR_DS_NAME_UNPARSEABLE";
		break;
	 case 0x209f:
		return "WERR_DS_NAME_TYPE_UNKNOWN";
		break;
	 case 0x20a0:
		return "WERR_DS_NOT_AN_OBJECT";
		break;
	 case 0x20a1:
		return "WERR_DS_SEC_DESC_TOO_SHORT";
		break;
	 case 0x20a2:
		return "WERR_DS_SEC_DESC_INVALID";
		break;
	 case 0x20a3:
		return "WERR_DS_NO_DELETED_NAME";
		break;
	 case 0x20a4:
		return "WERR_DS_SUBREF_MUST_HAVE_PARENT";
		break;
	 case 0x20a5:
		return "WERR_DS_NCNAME_MUST_BE_NC";
		break;
	 case 0x20a6:
		return "WERR_DS_CANT_ADD_SYSTEM_ONLY";
		break;
	 case 0x20a7:
		return "WERR_DS_CLASS_MUST_BE_CONCRETE";
		break;
	 case 0x20a8:
		return "WERR_DS_INVALID_DMD";
		break;
	 case 0x20a9:
		return "WERR_DS_OBJ_GUID_EXISTS";
		break;
	 case 0x20aa:
		return "WERR_DS_NOT_ON_BACKLINK";
		break;
	 case 0x20ab:
		return "WERR_DS_NO_CROSSREF_FOR_NC";
		break;
	 case 0x20ac:
		return "WERR_DS_SHUTTING_DOWN";
		break;
	 case 0x20ad:
		return "WERR_DS_UNKNOWN_OPERATION";
		break;
	 case 0x20ae:
		return "WERR_DS_INVALID_ROLE_OWNER";
		break;
	 case 0x20af:
		return "WERR_DS_COULDNT_CONTACT_FSMO";
		break;
	 case 0x20b0:
		return "WERR_DS_CROSS_NC_DN_RENAME";
		break;
	 case 0x20b1:
		return "WERR_DS_CANT_MOD_SYSTEM_ONLY";
		break;
	 case 0x20b2:
		return "WERR_DS_REPLICATOR_ONLY";
		break;
	 case 0x20b3:
		return "WERR_DS_OBJ_CLASS_NOT_DEFINED";
		break;
	 case 0x20b4:
		return "WERR_DS_OBJ_CLASS_NOT_SUBCLASS";
		break;
	 case 0x20b5:
		return "WERR_DS_NAME_REFERENCE_INVALID";
		break;
	 case 0x20b6:
		return "WERR_DS_CROSS_REF_EXISTS";
		break;
	 case 0x20b7:
		return "WERR_DS_CANT_DEL_MASTER_CROSSREF";
		break;
	 case 0x20b8:
		return "WERR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD";
		break;
	 case 0x20b9:
		return "WERR_DS_NOTIFY_FILTER_TOO_COMPLEX";
		break;
	 case 0x20ba:
		return "WERR_DS_DUP_RDN";
		break;
	 case 0x20bb:
		return "WERR_DS_DUP_OID";
		break;
	 case 0x20bc:
		return "WERR_DS_DUP_MAPI_ID";
		break;
	 case 0x20bd:
		return "WERR_DS_DUP_SCHEMA_ID_GUID";
		break;
	 case 0x20be:
		return "WERR_DS_DUP_LDAP_DISPLAY_NAME";
		break;
	 case 0x20bf:
		return "WERR_DS_SEMANTIC_ATT_TEST";
		break;
	 case 0x20c0:
		return "WERR_DS_SYNTAX_MISMATCH";
		break;
	 case 0x20c1:
		return "WERR_DS_EXISTS_IN_MUST_HAVE";
		break;
	 case 0x20c2:
		return "WERR_DS_EXISTS_IN_MAY_HAVE";
		break;
	 case 0x20c3:
		return "WERR_DS_NONEXISTENT_MAY_HAVE";
		break;
	 case 0x20c4:
		return "WERR_DS_NONEXISTENT_MUST_HAVE";
		break;
	 case 0x20c5:
		return "WERR_DS_AUX_CLS_TEST_FAIL";
		break;
	 case 0x20c6:
		return "WERR_DS_NONEXISTENT_POSS_SUP";
		break;
	 case 0x20c7:
		return "WERR_DS_SUB_CLS_TEST_FAIL";
		break;
	 case 0x20c8:
		return "WERR_DS_BAD_RDN_ATT_ID_SYNTAX";
		break;
	 case 0x20c9:
		return "WERR_DS_EXISTS_IN_AUX_CLS";
		break;
	 case 0x20ca:
		return "WERR_DS_EXISTS_IN_SUB_CLS";
		break;
	 case 0x20cb:
		return "WERR_DS_EXISTS_IN_POSS_SUP";
		break;
	 case 0x20cc:
		return "WERR_DS_RECALCSCHEMA_FAILED";
		break;
	 case 0x20cd:
		return "WERR_DS_TREE_DELETE_NOT_FINISHED";
		break;
	 case 0x20ce:
		return "WERR_DS_CANT_DELETE";
		break;
	 case 0x20cf:
		return "WERR_DS_ATT_SCHEMA_REQ_ID";
		break;
	 case 0x20d0:
		return "WERR_DS_BAD_ATT_SCHEMA_SYNTAX";
		break;
	 case 0x20d1:
		return "WERR_DS_CANT_CACHE_ATT";
		break;
	 case 0x20d2:
		return "WERR_DS_CANT_CACHE_CLASS";
		break;
	 case 0x20d3:
		return "WERR_DS_CANT_REMOVE_ATT_CACHE";
		break;
	 case 0x20d4:
		return "WERR_DS_CANT_REMOVE_CLASS_CACHE";
		break;
	 case 0x20d5:
		return "WERR_DS_CANT_RETRIEVE_DN";
		break;
	 case 0x20d6:
		return "WERR_DS_MISSING_SUPREF";
		break;
	 case 0x20d7:
		return "WERR_DS_CANT_RETRIEVE_INSTANCE";
		break;
	 case 0x20d8:
		return "WERR_DS_CODE_INCONSISTENCY";
		break;
	 case 0x20d9:
		return "WERR_DS_DATABASE_ERROR";
		break;
	 case 0x20da:
		return "WERR_DS_GOVERNSID_MISSING";
		break;
	 case 0x20db:
		return "WERR_DS_MISSING_EXPECTED_ATT";
		break;
	 case 0x20dc:
		return "WERR_DS_NCNAME_MISSING_CR_REF";
		break;
	 case 0x20dd:
		return "WERR_DS_SECURITY_CHECKING_ERROR";
		break;
	 case 0x20de:
		return "WERR_DS_SCHEMA_NOT_LOADED";
		break;
	 case 0x20df:
		return "WERR_DS_SCHEMA_ALLOC_FAILED";
		break;
	 case 0x20e0:
		return "WERR_DS_ATT_SCHEMA_REQ_SYNTAX";
		break;
	 case 0x20e1:
		return "WERR_DS_GCVERIFY_ERROR";
		break;
	 case 0x20e2:
		return "WERR_DS_DRA_SCHEMA_MISMATCH";
		break;
	 case 0x20e3:
		return "WERR_DS_CANT_FIND_DSA_OBJ";
		break;
	 case 0x20e4:
		return "WERR_DS_CANT_FIND_EXPECTED_NC";
		break;
	 case 0x20e5:
		return "WERR_DS_CANT_FIND_NC_IN_CACHE";
		break;
	 case 0x20e6:
		return "WERR_DS_CANT_RETRIEVE_CHILD";
		break;
	 case 0x20e7:
		return "WERR_DS_SECURITY_ILLEGAL_MODIFY";
		break;
	 case 0x20e8:
		return "WERR_DS_CANT_REPLACE_HIDDEN_REC";
		break;
	 case 0x20e9:
		return "WERR_DS_BAD_HIERARCHY_FILE";
		break;
	 case 0x20ea:
		return "WERR_DS_BUILD_HIERARCHY_TABLE_FAILED";
		break;
	 case 0x20eb:
		return "WERR_DS_CONFIG_PARAM_MISSING";
		break;
	 case 0x20ec:
		return "WERR_DS_COUNTING_AB_INDICES_FAILED";
		break;
	 case 0x20ed:
		return "WERR_DS_HIERARCHY_TABLE_MALLOC_FAILED";
		break;
	 case 0x20ee:
		return "WERR_DS_INTERNAL_FAILURE";
		break;
	 case 0x20ef:
		return "WERR_DS_UNKNOWN_ERROR";
		break;
	 case 0x20f0:
		return "WERR_DS_ROOT_REQUIRES_CLASS_TOP";
		break;
	 case 0x20f1:
		return "WERR_DS_REFUSING_FSMO_ROLES";
		break;
	 case 0x20f2:
		return "WERR_DS_MISSING_FSMO_SETTINGS";
		break;
	 case 0x20f3:
		return "WERR_DS_UNABLE_TO_SURRENDER_ROLES";
		break;
	 case 0x20f4:
		return "WERR_DS_DRA_GENERIC";
		break;
	 case 0x20f5:
		return "WERR_DS_DRA_INVALID_PARAMETER";
		break;
	 case 0x20f6:
		return "WERR_DS_DRA_BUSY";
		break;
	 case 0x20f7:
		return "WERR_DS_DRA_BAD_DN";
		break;
	 case 0x20f8:
		return "WERR_DS_DRA_BAD_NC";
		break;
	 case 0x20f9:
		return "WERR_DS_DRA_DN_EXISTS";
		break;
	 case 0x20fa:
		return "WERR_DS_DRA_INTERNAL_ERROR";
		break;
	 case 0x20fb:
		return "WERR_DS_DRA_INCONSISTENT_DIT";
		break;
	 case 0x20fc:
		return "WERR_DS_DRA_CONNECTION_FAILED";
		break;
	 case 0x20fd:
		return "WERR_DS_DRA_BAD_INSTANCE_TYPE";
		break;
	 case 0x20fe:
		return "WERR_DS_DRA_OUT_OF_MEM";
		break;
	 case 0x20ff:
		return "WERR_DS_DRA_MAIL_PROBLEM";
		break;
	 case 0x2100:
		return "WERR_DS_DRA_REF_ALREADY_EXISTS";
		break;
	 case 0x2101:
		return "WERR_DS_DRA_REF_NOT_FOUND";
		break;
	 case 0x2102:
		return "WERR_DS_DRA_OBJ_IS_REP_SOURCE";
		break;
	 case 0x2103:
		return "WERR_DS_DRA_DB_ERROR";
		break;
	 case 0x2104:
		return "WERR_DS_DRA_NO_REPLICA";
		break;
	 case 0x2105:
		return "WERR_DS_DRA_ACCESS_DENIED";
		break;
	 case 0x2106:
		return "WERR_DS_DRA_NOT_SUPPORTED";
		break;
	 case 0x2107:
		return "WERR_DS_DRA_RPC_CANCELLED";
		break;
	 case 0x2108:
		return "WERR_DS_DRA_SOURCE_DISABLED";
		break;
	 case 0x2109:
		return "WERR_DS_DRA_SINK_DISABLED";
		break;
	 case 0x210a:
		return "WERR_DS_DRA_NAME_COLLISION";
		break;
	 case 0x210b:
		return "WERR_DS_DRA_SOURCE_REINSTALLED";
		break;
	 case 0x210c:
		return "WERR_DS_DRA_MISSING_PARENT";
		break;
	 case 0x210d:
		return "WERR_DS_DRA_PREEMPTED";
		break;
	 case 0x210e:
		return "WERR_DS_DRA_ABANDON_SYNC";
		break;
	 case 0x210f:
		return "WERR_DS_DRA_SHUTDOWN";
		break;
	 case 0x2110:
		return "WERR_DS_DRA_INCOMPATIBLE_PARTIAL_SET";
		break;
	 case 0x2111:
		return "WERR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA";
		break;
	 case 0x2112:
		return "WERR_DS_DRA_EXTN_CONNECTION_FAILED";
		break;
	 case 0x2113:
		return "WERR_DS_INSTALL_SCHEMA_MISMATCH";
		break;
	 case 0x2114:
		return "WERR_DS_DUP_LINK_ID";
		break;
	 case 0x2115:
		return "WERR_DS_NAME_ERROR_RESOLVING";
		break;
	 case 0x2116:
		return "WERR_DS_NAME_ERROR_NOT_FOUND";
		break;
	 case 0x2117:
		return "WERR_DS_NAME_ERROR_NOT_UNIQUE";
		break;
	 case 0x2118:
		return "WERR_DS_NAME_ERROR_NO_MAPPING";
		break;
	 case 0x2119:
		return "WERR_DS_NAME_ERROR_DOMAIN_ONLY";
		break;
	 case 0x211a:
		return "WERR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING";
		break;
	 case 0x211b:
		return "WERR_DS_CONSTRUCTED_ATT_MOD";
		break;
	 case 0x211c:
		return "WERR_DS_WRONG_OM_OBJ_CLASS";
		break;
	 case 0x211d:
		return "WERR_DS_DRA_REPL_PENDING";
		break;
	 case 0x211e:
		return "WERR_DS_DS_REQUIRED";
		break;
	 case 0x211f:
		return "WERR_DS_INVALID_LDAP_DISPLAY_NAME";
		break;
	 case 0x2120:
		return "WERR_DS_NON_BASE_SEARCH";
		break;
	 case 0x2121:
		return "WERR_DS_CANT_RETRIEVE_ATTS";
		break;
	 case 0x2122:
		return "WERR_DS_BACKLINK_WITHOUT_LINK";
		break;
	 case 0x2123:
		return "WERR_DS_EPOCH_MISMATCH";
		break;
	 case 0x2124:
		return "WERR_DS_SRC_NAME_MISMATCH";
		break;
	 case 0x2125:
		return "WERR_DS_SRC_AND_DST_NC_IDENTICAL";
		break;
	 case 0x2126:
		return "WERR_DS_DST_NC_MISMATCH";
		break;
	 case 0x2127:
		return "WERR_DS_NOT_AUTHORITIVE_FOR_DST_NC";
		break;
	 case 0x2128:
		return "WERR_DS_SRC_GUID_MISMATCH";
		break;
	 case 0x2129:
		return "WERR_DS_CANT_MOVE_DELETED_OBJECT";
		break;
	 case 0x212a:
		return "WERR_DS_PDC_OPERATION_IN_PROGRESS";
		break;
	 case 0x212b:
		return "WERR_DS_CROSS_DOMAIN_CLEANUP_REQD";
		break;
	 case 0x212c:
		return "WERR_DS_ILLEGAL_XDOM_MOVE_OPERATION";
		break;
	 case 0x212d:
		return "WERR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS";
		break;
	 case 0x212e:
		return "WERR_DS_NC_MUST_HAVE_NC_PARENT";
		break;
	 case 0x212f:
		return "WERR_DS_CR_IMPOSSIBLE_TO_VALIDATE";
		break;
	 case 0x2130:
		return "WERR_DS_DST_DOMAIN_NOT_NATIVE";
		break;
	 case 0x2131:
		return "WERR_DS_MISSING_INFRASTRUCTURE_CONTAINER";
		break;
	 case 0x2132:
		return "WERR_DS_CANT_MOVE_ACCOUNT_GROUP";
		break;
	 case 0x2133:
		return "WERR_DS_CANT_MOVE_RESOURCE_GROUP";
		break;
	 case 0x2134:
		return "WERR_DS_INVALID_SEARCH_FLAG";
		break;
	 case 0x2135:
		return "WERR_DS_NO_TREE_DELETE_ABOVE_NC";
		break;
	 case 0x2136:
		return "WERR_DS_COULDNT_LOCK_TREE_FOR_DELETE";
		break;
	 case 0x2137:
		return "WERR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE";
		break;
	 case 0x2138:
		return "WERR_DS_SAM_INIT_FAILURE";
		break;
	 case 0x2139:
		return "WERR_DS_SENSITIVE_GROUP_VIOLATION";
		break;
	 case 0x213a:
		return "WERR_DS_CANT_MOD_PRIMARYGROUPID";
		break;
	 case 0x213b:
		return "WERR_DS_ILLEGAL_BASE_SCHEMA_MOD";
		break;
	 case 0x213c:
		return "WERR_DS_NONSAFE_SCHEMA_CHANGE";
		break;
	 case 0x213d:
		return "WERR_DS_SCHEMA_UPDATE_DISALLOWED";
		break;
	 case 0x213e:
		return "WERR_DS_CANT_CREATE_UNDER_SCHEMA";
		break;
	 case 0x213f:
		return "WERR_DS_INSTALL_NO_SRC_SCH_VERSION";
		break;
	 case 0x2140:
		return "WERR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE";
		break;
	 case 0x2141:
		return "WERR_DS_INVALID_GROUP_TYPE";
		break;
	 case 0x2142:
		return "WERR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN";
		break;
	 case 0x2143:
		return "WERR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN";
		break;
	 case 0x2144:
		return "WERR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER";
		break;
	 case 0x2145:
		return "WERR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER";
		break;
	 case 0x2146:
		return "WERR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER";
		break;
	 case 0x2147:
		return "WERR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER";
		break;
	 case 0x2148:
		return "WERR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER";
		break;
	 case 0x2149:
		return "WERR_DS_HAVE_PRIMARY_MEMBERS";
		break;
	 case 0x214a:
		return "WERR_DS_STRING_SD_CONVERSION_FAILED";
		break;
	 case 0x214b:
		return "WERR_DS_NAMING_MASTER_GC";
		break;
	 case 0x214c:
		return "WERR_DS_DNS_LOOKUP_FAILURE";
		break;
	 case 0x214d:
		return "WERR_DS_COULDNT_UPDATE_SPNS";
		break;
	 case 0x214e:
		return "WERR_DS_CANT_RETRIEVE_SD";
		break;
	 case 0x214f:
		return "WERR_DS_KEY_NOT_UNIQUE";
		break;
	 case 0x2150:
		return "WERR_DS_WRONG_LINKED_ATT_SYNTAX";
		break;
	 case 0x2151:
		return "WERR_DS_SAM_NEED_BOOTKEY_PASSWORD";
		break;
	 case 0x2152:
		return "WERR_DS_SAM_NEED_BOOTKEY_FLOPPY";
		break;
	 case 0x2153:
		return "WERR_DS_CANT_START";
		break;
	 case 0x2154:
		return "WERR_DS_INIT_FAILURE";
		break;
	 case 0x2155:
		return "WERR_DS_NO_PKT_PRIVACY_ON_CONNECTION";
		break;
	 case 0x2156:
		return "WERR_DS_SOURCE_DOMAIN_IN_FOREST";
		break;
	 case 0x2157:
		return "WERR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST";
		break;
	 case 0x2158:
		return "WERR_DS_DESTINATION_AUDITING_NOT_ENABLED";
		break;
	 case 0x2159:
		return "WERR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN";
		break;
	 case 0x215a:
		return "WERR_DS_SRC_OBJ_NOT_GROUP_OR_USER";
		break;
	 case 0x215b:
		return "WERR_DS_SRC_SID_EXISTS_IN_FOREST";
		break;
	 case 0x215c:
		return "WERR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH";
		break;
	 case 0x215d:
		return "WERR_SAM_INIT_FAILURE";
		break;
	 case 0x215e:
		return "WERR_DS_DRA_SCHEMA_INFO_SHIP";
		break;
	 case 0x215f:
		return "WERR_DS_DRA_SCHEMA_CONFLICT";
		break;
	 case 0x2160:
		return "WERR_DS_DRA_EARLIER_SCHEMA_CONFLICT";
		break;
	 case 0x2161:
		return "WERR_DS_DRA_OBJ_NC_MISMATCH";
		break;
	 case 0x2162:
		return "WERR_DS_NC_STILL_HAS_DSAS";
		break;
	 case 0x2163:
		return "WERR_DS_GC_REQUIRED";
		break;
	 case 0x2164:
		return "WERR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY";
		break;
	 case 0x2165:
		return "WERR_DS_NO_FPO_IN_UNIVERSAL_GROUPS";
		break;
	 case 0x2166:
		return "WERR_DS_CANT_ADD_TO_GC";
		break;
	 case 0x2167:
		return "WERR_DS_NO_CHECKPOINT_WITH_PDC";
		break;
	 case 0x2168:
		return "WERR_DS_SOURCE_AUDITING_NOT_ENABLED";
		break;
	 case 0x2169:
		return "WERR_DS_CANT_CREATE_IN_NONDOMAIN_NC";
		break;
	 case 0x216a:
		return "WERR_DS_INVALID_NAME_FOR_SPN";
		break;
	 case 0x216b:
		return "WERR_DS_FILTER_USES_CONTRUCTED_ATTRS";
		break;
	 case 0x216c:
		return "WERR_DS_UNICODEPWD_NOT_IN_QUOTES";
		break;
	 case 0x216d:
		return "WERR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED";
		break;
	 case 0x216e:
		return "WERR_DS_MUST_BE_RUN_ON_DST_DC";
		break;
	 case 0x216f:
		return "WERR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER";
		break;
	 case 0x2170:
		return "WERR_DS_CANT_TREE_DELETE_CRITICAL_OBJ";
		break;
	 case 0x2171:
		return "WERR_DS_INIT_FAILURE_CONSOLE";
		break;
	 case 0x2172:
		return "WERR_DS_SAM_INIT_FAILURE_CONSOLE";
		break;
	 case 0x2173:
		return "WERR_DS_FOREST_VERSION_TOO_HIGH";
		break;
	 case 0x2174:
		return "WERR_DS_DOMAIN_VERSION_TOO_HIGH";
		break;
	 case 0x2175:
		return "WERR_DS_FOREST_VERSION_TOO_LOW";
		break;
	 case 0x2176:
		return "WERR_DS_DOMAIN_VERSION_TOO_LOW";
		break;
	 case 0x2177:
		return "WERR_DS_INCOMPATIBLE_VERSION";
		break;
	 case 0x2178:
		return "WERR_DS_LOW_DSA_VERSION";
		break;
	 case 0x2179:
		return "WERR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN";
		break;
	 case 0x217a:
		return "WERR_DS_NOT_SUPPORTED_SORT_ORDER";
		break;
	 case 0x217b:
		return "WERR_DS_NAME_NOT_UNIQUE";
		break;
	 case 0x217c:
		return "WERR_DS_MACHINE_ACCOUNT_CREATED_PRENT4";
		break;
	 case 0x217d:
		return "WERR_DS_OUT_OF_VERSION_STORE";
		break;
	 case 0x217e:
		return "WERR_DS_INCOMPATIBLE_CONTROLS_USED";
		break;
	 case 0x217f:
		return "WERR_DS_NO_REF_DOMAIN";
		break;
	 case 0x2180:
		return "WERR_DS_RESERVED_LINK_ID";
		break;
	 case 0x2181:
		return "WERR_DS_LINK_ID_NOT_AVAILABLE";
		break;
	 case 0x2182:
		return "WERR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER";
		break;
	 case 0x2183:
		return "WERR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE";
		break;
	 case 0x2184:
		return "WERR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC";
		break;
	 case 0x2185:
		return "WERR_DS_MODIFYDN_DISALLOWED_BY_FLAG";
		break;
	 case 0x2186:
		return "WERR_DS_MODIFYDN_WRONG_GRANDPARENT";
		break;
	 case 0x2187:
		return "WERR_DS_NAME_ERROR_TRUST_REFERRAL";
		break;
	 case 0x2188:
		return "WERR_NOT_SUPPORTED_ON_STANDARD_SERVER";
		break;
	 case 0x2189:
		return "WERR_DS_CANT_ACCESS_REMOTE_PART_OF_AD";
		break;
	 case 0x218a:
		return "WERR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2";
		break;
	 case 0x218b:
		return "WERR_DS_THREAD_LIMIT_EXCEEDED";
		break;
	 case 0x218c:
		return "WERR_DS_NOT_CLOSEST";
		break;
	 case 0x218d:
		return "WERR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF";
		break;
	 case 0x218e:
		return "WERR_DS_SINGLE_USER_MODE_FAILED";
		break;
	 case 0x218f:
		return "WERR_DS_NTDSCRIPT_SYNTAX_ERROR";
		break;
	 case 0x2190:
		return "WERR_DS_NTDSCRIPT_PROCESS_ERROR";
		break;
	 case 0x2191:
		return "WERR_DS_DIFFERENT_REPL_EPOCHS";
		break;
	 case 0x2192:
		return "WERR_DS_DRS_EXTENSIONS_CHANGED";
		break;
	 case 0x2193:
		return "WERR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR";
		break;
	 case 0x2194:
		return "WERR_DS_NO_MSDS_INTID";
		break;
	 case 0x2195:
		return "WERR_DS_DUP_MSDS_INTID";
		break;
	 case 0x2196:
		return "WERR_DS_EXISTS_IN_RDNATTID";
		break;
	 case 0x2197:
		return "WERR_DS_AUTHORIZATION_FAILED";
		break;
	 case 0x2198:
		return "WERR_DS_INVALID_SCRIPT";
		break;
	 case 0x2199:
		return "WERR_DS_REMOTE_CROSSREF_OP_FAILED";
		break;
	 case 0x219a:
		return "WERR_DS_CROSS_REF_BUSY";
		break;
	 case 0x219b:
		return "WERR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN";
		break;
	 case 0x219c:
		return "WERR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC";
		break;
	 case 0x219d:
		return "WERR_DS_DUPLICATE_ID_FOUND";
		break;
	 case 0x219e:
		return "WERR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT";
		break;
	 case 0x219f:
		return "WERR_DS_GROUP_CONVERSION_ERROR";
		break;
	 case 0x21a0:
		return "WERR_DS_CANT_MOVE_APP_BASIC_GROUP";
		break;
	 case 0x21a1:
		return "WERR_DS_CANT_MOVE_APP_QUERY_GROUP";
		break;
	 case 0x21a2:
		return "WERR_DS_ROLE_NOT_VERIFIED";
		break;
	 case 0x21a3:
		return "WERR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL";
		break;
	 case 0x21a4:
		return "WERR_DS_DOMAIN_RENAME_IN_PROGRESS";
		break;
	 case 0x21a5:
		return "WERR_DS_EXISTING_AD_CHILD_NC";
		break;
	 case 0x21a6:
		return "WERR_DS_REPL_LIFETIME_EXCEEDED";
		break;
	 case 0x21a7:
		return "WERR_DS_DISALLOWED_IN_SYSTEM_CONTAINER";
		break;
	 case 0x21a8:
		return "WERR_DS_LDAP_SEND_QUEUE_FULL";
		break;
	 case 0x21a9:
		return "WERR_DS_DRA_OUT_SCHEDULE_WINDOW";
		break;
	 case 0x21aa:
		return "WERR_DS_POLICY_NOT_KNOWN";
		break;
	 case 0x21ab:
		return "WERR_NO_SITE_SETTINGS_OBJECT";
		break;
	 case 0x21ac:
		return "WERR_NO_SECRETS";
		break;
	 case 0x21ad:
		return "WERR_NO_WRITABLE_DC_FOUND";
		break;
	 case 0x21ae:
		return "WERR_DS_NO_SERVER_OBJECT";
		break;
	 case 0x21af:
		return "WERR_DS_NO_NTDSA_OBJECT";
		break;
	 case 0x21b0:
		return "WERR_DS_NON_ASQ_SEARCH";
		break;
	 case 0x21b1:
		return "WERR_DS_AUDIT_FAILURE";
		break;
	 case 0x21b2:
		return "WERR_DS_INVALID_SEARCH_FLAG_SUBTREE";
		break;
	 case 0x21b3:
		return "WERR_DS_INVALID_SEARCH_FLAG_TUPLE";
		break;
	 case 0x21bf:
		return "WERR_DS_DRA_RECYCLED_TARGET";
		break;
	 case 0x21c2:
		return "WERR_DS_HIGH_DSA_VERSION";
		break;
	 case 0x21c7:
		return "WERR_DS_SPN_VALUE_NOT_UNIQUE_IN_FOREST";
		break;
	 case 0x21c8:
		return "WERR_DS_UPN_VALUE_NOT_UNIQUE_IN_FOREST";
		break;
	 case 0x2329:
		return "WERR_DNS_ERROR_RCODE_FORMAT_ERROR";
		break;
	 case 0x232a:
		return "WERR_DNS_ERROR_RCODE_SERVER_FAILURE";
		break;
	 case 0x232b:
		return "WERR_DNS_ERROR_RCODE_NAME_ERROR";
		break;
	 case 0x232c:
		return "WERR_DNS_ERROR_RCODE_NOT_IMPLEMENTED";
		break;
	 case 0x232d:
		return "WERR_DNS_ERROR_RCODE_REFUSED";
		break;
	 case 0x232e:
		return "WERR_DNS_ERROR_RCODE_YXDOMAIN";
		break;
	 case 0x232f:
		return "WERR_DNS_ERROR_RCODE_YXRRSET";
		break;
	 case 0x2330:
		return "WERR_DNS_ERROR_RCODE_NXRRSET";
		break;
	 case 0x2331:
		return "WERR_DNS_ERROR_RCODE_NOTAUTH";
		break;
	 case 0x2332:
		return "WERR_DNS_ERROR_RCODE_NOTZONE";
		break;
	 case 0x2338:
		return "WERR_DNS_ERROR_RCODE_BADSIG";
		break;
	 case 0x2339:
		return "WERR_DNS_ERROR_RCODE_BADKEY";
		break;
	 case 0x233a:
		return "WERR_DNS_ERROR_RCODE_BADTIME";
		break;
	 case 0x251d:
		return "WERR_DNS_INFO_NO_RECORDS";
		break;
	 case 0x251e:
		return "WERR_DNS_ERROR_BAD_PACKET";
		break;
	 case 0x251f:
		return "WERR_DNS_ERROR_NO_PACKET";
		break;
	 case 0x2520:
		return "WERR_DNS_ERROR_RCODE";
		break;
	 case 0x2521:
		return "WERR_DNS_ERROR_UNSECURE_PACKET";
		break;
	 case 0x254f:
		return "WERR_DNS_ERROR_INVALID_TYPE";
		break;
	 case 0x2550:
		return "WERR_DNS_ERROR_INVALID_IP_ADDRESS";
		break;
	 case 0x2551:
		return "WERR_DNS_ERROR_INVALID_PROPERTY";
		break;
	 case 0x2552:
		return "WERR_DNS_ERROR_TRY_AGAIN_LATER";
		break;
	 case 0x2553:
		return "WERR_DNS_ERROR_NOT_UNIQUE";
		break;
	 case 0x2554:
		return "WERR_DNS_ERROR_NON_RFC_NAME";
		break;
	 case 0x2555:
		return "WERR_DNS_STATUS_FQDN";
		break;
	 case 0x2556:
		return "WERR_DNS_STATUS_DOTTED_NAME";
		break;
	 case 0x2557:
		return "WERR_DNS_STATUS_SINGLE_PART_NAME";
		break;
	 case 0x2558:
		return "WERR_DNS_ERROR_INVALID_NAME_CHAR";
		break;
	 case 0x2559:
		return "WERR_DNS_ERROR_NUMERIC_NAME";
		break;
	 case 0x255a:
		return "WERR_DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER";
		break;
	 case 0x255b:
		return "WERR_DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION";
		break;
	 case 0x255c:
		return "WERR_DNS_ERROR_CANNOT_FIND_ROOT_HINTS";
		break;
	 case 0x255d:
		return "WERR_DNS_ERROR_INCONSISTENT_ROOT_HINTS";
		break;
	 case 0x255e:
		return "WERR_DNS_ERROR_DWORD_VALUE_TOO_SMALL";
		break;
	 case 0x255f:
		return "WERR_DNS_ERROR_DWORD_VALUE_TOO_LARGE";
		break;
	 case 0x2560:
		return "WERR_DNS_ERROR_BACKGROUND_LOADING";
		break;
	 case 0x2561:
		return "WERR_DNS_ERROR_NOT_ALLOWED_ON_RODC";
		break;
	 case 0x2581:
		return "WERR_DNS_ERROR_ZONE_DOES_NOT_EXIST";
		break;
	 case 0x2582:
		return "WERR_DNS_ERROR_NO_ZONE_INFO";
		break;
	 case 0x2583:
		return "WERR_DNS_ERROR_INVALID_ZONE_OPERATION";
		break;
	 case 0x2584:
		return "WERR_DNS_ERROR_ZONE_CONFIGURATION_ERROR";
		break;
	 case 0x2585:
		return "WERR_DNS_ERROR_ZONE_HAS_NO_SOA_RECORD";
		break;
	 case 0x2586:
		return "WERR_DNS_ERROR_ZONE_HAS_NO_NS_RECORDS";
		break;
	 case 0x2587:
		return "WERR_DNS_ERROR_ZONE_LOCKED";
		break;
	 case 0x2588:
		return "WERR_DNS_ERROR_ZONE_CREATION_FAILED";
		break;
	 case 0x2589:
		return "WERR_DNS_ERROR_ZONE_ALREADY_EXISTS";
		break;
	 case 0x258a:
		return "WERR_DNS_ERROR_AUTOZONE_ALREADY_EXISTS";
		break;
	 case 0x258b:
		return "WERR_DNS_ERROR_INVALID_ZONE_TYPE";
		break;
	 case 0x258c:
		return "WERR_DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP";
		break;
	 case 0x258d:
		return "WERR_DNS_ERROR_ZONE_NOT_SECONDARY";
		break;
	 case 0x258e:
		return "WERR_DNS_ERROR_NEED_SECONDARY_ADDRESSES";
		break;
	 case 0x258f:
		return "WERR_DNS_ERROR_WINS_INIT_FAILED";
		break;
	 case 0x2590:
		return "WERR_DNS_ERROR_NEED_WINS_SERVERS";
		break;
	 case 0x2591:
		return "WERR_DNS_ERROR_NBSTAT_INIT_FAILED";
		break;
	 case 0x2592:
		return "WERR_DNS_ERROR_SOA_DELETE_INVALID";
		break;
	 case 0x2593:
		return "WERR_DNS_ERROR_FORWARDER_ALREADY_EXISTS";
		break;
	 case 0x2594:
		return "WERR_DNS_ERROR_ZONE_REQUIRES_MASTER_IP";
		break;
	 case 0x2595:
		return "WERR_DNS_ERROR_ZONE_IS_SHUTDOWN";
		break;
	 case 0x25b3:
		return "WERR_DNS_ERROR_PRIMARY_REQUIRES_DATAFILE";
		break;
	 case 0x25b4:
		return "WERR_DNS_ERROR_INVALID_DATAFILE_NAME";
		break;
	 case 0x25b5:
		return "WERR_DNS_ERROR_DATAFILE_OPEN_FAILURE";
		break;
	 case 0x25b6:
		return "WERR_DNS_ERROR_FILE_WRITEBACK_FAILED";
		break;
	 case 0x25b7:
		return "WERR_DNS_ERROR_DATAFILE_PARSING";
		break;
	 case 0x25e5:
		return "WERR_DNS_ERROR_RECORD_DOES_NOT_EXIST";
		break;
	 case 0x25e6:
		return "WERR_DNS_ERROR_RECORD_FORMAT";
		break;
	 case 0x25e7:
		return "WERR_DNS_ERROR_NODE_CREATION_FAILED";
		break;
	 case 0x25e8:
		return "WERR_DNS_ERROR_UNKNOWN_RECORD_TYPE";
		break;
	 case 0x25e9:
		return "WERR_DNS_ERROR_RECORD_TIMED_OUT";
		break;
	 case 0x25ea:
		return "WERR_DNS_ERROR_NAME_NOT_IN_ZONE";
		break;
	 case 0x25eb:
		return "WERR_DNS_ERROR_CNAME_LOOP";
		break;
	 case 0x25ec:
		return "WERR_DNS_ERROR_NODE_IS_CNAME";
		break;
	 case 0x25ed:
		return "WERR_DNS_ERROR_CNAME_COLLISION";
		break;
	 case 0x25ee:
		return "WERR_DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT";
		break;
	 case 0x25ef:
		return "WERR_DNS_ERROR_RECORD_ALREADY_EXISTS";
		break;
	 case 0x25f0:
		return "WERR_DNS_ERROR_SECONDARY_DATA";
		break;
	 case 0x25f1:
		return "WERR_DNS_ERROR_NO_CREATE_CACHE_DATA";
		break;
	 case 0x25f2:
		return "WERR_DNS_ERROR_NAME_DOES_NOT_EXIST";
		break;
	 case 0x25f3:
		return "WERR_DNS_WARNING_PTR_CREATE_FAILED";
		break;
	 case 0x25f4:
		return "WERR_DNS_WARNING_DOMAIN_UNDELETED";
		break;
	 case 0x25f5:
		return "WERR_DNS_ERROR_DS_UNAVAILABLE";
		break;
	 case 0x25f6:
		return "WERR_DNS_ERROR_DS_ZONE_ALREADY_EXISTS";
		break;
	 case 0x25f7:
		return "WERR_DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE";
		break;
	 case 0x2617:
		return "WERR_DNS_INFO_AXFR_COMPLETE";
		break;
	 case 0x2618:
		return "WERR_DNS_ERROR_AXFR";
		break;
	 case 0x2619:
		return "WERR_DNS_INFO_ADDED_LOCAL_WINS";
		break;
	 case 0x2649:
		return "WERR_DNS_STATUS_CONTINUE_NEEDED";
		break;
	 case 0x267b:
		return "WERR_DNS_ERROR_NO_TCPIP";
		break;
	 case 0x267c:
		return "WERR_DNS_ERROR_NO_DNS_SERVERS";
		break;
	 case 0x26ad:
		return "WERR_DNS_ERROR_DP_DOES_NOT_EXIST";
		break;
	 case 0x26ae:
		return "WERR_DNS_ERROR_DP_ALREADY_EXISTS";
		break;
	 case 0x26af:
		return "WERR_DNS_ERROR_DP_NOT_ENLISTED";
		break;
	 case 0x26b0:
		return "WERR_DNS_ERROR_DP_ALREADY_ENLISTED";
		break;
	 case 0x26b1:
		return "WERR_DNS_ERROR_DP_NOT_AVAILABLE";
		break;
	 case 0x26b2:
		return "WERR_DNS_ERROR_DP_FSMO_ERROR";
		break;
	 case 0x2714:
		return "WERR_WSAEINTR";
		break;
	 case 0x2719:
		return "WERR_WSAEBADF";
		break;
	 case 0x271d:
		return "WERR_WSAEACCES";
		break;
	 case 0x271e:
		return "WERR_WSAEFAULT";
		break;
	 case 0x2726:
		return "WERR_WSAEINVAL";
		break;
	 case 0x2728:
		return "WERR_WSAEMFILE";
		break;
	 case 0x2733:
		return "WERR_WSAEWOULDBLOCK";
		break;
	 case 0x2734:
		return "WERR_WSAEINPROGRESS";
		break;
	 case 0x2735:
		return "WERR_WSAEALREADY";
		break;
	 case 0x2736:
		return "WERR_WSAENOTSOCK";
		break;
	 case 0x2737:
		return "WERR_WSAEDESTADDRREQ";
		break;
	 case 0x2738:
		return "WERR_WSAEMSGSIZE";
		break;
	 case 0x2739:
		return "WERR_WSAEPROTOTYPE";
		break;
	 case 0x273a:
		return "WERR_WSAENOPROTOOPT";
		break;
	 case 0x273b:
		return "WERR_WSAEPROTONOSUPPORT";
		break;
	 case 0x273c:
		return "WERR_WSAESOCKTNOSUPPORT";
		break;
	 case 0x273d:
		return "WERR_WSAEOPNOTSUPP";
		break;
	 case 0x273e:
		return "WERR_WSAEPFNOSUPPORT";
		break;
	 case 0x273f:
		return "WERR_WSAEAFNOSUPPORT";
		break;
	 case 0x2740:
		return "WERR_WSAEADDRINUSE";
		break;
	 case 0x2741:
		return "WERR_WSAEADDRNOTAVAIL";
		break;
	 case 0x2742:
		return "WERR_WSAENETDOWN";
		break;
	 case 0x2743:
		return "WERR_WSAENETUNREACH";
		break;
	 case 0x2744:
		return "WERR_WSAENETRESET";
		break;
	 case 0x2745:
		return "WERR_WSAECONNABORTED";
		break;
	 case 0x2746:
		return "WERR_WSAECONNRESET";
		break;
	 case 0x2747:
		return "WERR_WSAENOBUFS";
		break;
	 case 0x2748:
		return "WERR_WSAEISCONN";
		break;
	 case 0x2749:
		return "WERR_WSAENOTCONN";
		break;
	 case 0x274a:
		return "WERR_WSAESHUTDOWN";
		break;
	 case 0x274b:
		return "WERR_WSAETOOMANYREFS";
		break;
	 case 0x274c:
		return "WERR_WSAETIMEDOUT";
		break;
	 case 0x274d:
		return "WERR_WSAECONNREFUSED";
		break;
	 case 0x274e:
		return "WERR_WSAELOOP";
		break;
	 case 0x274f:
		return "WERR_WSAENAMETOOLONG";
		break;
	 case 0x2750:
		return "WERR_WSAEHOSTDOWN";
		break;
	 case 0x2751:
		return "WERR_WSAEHOSTUNREACH";
		break;
	 case 0x2752:
		return "WERR_WSAENOTEMPTY";
		break;
	 case 0x2753:
		return "WERR_WSAEPROCLIM";
		break;
	 case 0x2754:
		return "WERR_WSAEUSERS";
		break;
	 case 0x2755:
		return "WERR_WSAEDQUOT";
		break;
	 case 0x2756:
		return "WERR_WSAESTALE";
		break;
	 case 0x2757:
		return "WERR_WSAEREMOTE";
		break;
	 case 0x276b:
		return "WERR_WSASYSNOTREADY";
		break;
	 case 0x276c:
		return "WERR_WSAVERNOTSUPPORTED";
		break;
	 case 0x276d:
		return "WERR_WSANOTINITIALISED";
		break;
	 case 0x2775:
		return "WERR_WSAEDISCON";
		break;
	 case 0x2776:
		return "WERR_WSAENOMORE";
		break;
	 case 0x2777:
		return "WERR_WSAECANCELLED";
		break;
	 case 0x2778:
		return "WERR_WSAEINVALIDPROCTABLE";
		break;
	 case 0x2779:
		return "WERR_WSAEINVALIDPROVIDER";
		break;
	 case 0x277a:
		return "WERR_WSAEPROVIDERFAILEDINIT";
		break;
	 case 0x277b:
		return "WERR_WSASYSCALLFAILURE";
		break;
	 case 0x277c:
		return "WERR_WSASERVICE_NOT_FOUND";
		break;
	 case 0x277d:
		return "WERR_WSATYPE_NOT_FOUND";
		break;
	 case 0x277e:
		return "WERR_WSA_E_NO_MORE";
		break;
	 case 0x277f:
		return "WERR_WSA_E_CANCELLED";
		break;
	 case 0x2780:
		return "WERR_WSAEREFUSED";
		break;
	 case 0x2af9:
		return "WERR_WSAHOST_NOT_FOUND";
		break;
	 case 0x2afa:
		return "WERR_WSATRY_AGAIN";
		break;
	 case 0x2afb:
		return "WERR_WSANO_RECOVERY";
		break;
	 case 0x2afc:
		return "WERR_WSANO_DATA";
		break;
	 case 0x2afd:
		return "WERR_WSA_QOS_RECEIVERS";
		break;
	 case 0x2afe:
		return "WERR_WSA_QOS_SENDERS";
		break;
	 case 0x2aff:
		return "WERR_WSA_QOS_NO_SENDERS";
		break;
	 case 0x2b00:
		return "WERR_WSA_QOS_NO_RECEIVERS";
		break;
	 case 0x2b01:
		return "WERR_WSA_QOS_REQUEST_CONFIRMED";
		break;
	 case 0x2b02:
		return "WERR_WSA_QOS_ADMISSION_FAILURE";
		break;
	 case 0x2b03:
		return "WERR_WSA_QOS_POLICY_FAILURE";
		break;
	 case 0x2b04:
		return "WERR_WSA_QOS_BAD_STYLE";
		break;
	 case 0x2b05:
		return "WERR_WSA_QOS_BAD_OBJECT";
		break;
	 case 0x2b06:
		return "WERR_WSA_QOS_TRAFFIC_CTRL_ERROR";
		break;
	 case 0x2b07:
		return "WERR_WSA_QOS_GENERIC_ERROR";
		break;
	 case 0x2b08:
		return "WERR_WSA_QOS_ESERVICETYPE";
		break;
	 case 0x2b09:
		return "WERR_WSA_QOS_EFLOWSPEC";
		break;
	 case 0x2b0a:
		return "WERR_WSA_QOS_EPROVSPECBUF";
		break;
	 case 0x2b0b:
		return "WERR_WSA_QOS_EFILTERSTYLE";
		break;
	 case 0x2b0c:
		return "WERR_WSA_QOS_EFILTERTYPE";
		break;
	 case 0x2b0d:
		return "WERR_WSA_QOS_EFILTERCOUNT";
		break;
	 case 0x2b0e:
		return "WERR_WSA_QOS_EOBJLENGTH";
		break;
	 case 0x2b0f:
		return "WERR_WSA_QOS_EFLOWCOUNT";
		break;
	 case 0x2b10:
		return "WERR_WSA_QOS_EUNKOWNPSOBJ";
		break;
	 case 0x2b11:
		return "WERR_WSA_QOS_EPOLICYOBJ";
		break;
	 case 0x2b12:
		return "WERR_WSA_QOS_EFLOWDESC";
		break;
	 case 0x2b13:
		return "WERR_WSA_QOS_EPSFLOWSPEC";
		break;
	 case 0x2b14:
		return "WERR_WSA_QOS_EPSFILTERSPEC";
		break;
	 case 0x2b15:
		return "WERR_WSA_QOS_ESDMODEOBJ";
		break;
	 case 0x2b16:
		return "WERR_WSA_QOS_ESHAPERATEOBJ";
		break;
	 case 0x2b17:
		return "WERR_WSA_QOS_RESERVED_PETYPE";
		break;
	 case 0x32c8:
		return "WERR_IPSEC_QM_POLICY_EXISTS";
		break;
	 case 0x32c9:
		return "WERR_IPSEC_QM_POLICY_NOT_FOUND";
		break;
	 case 0x32ca:
		return "WERR_IPSEC_QM_POLICY_IN_USE";
		break;
	 case 0x32cb:
		return "WERR_IPSEC_MM_POLICY_EXISTS";
		break;
	 case 0x32cc:
		return "WERR_IPSEC_MM_POLICY_NOT_FOUND";
		break;
	 case 0x32cd:
		return "WERR_IPSEC_MM_POLICY_IN_USE";
		break;
	 case 0x32ce:
		return "WERR_IPSEC_MM_FILTER_EXISTS";
		break;
	 case 0x32cf:
		return "WERR_IPSEC_MM_FILTER_NOT_FOUND";
		break;
	 case 0x32d0:
		return "WERR_IPSEC_TRANSPORT_FILTER_EXISTS";
		break;
	 case 0x32d1:
		return "WERR_IPSEC_TRANSPORT_FILTER_NOT_FOUND";
		break;
	 case 0x32d2:
		return "WERR_IPSEC_MM_AUTH_EXISTS";
		break;
	 case 0x32d3:
		return "WERR_IPSEC_MM_AUTH_NOT_FOUND";
		break;
	 case 0x32d4:
		return "WERR_IPSEC_MM_AUTH_IN_USE";
		break;
	 case 0x32d5:
		return "WERR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND";
		break;
	 case 0x32d6:
		return "WERR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND";
		break;
	 case 0x32d7:
		return "WERR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND";
		break;
	 case 0x32d8:
		return "WERR_IPSEC_TUNNEL_FILTER_EXISTS";
		break;
	 case 0x32d9:
		return "WERR_IPSEC_TUNNEL_FILTER_NOT_FOUND";
		break;
	 case 0x32da:
		return "WERR_IPSEC_MM_FILTER_PENDING_DELETION";
		break;
	 case 0x32db:
		return "WERR_IPSEC_TRANSPORT_FILTER_ENDING_DELETION";
		break;
	 case 0x32dc:
		return "WERR_IPSEC_TUNNEL_FILTER_PENDING_DELETION";
		break;
	 case 0x32dd:
		return "WERR_IPSEC_MM_POLICY_PENDING_ELETION";
		break;
	 case 0x32de:
		return "WERR_IPSEC_MM_AUTH_PENDING_DELETION";
		break;
	 case 0x32df:
		return "WERR_IPSEC_QM_POLICY_PENDING_DELETION";
		break;
	 case 0x32e0:
		return "WERR_WARNING_IPSEC_MM_POLICY_PRUNED";
		break;
	 case 0x32e1:
		return "WERR_WARNING_IPSEC_QM_POLICY_PRUNED";
		break;
	 case 0x35e8:
		return "WERR_IPSEC_IKE_NEG_STATUS_BEGIN";
		break;
	 case 0x35e9:
		return "WERR_IPSEC_IKE_AUTH_FAIL";
		break;
	 case 0x35ea:
		return "WERR_IPSEC_IKE_ATTRIB_FAIL";
		break;
	 case 0x35eb:
		return "WERR_IPSEC_IKE_NEGOTIATION_PENDING";
		break;
	 case 0x35ec:
		return "WERR_IPSEC_IKE_GENERAL_PROCESSING_ERROR";
		break;
	 case 0x35ed:
		return "WERR_IPSEC_IKE_TIMED_OUT";
		break;
	 case 0x35ee:
		return "WERR_IPSEC_IKE_NO_CERT";
		break;
	 case 0x35ef:
		return "WERR_IPSEC_IKE_SA_DELETED";
		break;
	 case 0x35f0:
		return "WERR_IPSEC_IKE_SA_REAPED";
		break;
	 case 0x35f1:
		return "WERR_IPSEC_IKE_MM_ACQUIRE_DROP";
		break;
	 case 0x35f2:
		return "WERR_IPSEC_IKE_QM_ACQUIRE_DROP";
		break;
	 case 0x35f3:
		return "WERR_IPSEC_IKE_QUEUE_DROP_MM";
		break;
	 case 0x35f4:
		return "WERR_IPSEC_IKE_QUEUE_DROP_NO_MM";
		break;
	 case 0x35f5:
		return "WERR_IPSEC_IKE_DROP_NO_RESPONSE";
		break;
	 case 0x35f6:
		return "WERR_IPSEC_IKE_MM_DELAY_DROP";
		break;
	 case 0x35f7:
		return "WERR_IPSEC_IKE_QM_DELAY_DROP";
		break;
	 case 0x35f8:
		return "WERR_IPSEC_IKE_ERROR";
		break;
	 case 0x35f9:
		return "WERR_IPSEC_IKE_CRL_FAILED";
		break;
	 case 0x35fa:
		return "WERR_IPSEC_IKE_INVALID_KEY_USAGE";
		break;
	 case 0x35fb:
		return "WERR_IPSEC_IKE_INVALID_CERT_TYPE";
		break;
	 case 0x35fc:
		return "WERR_IPSEC_IKE_NO_PRIVATE_KEY";
		break;
	 case 0x35fe:
		return "WERR_IPSEC_IKE_DH_FAIL";
		break;
	 case 0x3600:
		return "WERR_IPSEC_IKE_INVALID_HEADER";
		break;
	 case 0x3601:
		return "WERR_IPSEC_IKE_NO_POLICY";
		break;
	 case 0x3602:
		return "WERR_IPSEC_IKE_INVALID_SIGNATURE";
		break;
	 case 0x3603:
		return "WERR_IPSEC_IKE_KERBEROS_ERROR";
		break;
	 case 0x3604:
		return "WERR_IPSEC_IKE_NO_PUBLIC_KEY";
		break;
	 case 0x3605:
		return "WERR_IPSEC_IKE_PROCESS_ERR";
		break;
	 case 0x3606:
		return "WERR_IPSEC_IKE_PROCESS_ERR_SA";
		break;
	 case 0x3607:
		return "WERR_IPSEC_IKE_PROCESS_ERR_PROP";
		break;
	 case 0x3608:
		return "WERR_IPSEC_IKE_PROCESS_ERR_TRANS";
		break;
	 case 0x3609:
		return "WERR_IPSEC_IKE_PROCESS_ERR_KE";
		break;
	 case 0x360a:
		return "WERR_IPSEC_IKE_PROCESS_ERR_ID";
		break;
	 case 0x360b:
		return "WERR_IPSEC_IKE_PROCESS_ERR_CERT";
		break;
	 case 0x360c:
		return "WERR_IPSEC_IKE_PROCESS_ERR_CERT_REQ";
		break;
	 case 0x360d:
		return "WERR_IPSEC_IKE_PROCESS_ERR_HASH";
		break;
	 case 0x360e:
		return "WERR_IPSEC_IKE_PROCESS_ERR_SIG";
		break;
	 case 0x360f:
		return "WERR_IPSEC_IKE_PROCESS_ERR_NONCE";
		break;
	 case 0x3610:
		return "WERR_IPSEC_IKE_PROCESS_ERR_NOTIFY";
		break;
	 case 0x3611:
		return "WERR_IPSEC_IKE_PROCESS_ERR_DELETE";
		break;
	 case 0x3612:
		return "WERR_IPSEC_IKE_PROCESS_ERR_VENDOR";
		break;
	 case 0x3613:
		return "WERR_IPSEC_IKE_INVALID_PAYLOAD";
		break;
	 case 0x3614:
		return "WERR_IPSEC_IKE_LOAD_SOFT_SA";
		break;
	 case 0x3615:
		return "WERR_IPSEC_IKE_SOFT_SA_TORN_DOWN";
		break;
	 case 0x3616:
		return "WERR_IPSEC_IKE_INVALID_COOKIE";
		break;
	 case 0x3617:
		return "WERR_IPSEC_IKE_NO_PEER_CERT";
		break;
	 case 0x3618:
		return "WERR_IPSEC_IKE_PEER_CRL_FAILED";
		break;
	 case 0x3619:
		return "WERR_IPSEC_IKE_POLICY_CHANGE";
		break;
	 case 0x361a:
		return "WERR_IPSEC_IKE_NO_MM_POLICY";
		break;
	 case 0x361b:
		return "WERR_IPSEC_IKE_NOTCBPRIV";
		break;
	 case 0x361c:
		return "WERR_IPSEC_IKE_SECLOADFAIL";
		break;
	 case 0x361d:
		return "WERR_IPSEC_IKE_FAILSSPINIT";
		break;
	 case 0x361e:
		return "WERR_IPSEC_IKE_FAILQUERYSSP";
		break;
	 case 0x361f:
		return "WERR_IPSEC_IKE_SRVACQFAIL";
		break;
	 case 0x3620:
		return "WERR_IPSEC_IKE_SRVQUERYCRED";
		break;
	 case 0x3621:
		return "WERR_IPSEC_IKE_GETSPIFAIL";
		break;
	 case 0x3622:
		return "WERR_IPSEC_IKE_INVALID_FILTER";
		break;
	 case 0x3623:
		return "WERR_IPSEC_IKE_OUT_OF_MEMORY";
		break;
	 case 0x3624:
		return "WERR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED";
		break;
	 case 0x3625:
		return "WERR_IPSEC_IKE_INVALID_POLICY";
		break;
	 case 0x3626:
		return "WERR_IPSEC_IKE_UNKNOWN_DOI";
		break;
	 case 0x3627:
		return "WERR_IPSEC_IKE_INVALID_SITUATION";
		break;
	 case 0x3628:
		return "WERR_IPSEC_IKE_DH_FAILURE";
		break;
	 case 0x3629:
		return "WERR_IPSEC_IKE_INVALID_GROUP";
		break;
	 case 0x362a:
		return "WERR_IPSEC_IKE_ENCRYPT";
		break;
	 case 0x362b:
		return "WERR_IPSEC_IKE_DECRYPT";
		break;
	 case 0x362c:
		return "WERR_IPSEC_IKE_POLICY_MATCH";
		break;
	 case 0x362d:
		return "WERR_IPSEC_IKE_UNSUPPORTED_ID";
		break;
	 case 0x362e:
		return "WERR_IPSEC_IKE_INVALID_HASH";
		break;
	 case 0x362f:
		return "WERR_IPSEC_IKE_INVALID_HASH_ALG";
		break;
	 case 0x3630:
		return "WERR_IPSEC_IKE_INVALID_HASH_SIZE";
		break;
	 case 0x3631:
		return "WERR_IPSEC_IKE_INVALID_ENCRYPT_ALG";
		break;
	 case 0x3632:
		return "WERR_IPSEC_IKE_INVALID_AUTH_ALG";
		break;
	 case 0x3633:
		return "WERR_IPSEC_IKE_INVALID_SIG";
		break;
	 case 0x3634:
		return "WERR_IPSEC_IKE_LOAD_FAILED";
		break;
	 case 0x3635:
		return "WERR_IPSEC_IKE_RPC_DELETE";
		break;
	 case 0x3636:
		return "WERR_IPSEC_IKE_BENIGN_REINIT";
		break;
	 case 0x3637:
		return "WERR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY";
		break;
	 case 0x3639:
		return "WERR_IPSEC_IKE_INVALID_CERT_KEYLEN";
		break;
	 case 0x363a:
		return "WERR_IPSEC_IKE_MM_LIMIT";
		break;
	 case 0x363b:
		return "WERR_IPSEC_IKE_NEGOTIATION_DISABLED";
		break;
	 case 0x363c:
		return "WERR_IPSEC_IKE_QM_LIMIT";
		break;
	 case 0x363d:
		return "WERR_IPSEC_IKE_MM_EXPIRED";
		break;
	 case 0x363e:
		return "WERR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID";
		break;
	 case 0x363f:
		return "WERR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH";
		break;
	 case 0x3640:
		return "WERR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID";
		break;
	 case 0x3641:
		return "WERR_IPSEC_IKE_INVALID_UMATTS";
		break;
	 case 0x3642:
		return "WERR_IPSEC_IKE_DOS_COOKIE_SENT";
		break;
	 case 0x3643:
		return "WERR_IPSEC_IKE_SHUTTING_DOWN";
		break;
	 case 0x3644:
		return "WERR_IPSEC_IKE_CGA_AUTH_FAILED";
		break;
	 case 0x3645:
		return "WERR_IPSEC_IKE_PROCESS_ERR_NATOA";
		break;
	 case 0x3646:
		return "WERR_IPSEC_IKE_INVALID_MM_FOR_QM";
		break;
	 case 0x3647:
		return "WERR_IPSEC_IKE_QM_EXPIRED";
		break;
	 case 0x3648:
		return "WERR_IPSEC_IKE_TOO_MANY_FILTERS";
		break;
	 case 0x3649:
		return "WERR_IPSEC_IKE_NEG_STATUS_END";
		break;
	 case 0x36b0:
		return "WERR_SXS_SECTION_NOT_FOUND";
		break;
	 case 0x36b1:
		return "WERR_SXS_CANT_GEN_ACTCTX";
		break;
	 case 0x36b2:
		return "WERR_SXS_INVALID_ACTCTXDATA_FORMAT";
		break;
	 case 0x36b3:
		return "WERR_SXS_ASSEMBLY_NOT_FOUND";
		break;
	 case 0x36b4:
		return "WERR_SXS_MANIFEST_FORMAT_ERROR";
		break;
	 case 0x36b5:
		return "WERR_SXS_MANIFEST_PARSE_ERROR";
		break;
	 case 0x36b6:
		return "WERR_SXS_ACTIVATION_CONTEXT_DISABLED";
		break;
	 case 0x36b7:
		return "WERR_SXS_KEY_NOT_FOUND";
		break;
	 case 0x36b8:
		return "WERR_SXS_VERSION_CONFLICT";
		break;
	 case 0x36b9:
		return "WERR_SXS_WRONG_SECTION_TYPE";
		break;
	 case 0x36ba:
		return "WERR_SXS_THREAD_QUERIES_DISABLED";
		break;
	 case 0x36bb:
		return "WERR_SXS_PROCESS_DEFAULT_ALREADY_SET";
		break;
	 case 0x36bc:
		return "WERR_SXS_UNKNOWN_ENCODING_GROUP";
		break;
	 case 0x36bd:
		return "WERR_SXS_UNKNOWN_ENCODING";
		break;
	 case 0x36be:
		return "WERR_SXS_INVALID_XML_NAMESPACE_URI";
		break;
	 case 0x36bf:
		return "WERR_SXS_ROOT_MANIFEST_DEPENDENCY_OT_INSTALLED";
		break;
	 case 0x36c0:
		return "WERR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED";
		break;
	 case 0x36c1:
		return "WERR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE";
		break;
	 case 0x36c2:
		return "WERR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE";
		break;
	 case 0x36c3:
		return "WERR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE";
		break;
	 case 0x36c4:
		return "WERR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT";
		break;
	 case 0x36c5:
		return "WERR_SXS_DUPLICATE_DLL_NAME";
		break;
	 case 0x36c6:
		return "WERR_SXS_DUPLICATE_WINDOWCLASS_NAME";
		break;
	 case 0x36c7:
		return "WERR_SXS_DUPLICATE_CLSID";
		break;
	 case 0x36c8:
		return "WERR_SXS_DUPLICATE_IID";
		break;
	 case 0x36c9:
		return "WERR_SXS_DUPLICATE_TLBID";
		break;
	 case 0x36ca:
		return "WERR_SXS_DUPLICATE_PROGID";
		break;
	 case 0x36cb:
		return "WERR_SXS_DUPLICATE_ASSEMBLY_NAME";
		break;
	 case 0x36cc:
		return "WERR_SXS_FILE_HASH_MISMATCH";
		break;
	 case 0x36cd:
		return "WERR_SXS_POLICY_PARSE_ERROR";
		break;
	 case 0x36ce:
		return "WERR_SXS_XML_E_MISSINGQUOTE";
		break;
	 case 0x36cf:
		return "WERR_SXS_XML_E_COMMENTSYNTAX";
		break;
	 case 0x36d0:
		return "WERR_SXS_XML_E_BADSTARTNAMECHAR";
		break;
	 case 0x36d1:
		return "WERR_SXS_XML_E_BADNAMECHAR";
		break;
	 case 0x36d2:
		return "WERR_SXS_XML_E_BADCHARINSTRING";
		break;
	 case 0x36d3:
		return "WERR_SXS_XML_E_XMLDECLSYNTAX";
		break;
	 case 0x36d4:
		return "WERR_SXS_XML_E_BADCHARDATA";
		break;
	 case 0x36d5:
		return "WERR_SXS_XML_E_MISSINGWHITESPACE";
		break;
	 case 0x36d6:
		return "WERR_SXS_XML_E_EXPECTINGTAGEND";
		break;
	 case 0x36d7:
		return "WERR_SXS_XML_E_MISSINGSEMICOLON";
		break;
	 case 0x36d8:
		return "WERR_SXS_XML_E_UNBALANCEDPAREN";
		break;
	 case 0x36d9:
		return "WERR_SXS_XML_E_INTERNALERROR";
		break;
	 case 0x36da:
		return "WERR_SXS_XML_E_UNEXPECTED_WHITESPACE";
		break;
	 case 0x36db:
		return "WERR_SXS_XML_E_INCOMPLETE_ENCODING";
		break;
	 case 0x36dc:
		return "WERR_SXS_XML_E_MISSING_PAREN";
		break;
	 case 0x36dd:
		return "WERR_SXS_XML_E_EXPECTINGCLOSEQUOTE";
		break;
	 case 0x36de:
		return "WERR_SXS_XML_E_MULTIPLE_COLONS";
		break;
	 case 0x36df:
		return "WERR_SXS_XML_E_INVALID_DECIMAL";
		break;
	 case 0x36e0:
		return "WERR_SXS_XML_E_INVALID_HEXIDECIMAL";
		break;
	 case 0x36e1:
		return "WERR_SXS_XML_E_INVALID_UNICODE";
		break;
	 case 0x36e2:
		return "WERR_SXS_XML_E_WHITESPACEORQUESTIONMARK";
		break;
	 case 0x36e3:
		return "WERR_SXS_XML_E_UNEXPECTEDENDTAG";
		break;
	 case 0x36e4:
		return "WERR_SXS_XML_E_UNCLOSEDTAG";
		break;
	 case 0x36e5:
		return "WERR_SXS_XML_E_DUPLICATEATTRIBUTE";
		break;
	 case 0x36e6:
		return "WERR_SXS_XML_E_MULTIPLEROOTS";
		break;
	 case 0x36e7:
		return "WERR_SXS_XML_E_INVALIDATROOTLEVEL";
		break;
	 case 0x36e8:
		return "WERR_SXS_XML_E_BADXMLDECL";
		break;
	 case 0x36e9:
		return "WERR_SXS_XML_E_MISSINGROOT";
		break;
	 case 0x36ea:
		return "WERR_SXS_XML_E_UNEXPECTEDEOF";
		break;
	 case 0x36eb:
		return "WERR_SXS_XML_E_BADPEREFINSUBSET";
		break;
	 case 0x36ec:
		return "WERR_SXS_XML_E_UNCLOSEDSTARTTAG";
		break;
	 case 0x36ed:
		return "WERR_SXS_XML_E_UNCLOSEDENDTAG";
		break;
	 case 0x36ee:
		return "WERR_SXS_XML_E_UNCLOSEDSTRING";
		break;
	 case 0x36ef:
		return "WERR_SXS_XML_E_UNCLOSEDCOMMENT";
		break;
	 case 0x36f0:
		return "WERR_SXS_XML_E_UNCLOSEDDECL";
		break;
	 case 0x36f1:
		return "WERR_SXS_XML_E_UNCLOSEDCDATA";
		break;
	 case 0x36f2:
		return "WERR_SXS_XML_E_RESERVEDNAMESPACE";
		break;
	 case 0x36f3:
		return "WERR_SXS_XML_E_INVALIDENCODING";
		break;
	 case 0x36f4:
		return "WERR_SXS_XML_E_INVALIDSWITCH";
		break;
	 case 0x36f5:
		return "WERR_SXS_XML_E_BADXMLCASE";
		break;
	 case 0x36f6:
		return "WERR_SXS_XML_E_INVALID_STANDALONE";
		break;
	 case 0x36f7:
		return "WERR_SXS_XML_E_UNEXPECTED_STANDALONE";
		break;
	 case 0x36f8:
		return "WERR_SXS_XML_E_INVALID_VERSION";
		break;
	 case 0x36f9:
		return "WERR_SXS_XML_E_MISSINGEQUALS";
		break;
	 case 0x36fa:
		return "WERR_SXS_PROTECTION_RECOVERY_FAILED";
		break;
	 case 0x36fb:
		return "WERR_SXS_PROTECTION_PUBLIC_KEY_OO_SHORT";
		break;
	 case 0x36fc:
		return "WERR_SXS_PROTECTION_CATALOG_NOT_VALID";
		break;
	 case 0x36fd:
		return "WERR_SXS_UNTRANSLATABLE_HRESULT";
		break;
	 case 0x36fe:
		return "WERR_SXS_PROTECTION_CATALOG_FILE_MISSING";
		break;
	 case 0x36ff:
		return "WERR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE";
		break;
	 case 0x3700:
		return "WERR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME";
		break;
	 case 0x3701:
		return "WERR_SXS_ASSEMBLY_MISSING";
		break;
	 case 0x3702:
		return "WERR_SXS_CORRUPT_ACTIVATION_STACK";
		break;
	 case 0x3703:
		return "WERR_SXS_CORRUPTION";
		break;
	 case 0x3704:
		return "WERR_SXS_EARLY_DEACTIVATION";
		break;
	 case 0x3705:
		return "WERR_SXS_INVALID_DEACTIVATION";
		break;
	 case 0x3706:
		return "WERR_SXS_MULTIPLE_DEACTIVATION";
		break;
	 case 0x3707:
		return "WERR_SXS_PROCESS_TERMINATION_REQUESTED";
		break;
	 case 0x3708:
		return "WERR_SXS_RELEASE_ACTIVATION_ONTEXT";
		break;
	 case 0x3709:
		return "WERR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY";
		break;
	 case 0x370a:
		return "WERR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE";
		break;
	 case 0x370b:
		return "WERR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME";
		break;
	 case 0x370c:
		return "WERR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE";
		break;
	 case 0x370d:
		return "WERR_SXS_IDENTITY_PARSE_ERROR";
		break;
	 case 0x370e:
		return "WERR_MALFORMED_SUBSTITUTION_STRING";
		break;
	 case 0x370f:
		return "WERR_SXS_INCORRECT_PUBLIC_KEY_OKEN";
		break;
	 case 0x3710:
		return "WERR_UNMAPPED_SUBSTITUTION_STRING";
		break;
	 case 0x3711:
		return "WERR_SXS_ASSEMBLY_NOT_LOCKED";
		break;
	 case 0x3712:
		return "WERR_SXS_COMPONENT_STORE_CORRUPT";
		break;
	 case 0x3713:
		return "WERR_ADVANCED_INSTALLER_FAILED";
		break;
	 case 0x3714:
		return "WERR_XML_ENCODING_MISMATCH";
		break;
	 case 0x3715:
		return "WERR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT";
		break;
	 case 0x3716:
		return "WERR_SXS_IDENTITIES_DIFFERENT";
		break;
	 case 0x3717:
		return "WERR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT";
		break;
	 case 0x3718:
		return "WERR_SXS_FILE_NOT_PART_OF_ASSEMBLY";
		break;
	 case 0x3719:
		return "WERR_SXS_MANIFEST_TOO_BIG";
		break;
	 case 0x371a:
		return "WERR_SXS_SETTING_NOT_REGISTERED";
		break;
	 case 0x371b:
		return "WERR_SXS_TRANSACTION_CLOSURE_INCOMPLETE";
		break;
	 case 0x3a98:
		return "WERR_EVT_INVALID_CHANNEL_PATH";
		break;
	 case 0x3a99:
		return "WERR_EVT_INVALID_QUERY";
		break;
	 case 0x3a9a:
		return "WERR_EVT_PUBLISHER_METADATA_NOT_FOUND";
		break;
	 case 0x3a9b:
		return "WERR_EVT_EVENT_TEMPLATE_NOT_FOUND";
		break;
	 case 0x3a9c:
		return "WERR_EVT_INVALID_PUBLISHER_NAME";
		break;
	 case 0x3a9d:
		return "WERR_EVT_INVALID_EVENT_DATA";
		break;
	 case 0x3a9f:
		return "WERR_EVT_CHANNEL_NOT_FOUND";
		break;
	 case 0x3aa0:
		return "WERR_EVT_MALFORMED_XML_TEXT";
		break;
	 case 0x3aa1:
		return "WERR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL";
		break;
	 case 0x3aa2:
		return "WERR_EVT_CONFIGURATION_ERROR";
		break;
	 case 0x3aa3:
		return "WERR_EVT_QUERY_RESULT_STALE";
		break;
	 case 0x3aa4:
		return "WERR_EVT_QUERY_RESULT_INVALID_POSITION";
		break;
	 case 0x3aa5:
		return "WERR_EVT_NON_VALIDATING_MSXML";
		break;
	 case 0x3aa6:
		return "WERR_EVT_FILTER_ALREADYSCOPED";
		break;
	 case 0x3aa7:
		return "WERR_EVT_FILTER_NOTELTSET";
		break;
	 case 0x3aa8:
		return "WERR_EVT_FILTER_INVARG";
		break;
	 case 0x3aa9:
		return "WERR_EVT_FILTER_INVTEST";
		break;
	 case 0x3aaa:
		return "WERR_EVT_FILTER_INVTYPE";
		break;
	 case 0x3aab:
		return "WERR_EVT_FILTER_PARSEERR";
		break;
	 case 0x3aac:
		return "WERR_EVT_FILTER_UNSUPPORTEDOP";
		break;
	 case 0x3aad:
		return "WERR_EVT_FILTER_UNEXPECTEDTOKEN";
		break;
	 case 0x3aae:
		return "WERR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL";
		break;
	 case 0x3aaf:
		return "WERR_EVT_INVALID_CHANNEL_PROPERTY_VALUE";
		break;
	 case 0x3ab0:
		return "WERR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE";
		break;
	 case 0x3ab1:
		return "WERR_EVT_CHANNEL_CANNOT_ACTIVATE";
		break;
	 case 0x3ab2:
		return "WERR_EVT_FILTER_TOO_COMPLEX";
		break;
	 case 0x3ab3:
		return "WERR_EVT_MESSAGE_NOT_FOUND";
		break;
	 case 0x3ab4:
		return "WERR_EVT_MESSAGE_ID_NOT_FOUND";
		break;
	 case 0x3ab5:
		return "WERR_EVT_UNRESOLVED_VALUE_INSERT";
		break;
	 case 0x3ab6:
		return "WERR_EVT_UNRESOLVED_PARAMETER_INSERT";
		break;
	 case 0x3ab7:
		return "WERR_EVT_MAX_INSERTS_REACHED";
		break;
	 case 0x3ab8:
		return "WERR_EVT_EVENT_DEFINITION_NOT_OUND";
		break;
	 case 0x3ab9:
		return "WERR_EVT_MESSAGE_LOCALE_NOT_FOUND";
		break;
	 case 0x3aba:
		return "WERR_EVT_VERSION_TOO_OLD";
		break;
	 case 0x3abb:
		return "WERR_EVT_VERSION_TOO_NEW";
		break;
	 case 0x3abc:
		return "WERR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY";
		break;
	 case 0x3abd:
		return "WERR_EVT_PUBLISHER_DISABLED";
		break;
	 case 0x3ae8:
		return "WERR_EC_SUBSCRIPTION_CANNOT_ACTIVATE";
		break;
	 case 0x3ae9:
		return "WERR_EC_LOG_DISABLED";
		break;
	 case 0x3afc:
		return "WERR_MUI_FILE_NOT_FOUND";
		break;
	 case 0x3afd:
		return "WERR_MUI_INVALID_FILE";
		break;
	 case 0x3afe:
		return "WERR_MUI_INVALID_RC_CONFIG";
		break;
	 case 0x3aff:
		return "WERR_MUI_INVALID_LOCALE_NAME";
		break;
	 case 0x3b00:
		return "WERR_MUI_INVALID_ULTIMATEFALLBACK_NAME";
		break;
	 case 0x3b01:
		return "WERR_MUI_FILE_NOT_LOADED";
		break;
	 case 0x3b02:
		return "WERR_RESOURCE_ENUM_USER_STOP";
		break;
	 case 0x3b03:
		return "WERR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED";
		break;
	 case 0x3b04:
		return "WERR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME";
		break;
	 case 0x3b60:
		return "WERR_MCA_INVALID_CAPABILITIES_STRING";
		break;
	 case 0x3b61:
		return "WERR_MCA_INVALID_VCP_VERSION";
		break;
	 case 0x3b62:
		return "WERR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION";
		break;
	 case 0x3b63:
		return "WERR_MCA_MCCS_VERSION_MISMATCH";
		break;
	 case 0x3b64:
		return "WERR_MCA_UNSUPPORTED_MCCS_VERSION";
		break;
	 case 0x3b65:
		return "WERR_MCA_INTERNAL_ERROR";
		break;
	 case 0x3b66:
		return "WERR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED";
		break;
	 case 0x3b67:
		return "WERR_MCA_UNSUPPORTED_COLOR_TEMPERATURE";
		break;
	 case 0x3b92:
		return "WERR_AMBIGUOUS_SYSTEM_DEVICE";
		break;
	 case 0x3bc3:
		return "WERR_SYSTEM_DEVICE_NOT_FOUND";
		break;
